@@ -321,11 +321,23 @@ var CentrimoGraphMetrics = function(legend_metrics, top_edge, bottom_edge,
  * Takes a results set and a window weight array and produces a graph. 
  * The weights in the window_weights should be non-negative and sum to 1.
  */
-var CentrimoGraph = function(rset, window_weights, fine_text, start, end, mirror) {
+var CentrimoGraph = function(rset, window_weights, fine_text, start, end, mirror, align, motif_width) {
   "use strict";
   var trim_left, trim_right, i, j, k, result, x, y, xpos, ypos, positions;
   var y_neg, ypos_neg, line_thickness;
 
+  // Set the position of the vertical line.
+  this.align = align ? align : "center";
+
+  // set the width of motif
+  this.motif_width = motif_width ? motif_width : 0;
+
+  // set the length of the sequences.
+  this.seq_len = rset.seq_len();
+
+  // Set the size of the smooting window.
+  this.window_width = window_weights.length;
+
   line_thickness = (window_weights.length < 10 ? 1 : 3);
   if (typeof fine_text !== "string") {
     fine_text = "";
@@ -539,7 +551,7 @@ CentrimoGraph.prototype.draw_x_axis = function(ctx, w, h) {
   }
   // draw the tics
   ctx.save();
-  ctx.font = "14pt Helvetica";
+  ctx.font = "19px Helvetica";
   ctx.textBaseline = "top";
   ctx.textAlign = "center";
   for (i = tic_min; i <= tic_max; i+= tic_inc) {
@@ -585,7 +597,7 @@ CentrimoGraph.prototype.draw_top_axis = function(ctx, w, h) {
   }
   // draw the tics
   ctx.save();
-  ctx.font = "14pt Helvetica";
+  ctx.font = "19px Helvetica";
   ctx.textBaseline = "top";
   ctx.textAlign = "center";
   for (i = tic_min; i <= tic_max; i+= tic_inc) {
@@ -605,7 +617,7 @@ CentrimoGraph.prototype.draw_top_axis = function(ctx, w, h) {
 CentrimoGraph.prototype.draw_x_axis_label = function(ctx, w, h) {
   "use strict";
   ctx.save();
-  ctx.font = "14pt Helvetica";
+  ctx.font = "19px Helvetica";
   ctx.textAlign = "center";
   ctx.textBaseline = "bottom";
   ctx.fillText((this.mirror ? 
@@ -623,7 +635,7 @@ CentrimoGraph.prototype.draw_y_axis = function(ctx, w, h) {
   "use strict";
   var y_scale, p, y;
   ctx.save();
-  ctx.font = "14pt Helvetica";
+  ctx.font = "19px Helvetica";
   ctx.textBaseline = "middle";
   ctx.textAlign = "right";
 
@@ -657,7 +669,7 @@ CentrimoGraph.prototype.draw_y_axis_label = function(ctx, w, h) {
   ctx.save();
   ctx.translate(0, h/2);
   ctx.rotate(-Math.PI / 2);
-  ctx.font = "14pt Helvetica";
+  ctx.font = "19px Helvetica";
   ctx.textBaseline = "top";
   ctx.textAlign = "center";
   ctx.fillText("Probability", 0, 0);
@@ -675,10 +687,55 @@ CentrimoGraph.prototype.draw_lines = function(ctx, w, h, tic_size) {
   }
   scale_y = h / this.scale.max;
   scale_x = w / (this.end - this.start);
-  // draw the central line
+
+  // draw the horizontal line and write range 
+  if (this.motif_width) {
+    ctx.save();
+    ctx.strokeStyle = '#DDD';
+    var txt_height, t1, t2, w1, w2, xlate, xlate1, xlate2;
+    ctx.font = "13px san-serif";
+    txt_height = parseInt(ctx.font);
+    if (this.align == "left") {
+      t1 = 0;
+      t2 = this.seq_len;
+    } else if (this.align == "center") {
+      t2 = this.seq_len/2;
+      t1 = -t2;
+    } else {
+      t1 = -this.seq_len;
+      t2 = 0;
+    }
+    xlate = (this.motif_width/2.0 + this.window_width/2.0) * scale_x;
+    w1 = ctx.measureText(t1).width;
+    xlate1 = xlate > w1 ? xlate : w1;
+    w2 = ctx.measureText(t2).width;
+    xlate2 = xlate > w2 ? xlate : w2;
+    ctx.textAlign = "left";
+    ctx.fillText(t1, 0, h);
+    ctx.textAlign = "right";
+    ctx.fillText(t1, 0, h);
+    ctx.fillText(t2, w, h);
+    ctx.beginPath();
+    ctx.moveTo(0, h-txt_height);
+    ctx.lineTo(w, h-txt_height);
+    ctx.stroke();
+    ctx.restore();
+    // Adjust h to allow for X axis labels.
+    h -= txt_height;
+    scale_y = h / this.scale.max;
+  }
+  // draw the vertical line
   if (0 > this.start && 0 < this.end) {
     ctx.save();
-    ctx.translate((-this.start) * scale_x, 0);
+    if (this.align == "left") {
+      //ctx.translate((this.motif_width/2.0 + this.window_width/2.0) * scale_x, 0);
+      ctx.translate(0, 0);
+    } else if (this.align == "center") {
+      ctx.translate((-this.start) * scale_x, 0);
+    } else if (this.align == "right") {
+      //ctx.translate(w - (this.motif_width/2.0 + this.window_width/2.0) * scale_x - 1, 0);
+      ctx.translate(w - 1, 0);
+    }
     ctx.strokeStyle = '#DDD';
     ctx.beginPath();
     ctx.moveTo(0.5, tic_size);
