@@ -108,19 +108,22 @@ var shared_doc = {
     "None."
   ],
 
-
-  /* parse-genomic-coord */
-  "all-pgc-opt": ["parse-genomic-coord"],
-  "all-pgc-desc": [
-    "Show actual sequence coordinates for motif sites in the output if the FASTA ",
-    "IDs of the sequences include coordinates in an <a href=\'fasta-coordinates-format.html\'> accepted format</a>. ",
-    "When this option is specified, each input sequence FASTA header is ",
-    "checked for UCSC-style genomic coordinates (e.g., <code>chr1:156887119-156887619</code>) or ",
+  /* no-pgc */
+  "all-no_pgc-opt": ["no-pgc"],
+  "all-no_pgc-desc": [
+    "Suppress parsing of genomic coordinates in the FASTA sequence header. ",
+    "Normally, FASTA sequence headers are parsed for ",
+    "UCSC-style genomic coordinates (e.g., <code>chr1:156887119-156887619</code>) or ",
     "Galaxy 'Fetch sequence'-style coordinates (e.g., <code>>mm9_chr18_75759530_7575972_-</code>). ",
-    "The strand (if given) is ignored."
+    "By default, if coordinates are found in an accepted ",
+    "<a href=\'fasta-coordinates-format.html\'>FASTA Coordinates Format</a>, ",
+    "then the actual sequence coordinates for motif sites will be given in the output. ",
+    "The strand specified in the FASTA sequence header, if given, is ignored. ",
+    "If this option is given, the FASTA sequence headers will not be parsed, and the ",
+    "first position in the sequence will be assumed to be position 1."
   ],
-  "all-pgc-def": [
-    "The first position in the sequence is assumed to be position 1."
+  "all-no_pgc-def": [
+    "The FASTA sequence headers are parsed for genomic coordinates."
   ],
 
   /* inc */
