@@ -70,6 +70,26 @@ function get_shared_doc_text(doc_type, extra, extra2) {
   if (extra == undefined) {extra = ""};
   if (extra2 == undefined) {extra2 = ""};
   switch (doc_type) {
+    case 'fasta-coordinates-name':
+      return(`
+        The sequence IDs in the FASTA header lines are used as the source of sequence names. 
+        The sequence ID is the string following the initial '>' up to the first white space character. 
+        If the sequence ID is in an accepted <a href="` + site_url + `/doc/fasta-coordinates-format.html">FASTA Coordinates Format</a>
+        (e.g., UCSC or Galaxy format), and you did NOT specify the <code>` + extra + `-no-pgc</code> option, 
+        then the coordinates are removed from the sequence ID to create the sequence name.
+      `);
+    case 'fasta-coordinates-brief':
+      return(`
+        The sequence IDs in the FASTA header lines are used as the source of sequence names. 
+        The sequence ID is the string following the initial '>' up to the first white space character. 
+        If the sequence ID is in an accepted <a href="` + site_url + `/doc/fasta-coordinates-format.html">FASTA Coordinates Format</a>
+        (e.g., UCSC or Galaxy format), and you did NOT specify the <code>` + extra + `-no-pgc</code> option, 
+        then the coordinates are removed from the sequence ID to create the sequence name,
+	and the starting coordinate given in the sequence ID will be used as the 
+        coordinate of the first position of the sequence. 
+        Otherwise, the coordinate of the first position of the sequence is taken as 1 and the entire
+	sequence ID is used as the sequence name. 
+      `);
     case 'fasta-coordinates':
       return(`
 	For sequence coordinates embedded in FASTA sequence headers to be parsed 
@@ -107,8 +127,11 @@ function get_shared_doc_text(doc_type, extra, extra2) {
         <b>Example:</b> <span class="pdata">>mm9_chr18_75759530_7575972_-</span>
 
 	<p>	
-	For both formats, the following rules apply:
+	For both formats, the following rules also apply:
         <ul>
+	  <li>The the coordinates are 1-start, fully-closed.  This means
+	  that the first base of the chromosome is position "1", and the bases at the
+	  first and last positions of the given range are included.</li>
 	  <li>The <span class='pdat'>sequence name</span> may not contain any white space.</li>
 	  <li>The <span class='pdat'>assembly name</span> is not optional.</li>
 	  <li>The <span class='pdat'>strand</span> is ignored.</li>
@@ -192,20 +215,10 @@ function get_shared_doc_text(doc_type, extra, extra2) {
       return(`
         The identifier of the sequence (from the FASTA sequence header line)` + extra + `
       `);
-    case 'sequence-name':
-      return(`
-	` + extra + `name of the sequence extracted from the sequence identifier (in the FASTA sequence header line).<br>
-	When you use the <code>--parse-genomic--coord</code> option, the sequence name ends at the
-	first colon ':' (if any) present in the sequence\'s FASTA identifier.  Typically this is the
-	chromosome or contig name.  With the <code>--parse-genomic--coord</code> option,
-	the start and stop positions are in 0-based coordinates relative to the sequence start given 
-	in the FASTA sequence identifier (just after the sequence name).</td> </tr>
-      `);
     case 'sequence-desc':
       return(`
         The description appearing after the identifier of the sequence in the FASTA header line.
       `);
-    case 'sequence-name':
     case 'alph-name':
       return(`
 	The name of the alphabet symbol.
@@ -214,6 +227,14 @@ function get_shared_doc_text(doc_type, extra, extra2) {
       return(`
 	The frequency of the alphabet symbol as defined by the background model.
       `);
+    case 'match-start':
+      return(`
+	The start position of the ` + extra + `.
+      `);
+    case 'match-stop':
+      return(`
+	The end position of the ` + extra + `.
+      `);
     case 'match-start-seq':
       return(`
 	The start position of the ` + extra + `; 1-based sequence coordinates.
@@ -230,12 +251,6 @@ function get_shared_doc_text(doc_type, extra, extra2) {
       return(`
 	The end position of the ` + extra + `; genomic coordinates.
       `);
-    case 'parse-genomic-coord':
-      return(`
-	` + extra + ` was run with the <code>--parse-genomic-coord</code> option
-	and has split the sequence identifier into sequence name, sequence start and sequence end 
-	in genomic coordinates.
-      `);
     case 'motif-consensus':
       return(`
         <p id="consensus_doc">
