@@ -1860,7 +1860,7 @@ function download_eps() {
   if (canvas.getContext) {
     var ctx = canvas.getContext('2d');
     var eps_ctx = new EpsContext(ctx, canvas.width, canvas.height);
-    eps_ctx.register_font("14pt Helvetica", "Helvetica", 14 / 3 * 4);
+    eps_ctx.register_font("19px Helvetica", "Helvetica", 19);
     eps_ctx.register_font("16px Helvetica", "Helvetica", 16);
     eps_ctx.register_font("9px Helvetica", "Helvetica", 9);
     make_MP_graph2(ctx, canvas.width, canvas.height);
