@@ -160,6 +160,7 @@ function make_clustered_motifs(container) {
       link.appendChild(document.createTextNode("CentriMo Group \u21B7"));
       link.href = centrimo_url(centrimo_list);
       group.appendChild(link);
+      group.append("\u2009");  // thin space
       group.appendChild(help_button("pop_centrimo_group"));
       motifbox.appendChild(group);
     }
@@ -560,6 +561,7 @@ function make_expand(target, nmotifs, grow_box, grow_table) {
   deactivator.grow_table = grow_table;
   deactivator.onclick = less_logos;
   control.appendChild(deactivator);
+  control.append("\u2009");		// thin space
   control.appendChild(help_button("pop_show_clustered"));
   return control;
 }
