@@ -212,14 +212,14 @@ function action_show_outpop(e, ordinal) {
     // setup program selection
     tbl_submit = $("programs");
     // when not dna, hide the inputs for programs that require dna motifs
-    toggle_class(tbl_submit, "alphabet_dna", current_alphabet.has_complement());//TODO FIXME alphabet_dna is a bad name for a field when allowing custom alphabets
+    toggle_class(tbl_submit, "alphabet_dna", current_alphabet.has_complement());//TODO alphabet_dna is a bad name for a field when allowing custom alphabets
     // add a click listener for the radio buttons
     inputs = tbl_submit.querySelectorAll("input[type='radio']");
     for (i = 0; i < inputs.length; i++) {
       inputs[i].addEventListener("click", action_outpop_program, false);
     }
     // ensure that a default program option is selected for DNA and Protein
-    default_prog = document.getElementById(current_alphabet.has_complement() ? "submit_tomtom" : "submit_fimo"); //TODO FIXME Tomtom might require a more strict definition of DNA
+    default_prog = document.getElementById(current_alphabet.has_complement() ? "submit_tomtom" : "submit_fimo"); //TODO Tomtom might require a more strict definition of DNA
     default_prog.checked = true;
     action_outpop_program.call(default_prog);
     // disable reverse-complement when not DNA
