@@ -107,7 +107,7 @@ sub _handle_test_positives{
 
 sub _start_motif {
   my $self = shift;
-  my ($id, $alt, $width, $initial_width, $seed, $score_threshold, 
+  my ($id, $alt, $width, $initial_width, $seed, $score_threshold, $npassing,
     $train_pos_count, $train_neg_count, $train_log_pvalue, $train_pvalue, $train_dtc, $train_bernoulli,
     $test_pos_count, $test_neg_count, $test_log_pvalue, $test_pvalue, $test_log_evalue, $test_evalue,
     $test_dtc, $test_bernoulli, $elapsed_time, $total_sites, $site_distr) = @_;
@@ -126,7 +126,7 @@ sub _start_motif {
     id => $id, 
     alt => $alt,
     width => $width, 
-    sites => $train_pos_count + $test_pos_count,
+    sites => $npassing >= 0 ? $npassing : $train_pos_count + $test_pos_count,	# npassing added in 5.5.3
     pseudo => 0,
     log_evalue_accurate => $evalue_accurate,
     log_evalue => $evalue_accurate ? $test_log_evalue : $train_log_pvalue,
