@@ -31,7 +31,7 @@ static void do_branch (
   BRANCH_PARAMS *branch_params, ///< The parameters controlling branching search
   HEAP *branch_heap, ///< The heap of SEEDs. Branching search will be
                      ///< performed around each of these seeds.
-  BOOLEAN ic,        ///< Allow motifs on reverse complement strand of DNA too.
+  bool ic,        ///< Allow motifs on reverse complement strand of DNA too.
   int lmap[MAXALPH][MAXALPH],
                      ///< Log freq x letter map (for converting seed to theta).
   DATASET *dataset,  ///< The dataset of sequences
@@ -44,7 +44,7 @@ static void do_branch (
 static void eval_mutant_seeds (
   BRANCH_PARAMS *branch_params, ///< The parameters controlling branching search
   char *init_str,    ///> The initial seed, which will be "branched" from
-  BOOLEAN ic,        ///< Allow motifs on reverse complement strand of DNA too.
+  bool ic,        ///< Allow motifs on reverse complement strand of DNA too.
   int lmap[MAXALPH][MAXALPH],
                      ///< Log freq x letter map (for converting seed to theta).
   DATASET *dataset,  ///< The dataset of sequences
@@ -56,7 +56,7 @@ static void eval_mutant_seeds (
 );
 static void evaluate_ACGTX_mutants (
   char *init_str,    ///< The initial seed, which will be "branched" from
-  BOOLEAN ic,        ///< Allow motifs on reverse complement strand of DNA too.
+  bool ic,        ///< Allow motifs on reverse complement strand of DNA too.
   int lmap[MAXALPH][MAXALPH],
                      ///< Log freq x letter map (for converting seed to theta).
   DATASET *dataset,  ///< The dataset of sequences
@@ -68,7 +68,7 @@ static void evaluate_ACGTX_mutants (
 );
 static void evaluate_width_mutants (
   char *init_str,    ///> The initial seed, which will be "branched" from
-  BOOLEAN ic,        ///< Allow motifs on reverse complement strand of DNA too.
+  bool ic,        ///< Allow motifs on reverse complement strand of DNA too.
   int lmap[MAXALPH][MAXALPH],
                      ///< Log freq x letter map (for converting seed to theta).
   DATASET *dataset,  ///< The dataset of sequences
@@ -89,7 +89,7 @@ static void consider_seed (
   int lmap[MAXALPH][MAXALPH],
                      ///< Log freq x letter map (for converting seed to theta).
   MTYPE mtype,       ///< The type of model.
-  BOOLEAN ic,        ///< Whether or not to consider inverse complement
+  bool ic,        ///< Whether or not to consider inverse complement
   DATASET *dataset,  ///< Contains the pY arrays
   SP_MATRIX *sp_mat  ///< This matrix will be updated with the seed, if novel.
 );
@@ -110,7 +110,7 @@ static void consider_seed (
  *    with the novel seeds
  *
  */
-extern void branching_search (
+void branching_search (
   BRANCH_PARAMS *branch_params, ///< The parameters controlling branching search
   MODEL *model,      ///< The motif model (nascent)
   DATASET *dataset,  ///< The dataset of sequences
@@ -124,11 +124,10 @@ extern void branching_search (
   MTYPE mtype = model->mtype;
   int ic = model->invcomp;
   THETA map = dataset->map;     // letter by frequency mapping matrix
-  int alength = dataset->alength;
 
   // Get the consensus letter vs. log frequency matrix:
   int lmap[MAXALPH][MAXALPH];
-  convert_to_lmap(map, lmap, alength);
+  convert_to_lmap(map, lmap, dataset->alph);
 
   int branch_iter;
   // Branch from each heap in the matrix once for each iteration:
@@ -211,7 +210,7 @@ static void do_branch (
   BRANCH_PARAMS *branch_params, ///< The parameters controlling branching search
   HEAP *branch_heap, ///< The heap of SEEDs. Branching search will be
                      ///< performed around each of these seeds.
-  BOOLEAN ic,        ///< Allow motifs on reverse complement strand of DNA too.
+  bool ic,        ///< Allow motifs on reverse complement strand of DNA too.
   int lmap[MAXALPH][MAXALPH],
                      ///< Log freq x letter map (for converting seed to theta).
   DATASET *dataset,  ///< The dataset of sequences
@@ -298,7 +297,7 @@ static void do_branch (
 static void eval_mutant_seeds (
   BRANCH_PARAMS *branch_params, ///< The parameters controlling branching search
   char *init_str,    ///> The initial seed, which will be "branched" from
-  BOOLEAN ic,        ///< Allow motifs on reverse complement strand of DNA too.
+  bool ic,        ///< Allow motifs on reverse complement strand of DNA too.
   int lmap[MAXALPH][MAXALPH],
                      ///< Log freq x letter map (for converting seed to theta).
   DATASET *dataset,  ///< The dataset of sequences
@@ -315,7 +314,7 @@ static void eval_mutant_seeds (
   // Declare the log motif corresponding to the current seed
   int *lmotif[MAXSITE];
   int mot_width;
-  create_lmotif(init_str, lmap, lmotif, &mot_width);
+  create_lmotif(dataset->alph, init_str, lmap, lmotif, &mot_width);
   
   // Set the pY arrays under the initial, unmutated seed:
   if (!ic) {
@@ -363,7 +362,7 @@ static void consider_seed (
   int lmap[MAXALPH][MAXALPH],
                      ///< Log freq x letter map (for converting seed to theta).
   MTYPE mtype,       ///< The type of model.
-  BOOLEAN ic,        ///< Whether or not to consider inverse complement
+  bool ic,        ///< Whether or not to consider inverse complement
   DATASET *dataset,  ///< Contains the pY arrays
   SP_MATRIX *sp_mat  ///< This matrix will be updated with the seed, if novel.
 ) {
@@ -371,31 +370,30 @@ static void consider_seed (
   /* Determine whether the new candidate seed is novel. It is not novel if
      it is the same as init_seed, or if it is already registered in
      evaluated_seed_ht: */
-  BOOLEAN seed_is_novel = TRUE;
+  bool seed_is_novel = true;
   if (strcmp(init_str, candidate_seed) == 0) {
-    seed_is_novel = FALSE;
+    seed_is_novel = false;
   }
-  int hash_value; // dummy: required by stupid hash_lookup interface.
-  if (hash_lookup_str(candidate_seed, evaluated_seed_ht, &hash_value) != NULL) {
-    seed_is_novel = FALSE;
+  if (hash_lookup_str(candidate_seed, evaluated_seed_ht) != NULL) {
+    seed_is_novel = false;
   }
 
   // Determine whether the length of the new candidate seed is encompassed by
   // sp_mat:
-  BOOLEAN length_ok = TRUE;
+  bool length_ok = true;
   if ((strlen(candidate_seed) < get_min_width(sp_mat)) ||
       (strlen(candidate_seed) > get_max_width(sp_mat))) {
-    length_ok = FALSE;
+    length_ok = false;
   }
 
   // Evaluate the seed IFF the seed is novel and its length is valid:
-  BOOLEAN eval_seed = (seed_is_novel && length_ok);
+  bool eval_seed = (seed_is_novel && length_ok);
 
   if (eval_seed) {
     /* Compare this candidate seed against the seed for which pY is set.
        Generate an object representing the differences between the candidate
        seed and the previous seed: */
-    SEED_DIFFS *s_diffs = get_seed_diffs(pY_str, candidate_seed, lmap);
+    SEED_DIFFS *s_diffs = get_seed_diffs(dataset->alph, pY_str, candidate_seed, lmap);
     
     /* Evaluate the candidate seed using DP, given that we know which columns
        differ with respect to the current "pY" seed. This function updates
@@ -444,7 +442,7 @@ static void consider_seed (
  */
 static void evaluate_ACGTX_mutants (
   char *init_str,    ///> The initial seed, which will be "branched" from
-  BOOLEAN ic,        ///< Allow motifs on reverse complement strand of DNA too.
+  bool ic,        ///< Allow motifs on reverse complement strand of DNA too.
   int lmap[MAXALPH][MAXALPH],
                      ///< Log freq x letter map (for converting seed to theta).
   DATASET *dataset,  ///< The dataset of sequences
@@ -455,34 +453,33 @@ static void evaluate_ACGTX_mutants (
                      ///< by this branching
 ) {
   // Keep a copy of the string that currently corresponds to the pY arrays:
-  char pY_str[MAXSITE];
+  char pY_str[MAXSITE+1];
   strcpy(pY_str, init_str);
 
   // Set aside memory for a copy of the initial seed, which will be mutated:
   int seed_len = strlen(init_str);
-  char modified_seed[MAXSITE];       // String representation
+  char modified_seed[MAXSITE+1];       // String representation
   
   /* Now, calculate the objective function score for each NOVEL seed in the
      series of mutants... The sequence of mutants will be generated by
      sequentially "mutating" each column to the alternative characters. */
 
   // First and last letters to try mutating to...
-  int nrows = dataset->alength;
-  int lett_start=nrows;
+  int lett_start = alph_wild(dataset->alph); // index of wildcard
   if (dataset->branch_params->point_branch == X_ONLY) {
     // X only branching:
-    lett_start=nrows;
+    lett_start = alph_wild(dataset->alph); // index of wildcard
   } else {
-    lett_start=0;
+    lett_start = 0; // index of first core letter
   }
   // If branching search is considering "mutate to X" as a move, then
   // make this happen by setting the final letter differently:
   int lett_end;
   if ((dataset->branch_params->point_branch == ALL) ||
       (dataset->branch_params->point_branch == X_ONLY)) {
-    lett_end=nrows;
+    lett_end = alph_wild(dataset->alph); // index of wildcard
   } else {
-    lett_end=nrows - 1;
+    lett_end = alph_size_core(dataset->alph) - 1; // index of last core letter
   }
 
   // Try mutating each column:
@@ -499,7 +496,7 @@ static void evaluate_ACGTX_mutants (
       strcpy(modified_seed, init_str);
 
       // Set the letter at column "col_idx" to "lett":
-      modified_seed[col_idx] = unhash(lett);
+      modified_seed[col_idx] = alph_char(dataset->alph, lett);
 
       // Consider the new candidate current seed; evaluate IFF novel:
       consider_seed(modified_seed, init_str, evaluated_seed_ht, pY_str, lmap,
@@ -511,13 +508,13 @@ static void evaluate_ACGTX_mutants (
   // they were at the start of the function. HOWEVER I only need to do this if
   // pY_str is not the same as modified_seed:
   if (strcmp(init_str, pY_str) != 0) {
-    SEED_DIFFS *s_diffs = get_seed_diffs(pY_str, init_str, lmap);
+    SEED_DIFFS *s_diffs = get_seed_diffs(dataset->alph, pY_str, init_str, lmap);
 
     // Update the pY arrays to correspond to the init_str (as they did at the
     // start of this function):
     int *lmotif[MAXSITE];
     int mot_width;
-    create_lmotif(init_str, lmap, lmotif, &mot_width);
+    create_lmotif(dataset->alph, init_str, lmap, lmotif, &mot_width);
     assert(mot_width == strlen(init_str));
     if (!ic) {
       next_pY_branching(lmotif, s_diffs, dataset, 0);
@@ -545,7 +542,7 @@ static void evaluate_ACGTX_mutants (
  */
 static void evaluate_width_mutants (
   char *init_str,    ///> The initial seed, which will be "branched" from
-  BOOLEAN ic,        ///< Allow motifs on reverse complement strand of DNA too.
+  bool ic,        ///< Allow motifs on reverse complement strand of DNA too.
   int lmap[MAXALPH][MAXALPH],
                      ///< Log freq x letter map (for converting seed to theta).
   DATASET *dataset,  ///< The dataset of sequences
@@ -556,19 +553,18 @@ static void evaluate_width_mutants (
                      ///< by this branching
 ) {
   // Keep a copy of the string that currently corresponds to the pY arrays:
-  char pY_str[MAXSITE];
+  char pY_str[MAXSITE+1];
   strcpy(pY_str, init_str);
 
   // Set aside memory for a copy of the initial seed, which will be mutated:
-  char modified_seed[MAXSITE];       // String representation
+  char modified_seed[MAXSITE+1];       // String representation
   
   /* Now, calculate the objective function score for each NOVEL seed in the
      series of mutants... */
 
   // Determine letters to consider when appending at either end of the seed:
-  int nrows = dataset->alength;
   int lett_start = 0;
-  int lett_end = nrows - 1;
+  int lett_end = alph_size_core(dataset->alph) - 1; // index of last core letter
 
   // Consider mutants generated by appending a letter to the end of the
   // seed...
@@ -578,7 +574,7 @@ static void evaluate_width_mutants (
   for (lett = lett_start; lett <= lett_end; lett++) {
     // Set the letter at the end of the seed (and terminate string with '\0'):
     int curr_end_idx = strlen(init_str);
-    modified_seed[curr_end_idx] = unhash(lett);
+    modified_seed[curr_end_idx] = alph_char(dataset->alph, lett);
     modified_seed[curr_end_idx + 1] = '\0';
 
     // Consider the new candidate current seed; evaluate IFF novel:
@@ -609,7 +605,7 @@ static void evaluate_width_mutants (
   strcpy((modified_seed+1), init_str);
   for (lett = lett_start; lett <= lett_end; lett++) {
     // Place the extra letter at the start of the new seed:
-    modified_seed[0] = unhash(lett);
+    modified_seed[0] = alph_char(dataset->alph, lett);
 
     // Consider the new candidate current seed; evaluate IFF novel:
     consider_seed(modified_seed, init_str, evaluated_seed_ht, pY_str, lmap,
