@@ -741,6 +741,11 @@ MATCHED_ELEMENT_T **get_pattern_stored_matches(PATTERN_T *pattern);
 **********************************************************************/
 MATCHED_ELEMENT_T **get_pattern_matched_elements(PATTERN_T *pattern);
 
+/*************************************************************************
+ * Find the best site for each sequence and mark the matches.
+ *************************************************************************/
+void pattern_find_best_site(PATTERN_T *pattern);
+
 /*************************************************************************
  * Calculate the q-values for each matched-element in this pattern
  * from the p-values.
@@ -918,6 +923,13 @@ void set_scanned_sequence_db(SCANNED_SEQUENCE_T *scanned_sequence, char *db);
 **********************************************************************/
 char *get_scanned_sequence_db(SCANNED_SEQUENCE_T* scanned_sequence);
 
+/**********************************************************************
+  get_scanned_sequence_uid
+
+  Gets the unique numeric identifier from a cisml scanned_sequence object.
+**********************************************************************/
+long get_scanned_sequence_uid(SCANNED_SEQUENCE_T* scanned_sequence);
+
 /**********************************************************************
   set_scanned_sequence_lsid
 
@@ -1062,6 +1074,13 @@ MATCHED_ELEMENT_T *allocate_matched_element_with_score(
 **********************************************************************/
 void free_matched_element(MATCHED_ELEMENT_T *element);
 
+/**********************************************************************
+  get_matched_element_is_best_site
+
+  Gets if a cisml matched_element object is the best site in the sequence.
+**********************************************************************/
+bool get_matched_element_is_best_site(MATCHED_ELEMENT_T* element);
+
 /**********************************************************************
   get_matched_element_start
 
@@ -1076,8 +1095,6 @@ int get_matched_element_start(MATCHED_ELEMENT_T* matched_element);
 **********************************************************************/
 void set_matched_element_start(MATCHED_ELEMENT_T* matched_element, int newstart);
 
-
-
 /**********************************************************************
   get_matched_element_stop
 
