@@ -65,7 +65,7 @@ int main(int argc, char* argv[]) {
   int c = 0;
   char* option_name = NULL;
   char* option_value = NULL;
-	const char *  message = NULL;
+	const char*  message = NULL;
 
   // Define the usage message.
   char      usage[400] = "";
@@ -88,7 +88,7 @@ int main(int argc, char* argv[]) {
       break;
     } else if (c < 0) {
     	simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
 
     if (strcmp(option_name, "nogap") == 0) {
