@@ -64,7 +64,8 @@ static void process_command_line(
     {"num-bins", REQUIRED_VALUE},
     {"o", REQUIRED_VALUE},
     {"oc", REQUIRED_VALUE},
-    {"parse-genomic-coord", NO_VALUE},
+    {"no-pgc", NO_VALUE},
+    {"parse-genomic-coord", NO_VALUE},	// backward compatibility
     {"psp", NO_VALUE},
     {"verbosity", REQUIRED_VALUE},
     {"version", NO_VALUE}
@@ -83,7 +84,7 @@ static void process_command_line(
     "     --num-bins <int> (default 100)\n"
     "     --o <output dir> (default=createpriors_out)\n"
     "     --oc <output dir> (default=createpriors_out)\n"
-    "     --parse-genomic-coord\n"
+    "     --no-pgc\n"
     "     --psp\n"
     "     --verbosity [1|2|3|4] (default 2)\n"
     "     --version\n"
@@ -97,7 +98,7 @@ static void process_command_line(
   options->output_dirname = "create-priors_out";
   options->output_psp = false;
   options->output_version = false;
-  options->parse_genomic_coord = false;
+  options->parse_genomic_coord = true;
 
   simple_setopt(argc, argv, num_options, createpriors_options);
 
@@ -139,6 +140,9 @@ static void process_command_line(
     else if (strcmp(option_name, "parse-genomic-coord") == 0){
       options->parse_genomic_coord = true;
     }
+    else if (strcmp(option_name, "no-pgc") == 0){
+      options->parse_genomic_coord = false;
+    }
     else if (strcmp(option_name, "psp") == 0){
       options->output_psp = true;
     }
@@ -695,16 +699,17 @@ size_t read_sequences_from_fasta(
     int end;
     SEQ_INFO_T *seq_info = mm_malloc(sizeof(SEQ_INFO_T));
     // We may need to extract genomic coordinates out of the name
-    if (options.parse_genomic_coord) {
-      char *parsed_name = NULL;
-      size_t parsed_name_size = 0;
-      bool result = parse_genomic_coordinates_helper(
-        sample_name,
-        &parsed_name,
-        &parsed_name_size,
-        &start,
-        &end
-      );
+    char *parsed_name = NULL;
+    size_t parsed_name_size = 0;
+    if (options.parse_genomic_coord && 
+      parse_genomic_coordinates_helper(
+	sample_name,
+	&parsed_name,
+	&parsed_name_size,
+	&start,
+	&end
+      ) 
+    ) {
       // TODO: Genomic coord are currently coming back as 0-based
       // Talk to Tim about this.
       ++start;
