@@ -7,6 +7,45 @@
 
 const int MAX_HTML_MATCHES = 1000;
 
+/***********************************************************************
+  Print narrowPeak record for a motif site.
+ ***********************************************************************/
+void print_site_as_narrow_peak(
+  FILE *narrow_peak_file,
+  MATCHED_ELEMENT_T *match,
+  SCANNED_SEQUENCE_T *scanned_seq
+) {
+
+  PATTERN_T *pattern = get_scanned_sequence_parent(scanned_seq);
+  char *seq_name = get_scanned_sequence_name(scanned_seq);
+  int start = get_matched_element_start(match);
+  int stop = get_matched_element_stop(match);
+  if (stop < start) {
+    SWAP(int, start, stop);
+  }
+  char *motif_id = get_pattern_accession(pattern);
+  char strand = get_matched_element_strand(match);
+  double score = get_matched_element_score(match);
+  double pvalue = get_matched_element_pvalue(match);
+  double qvalue = get_matched_element_qvalue(match);
+  int peak = (stop-start)/2;
+  fprintf(
+    narrow_peak_file, 
+    "%s\t%d\t%d\t%s\t%d\t%c\t%g\t%.3g\t%.3g\t%d\n",
+    seq_name,	// chrom
+    start,	// chromStart
+    stop+1,	// chromEnd
+    motif_id,	// name
+    450,	// score
+    strand, 	// strand
+    score,	// signalValue
+    pvalue,	// pValue
+    qvalue,	// qvalue
+    peak	// peak
+  );
+
+} // print_site_as_narrow_peak
+
 /***********************************************************************
   Print TSV record for a motif site.
  ***********************************************************************/
@@ -239,6 +278,28 @@ void print_fimo_xml_file(
   fputs("</fimo>\n", out);
 }
 
+/**********************************************************************
+ * This function saves best site for each motif in each sequence 
+ * as an ENCODE narrowPeak file.
+ *********************************************************************/
+void print_fimo_best_site_file(
+  FILE *best_site_file, 
+  CISML_T *cisml, 
+  FIMO_OPTIONS_T options
+) {
+
+  CISML_MATCH_IT_T *it = allocate_cisml_match_iterator(cisml);
+  MATCHED_ELEMENT_T *match = NULL;
+  while ((match = cisml_match_iterator_next(it)) !=NULL) {
+    SCANNED_SEQUENCE_T *scanned_seq = get_matched_element_scanned_seq(match);
+    if (get_matched_element_is_best_site(match)) {
+      print_site_as_narrow_peak(best_site_file, match, scanned_seq);
+    }
+  }
+
+  free_cisml_match_iterator(it);
+}
+
 /**********************************************************************
  * This function saves significant FIMO results as a TSV file.
  *********************************************************************/
@@ -265,10 +326,10 @@ void print_fimo_tsv_file(
 
   free_cisml_match_iterator(it);
 
-  // Finish the TSV output
+  // Finish the TSV output.
   char *version_message = "# FIMO (Find Individual Motif Occurrences): Version " VERSION " compiled on " __DATE__ " at " __TIME__ "\n";
   fprintf(tsv_file, "\n%s", version_message);
-  fprintf(tsv_file, "# The format of this file is described at %s/%s.\n", SITE_URL, "doc/fimo-output-format.html");
+  fprintf(tsv_file, "# The format of this file is described at %s/%s.\n", SITE_URL, "doc/fimo-output-format.html#tsv_results");
   fprintf(tsv_file, "# %s\n", options.command_line);
 }
 
@@ -760,6 +821,11 @@ void print_fimo_results(
   long num_residues
 ) {
 
+  if (options.best_site_only) {
+    print_fimo_best_site_file(stdout, cisml, options);
+    return;
+  }
+
   const bool PRINT_WARNINGS = false;
   if (create_output_directory(
        options.output_dirname,
@@ -796,7 +862,7 @@ void print_fimo_results(
   );
   fclose(fimo_file);
 
-  // Print plain text.
+  // Print TSV file.
   fimo_file = fopen(options.text_path, "w");
   if (!fimo_file) {
     die("Couldn't open file %s for output.\n", options.text_path);
@@ -804,6 +870,13 @@ void print_fimo_results(
   print_fimo_tsv_file(fimo_file, cisml, options);
   fclose(fimo_file);
 
+  // Print best sites in narrowPeak file.
+  fimo_file = fopen(options.best_site_path, "w");
+  if (!fimo_file) {
+    die("Couldn't open file %s for output.\n", options.text_path);
+  }
+  print_fimo_best_site_file(fimo_file, cisml, options);
+
   // Print GFF.
   fimo_file = fopen(options.gff_path, "w");
   if (!fimo_file) {
