@@ -85,6 +85,7 @@ static void cleanup_options(FIMO_OPTIONS_T options) {
   myfree(options.html_path);
   myfree(options.text_path);
   myfree(options.gff_path);
+  myfree(options.best_site_path);
   myfree(options.xml_path);
   myfree(options.cisml_path);
   free_string_list(options.selected_motifs);
@@ -114,11 +115,13 @@ static FIMO_OPTIONS_T process_fimo_command_line(
     {"o", REQUIRED_VALUE},
     {"oc", REQUIRED_VALUE},
     {"no-qvalue", NO_VALUE},
-    {"parse-genomic-coord", NO_VALUE},
+    {"no-pgc", NO_VALUE},
+    {"parse-genomic-coord", NO_VALUE}, // backward compatibility
     {"psp", REQUIRED_VALUE},
     {"prior-dist", REQUIRED_VALUE},
     {"qv-thresh", NO_VALUE},
     {"text", NO_VALUE},
+    {"best-site", NO_VALUE},
     {"skip-matched-sequence", NO_VALUE},
     {"thresh", REQUIRED_VALUE},
     {"verbosity", REQUIRED_VALUE},
@@ -136,9 +139,10 @@ static FIMO_OPTIONS_T process_fimo_command_line(
     "     --oc <output dir> (default: fimo_out)\n"
     "     --text\n"
     "     --skip-matched-sequence\n"
+    "     --best-site\n"
     "     --motif <id> (default: all)\n"
     "     --motif-pseudo <float> (default: 0.1)\n"
-    "     --parse-genomic-coord\n"
+    "     --no-pgc\n"
     "     --bfile <background file> (DNA and protein use NRDB by default)\n"
     "     --psp <PSP filename> (default: none)\n"
     "     --alpha <double> (default 1.0)\n"
@@ -165,9 +169,10 @@ static FIMO_OPTIONS_T process_fimo_command_line(
   options.allow_clobber = true;
   options.compute_qvalues = true;
   options.max_strand = false;
-  options.parse_genomic_coord = false;
+  options.parse_genomic_coord = true;
   options.threshold_type = PV_THRESH;
   options.text_only = false;
+  options.best_site_only = false;
   options.scan_both_strands = true;
   options.skip_matched_sequence = false;
 
@@ -181,7 +186,6 @@ static FIMO_OPTIONS_T process_fimo_command_line(
 
   options.max_stored_scores = 100000;
 
-
   options.alpha = 1.0;
   options.pseudocount = 0.1;
   options.pseudocount = 0.1;
@@ -254,6 +258,9 @@ static FIMO_OPTIONS_T process_fimo_command_line(
     else if (strcmp(option_name, "parse-genomic-coord") == 0){
       options.parse_genomic_coord = true;
     }
+    else if (strcmp(option_name, "no-pgc") == 0){
+      options.parse_genomic_coord = false;
+    }
     else if (strcmp(option_name, "thresh") == 0){
       options.output_threshold = atof(option_value);
     }
@@ -270,6 +277,9 @@ static FIMO_OPTIONS_T process_fimo_command_line(
     else if (strcmp(option_name, "text") == 0){
       options.text_only = true;
     }
+    else if (strcmp(option_name, "best-site") == 0){
+      options.best_site_only = true;
+    }
     else if (strcmp(option_name, "verbosity") == 0){
       verbosity = atoi(option_value);
     }
@@ -302,6 +312,11 @@ static FIMO_OPTIONS_T process_fimo_command_line(
     die("The --no-qvalue option cannot be used with the --qv-thresh option");
   }
 
+  // --text and --best-site are incompatible. 
+  if (options.text_only == true && options.best_site_only) {
+      die("The --text option cannot be used with the --best-site option");
+  }
+
   // Turn off q-values if text only.
   if (options.text_only == true) {
     if (options.threshold_type == QV_THRESH) {
@@ -331,17 +346,18 @@ static FIMO_OPTIONS_T process_fimo_command_line(
   options.HTML_FILENAME = "fimo.html";
   options.TSV_FILENAME = "fimo.tsv";
   options.GFF_FILENAME = "fimo.gff";
+  options.BEST_SITE_FILENAME = "best_site.narrowPeak";
   options.XML_FILENAME = "fimo.xml";
   options.CISML_FILENAME = "cisml.xml";
   options.html_path = make_path_to_file(options.output_dirname, options.HTML_FILENAME);
   options.text_path = make_path_to_file(options.output_dirname, options.TSV_FILENAME);
   options.gff_path = make_path_to_file(options.output_dirname, options.GFF_FILENAME);
+  options.best_site_path = make_path_to_file(options.output_dirname, options.BEST_SITE_FILENAME);
   options.xml_path = make_path_to_file(options.output_dirname, options.XML_FILENAME);
   options.cisml_path = make_path_to_file(options.output_dirname, options.CISML_FILENAME);
 
   return options;
-
-}
+} // process_fimo_command_line
 
 /**********************************************
 * Read the motifs from the motif file.
@@ -682,7 +698,6 @@ static long fimo_score_sequence(
       }
     }
 
-
     if (!options.text_only && !fwd_match_recorded) {
       free_matched_element(fwd_match);
     }
@@ -895,6 +910,8 @@ static void fimo_score_each_motif(
     // The pattern is complete.
     if (!options.text_only) {
       set_pattern_is_complete(pattern);
+      // Compute best site per sequence.
+      pattern_find_best_site(pattern);
       // Compute q-values, if requested.
       if (options.compute_qvalues) {
         int num_samples = get_reservoir_num_samples_retained(reservoir);
