@@ -64,7 +64,7 @@ static int hash_keys(
     if (d >= two24) d = 1;		/* d<2**23 insures d*key1<2**31 */
     p += (d * key1[i]) % n;
   }
-  return p % n;
+  return (p>=0 ? p % n : -p % n);
 }
 
 
@@ -405,6 +405,7 @@ HASH_TABLE_ENTRY *hash_lookup_internal(
 {
   /* compute the position in hash table of entry */
   *hash_value = hash_keys(key1, key2, ht->n);
+  assert(*hash_value >= 0);
   /* get collision list for this hash index */
   HASH_TABLE_ENTRY *hte = ht->table[*hash_value];
   while (hte != NULL) {
