@@ -11,6 +11,7 @@ typedef struct {
   Uint idlen; 		// length of sequence ID
   Uchar *seq;		// pointer to sequence data
   Uint seqlen;		// length of sequence data
+  BOOL rc_less;		// sequence has been reverse-complemented
 } Seqptr;
 DECLAREARRAYSTRUCT(Seqptr);
 
@@ -42,7 +43,8 @@ int compare_seqptrs(
   } else if (s1->idlen < s2->idlen) {
     return(-1);
   } else {
-    cmp = strncmp((char *) s1->id, (char *) s2->id, s1->idlen);
+    len = MIN(s1->idlen, s2->idlen);
+    cmp = strncmp((char *) s1->id, (char *) s2->id, len);
     if (cmp > 0) {
       return(+1);
     } else if (cmp < 0) {
@@ -160,11 +162,31 @@ void inline convert_dna_to_rna(
   }
 } // convert_dna_to_rna
 
+//
+// Convert a sequence in place to its reverse-complement.
+//
+void inline convert_to_rc(
+  Seqptr sptr,			// record describing memory mapped sequence
+  Uchar *compalph		// lookup table of complementary letters
+) {
+  Uint i, j;
+  Uchar *seq = sptr.seq;
+  Uint len = sptr.seqlen;
+
+  // Convert sequence to RC. Conversion is done in-place.
+  for (i=0, j=len-1; i<=j; i++, j--) {
+    Uchar a = seq[i];
+    seq[i] = compalph[(Uint) seq[j]];
+    if (i != j) seq[j] = compalph[(Uint) a];
+  }
+} // convert_to_rc
+
 //
 // Convert a sequence in place to its reverse-complement if
 // that is alphabetically smaller.
+// Return True if sequence has been converted to reverse-compelent.
 //
-void inline convert_to_rc_if_smaller(
+BOOL inline convert_to_rc_if_smaller(
   Seqptr sptr,			// record describing memory mapped sequence
   int alen,			// length of alphabet
   Uchar *compalph		// lookup table of complementary letters
@@ -193,6 +215,7 @@ void inline convert_to_rc_if_smaller(
     }
   }
 
+  return(rc_less);
 } // convert_to_rc_if_smaller(
 
 //
@@ -209,7 +232,7 @@ inline void save_legal_sequence(
 ) {
   if (sptr.seqlen >= minlength) {
     if (is_rna) convert_dna_to_rna(sptr);
-    if (use_smaller_strand) convert_to_rc_if_smaller(sptr, alen, compalph);
+    if (use_smaller_strand) sptr.rc_less = convert_to_rc_if_smaller(sptr, alen, compalph);
     PUSHARRAY(seqptrs, Seqptr, 4096, sptr); 
   } else {
     DEBUG_FMT(QUIET_VERBOSE, "# Warning: Ignoring sequence '>%*.*s' because it is too short (%d < %d).\n",
@@ -227,18 +250,21 @@ inline void save_legal_sequence(
 Sint read_fasta_to_multiseqs(
   Multiseq **train_multiseq_ptr,// the training sequences	// OUT
   Multiseq **test_multiseq_ptr,	// the test sequences		// OUT
-  double hofract,		// put this fraction of sequences in test_multiseq; put none if < 0
+  double hofract,		// put this fraction of sequences in test_multiseq; put none if <= 0
   int min_ho_size,		// minimum allowed number of test sequences
   BOOL use_rc,			// average complementary letter frequencies
   BOOL use_smaller_strand,	// ensure results are independent of strand
+  BOOL restore_strand,		// restore original strand after sorting
   BOOL is_rna,			// motifs are RNA, sequences may be DNA so convert
   BOOL allow_ambigs,		// don't convert ambiguous characters to SEPARATOR
   char *filename,		// the FASTA file name to read from
+  DBTYPE_T db_type,		// type of FASTA file: PRIMARY, CONTROL, SHUFFLED_PRIMARY
   ALPH_T *alph,			// MEME-style alphabet
   Uchar *compalph,		// lookup table of letter complements
   Uint minlength,		// minimum allowed sequence length
   Uint maxtotallength		// truncate total length of sequences to this length
 ) {
+  int i, j;
   Uint alen = alph_size_core(alph);     // length of alphabet
   Uchar *input;			// ptr to memory mapped file
   Uint inputlen;		// size of memory mapped file
@@ -253,6 +279,12 @@ Sint read_fasta_to_multiseqs(
   Seqptr sptr;			// current sequence pointer record
   Multiseq *train_multiseq=NULL, *test_multiseq=NULL;
   *train_multiseq_ptr = *test_multiseq_ptr = NULL;
+  char *db_type_name;
+  switch (db_type) {
+    case PRIMARY: db_type_name = "Primary"; break;
+    case CONTROL: db_type_name = "Control"; break;
+    case SHUFFLED_PRIMARY: db_type_name = "Shuffled_primary"; break;
+  }
 
   // Memory map the FASTA file.
   input = CREATEMEMORYMAP (filename, True, &inputlen);
@@ -331,9 +363,16 @@ Sint read_fasta_to_multiseqs(
   // Sort the index alphabetically by content.
   SORTARRAY(&seqptrs, Seqptr, compare_seqptrs);
 
+  // Un-complement any sequences that were complemented for sorting.
+  if (restore_strand && use_smaller_strand) {
+    for (i=0; i<nseqs; i++) {
+      sptr = *(PEEKARRAY(&seqptrs, i, Seqptr));
+      if (sptr.rc_less) convert_to_rc(sptr, compalph);
+    }
+  }
+
   // Create a permuted list of integers from 0 to nseqs-1.
   int *permuted_indices = (int *) malloc(nseqs * sizeof(int));
-  int i, j;
   for (i=0; i<nseqs; i++) permuted_indices[i] = i;
   for (i=nseqs-1; i>0; i--) {
     j = drand_mt() * (i + 1);
@@ -343,7 +382,7 @@ Sint read_fasta_to_multiseqs(
   // Determine the length of the training and test multiseq arrays.
   Uint train_len = 0;	// total length of training sequences
   Uint test_len = 0;	// total length of length sequences
-  int ntest = MAX(0, (hofract * nseqs));		// 0 if hofract <= 0
+  int ntest = MAX(0, (hofract * nseqs));		// 0 if hofract == 0
   if (hofract > 0 && ntest < min_ho_size) ntest = 0;	// prevent too small test set
   int ntrain = nseqs - ntest;
 
@@ -402,7 +441,7 @@ Sint read_fasta_to_multiseqs(
   double *freqs = (double *) calloc(alen, sizeof(double));
   Uint nletters = 0;
   int n_seqs = 0;
-  char *db_type = "primary";
+  char *seq_type = "train";
   for (i=i_seq=0; i<nseqs; i++, i_seq++) {
     // The first ntrain (shuffled order) sequences are training; rest are test.
     Multiseq *multiseq = (i < ntrain) ? train_multiseq : test_multiseq;
@@ -412,7 +451,7 @@ Sint read_fasta_to_multiseqs(
       i_seq = 0;
       totallength = 0;
       n_seqs = 0;
-      if (i==ntrain) db_type = "control";
+      if (i==ntrain) seq_type = "test";
     }
     sptr = *(PEEKARRAY(&seqptrs, permuted_indices[i], Seqptr));
     // Skip sequence if it would cause total length to be exceeded.
@@ -420,11 +459,11 @@ Sint read_fasta_to_multiseqs(
       DEBUG_FMT(QUIET_VERBOSE, 
         "# Warning: Skipping %s sequence '>%*.*s' of length %d because\n"
         "#          it causes total database length to be exceeded (%d > %d).\n",
-        db_type, sptr.idlen, sptr.idlen, sptr.id, sptr.seqlen, totallength + sptr.seqlen, maxlength);
+        db_type_name, sptr.idlen, sptr.idlen, sptr.id, sptr.seqlen, totallength + sptr.seqlen, maxlength);
       continue;
-     } else {
+    } else {
       n_seqs++;
-     }
+    }
     // Update the number of sequences stored and their total length.
     multiseq->numofsequences++;
     totallength += sptr.seqlen;
