@@ -2,6 +2,9 @@
 #define INPUTMULTISEQ_H
 #include "st_multidef.h"
 
+// Input file type.
+typedef enum {PRIMARY, CONTROL, SHUFFLED_PRIMARY} DBTYPE_T;
+
 //
 //  Read a FASTA file into one or two multiseq objects
 //
@@ -12,9 +15,11 @@ Sint read_fasta_to_multiseqs(
   int min_ho_size,              // minimum allowed number of test sequences
   BOOL use_rc,                  // average complementary letter frequencies
   BOOL use_smaller_strand,      // ensure results are independent of strand
+  BOOL restore_strand,          // restore original strand after sorting
   BOOL is_rna,                  // motifs are RNA, sequences may be DNA so convert
   BOOL allow_ambigs,            // don't convert ambiguous characters to SEPARATOR
   char *filename,               // the FASTA file name to read from
+  DBTYPE_T db_type,             // type of FASTA file: PRIMARY, CONTROL, SHUFFLED_PRIMARY
   ALPH_T *alph,                 // MEME-style alphabet
   Uchar *compalph,              // lookup table of letter complements
   Uint minlength,               // minimum allowed sequence length
