@@ -76,7 +76,6 @@
  // error flag 
 bool errored = false;
  // printing 
-VERBOSE_T verbosity = QUIET_VERBOSE;
 
 const char *program_name = "mast"; // the program name 
 static char *default_out_dir = "mast_out"; // default name of output 
@@ -2090,6 +2089,7 @@ int main(int argc, char *argv[])
   int nbad; // number of bad (correlated) motifs 
   double **pv = NULL; // p-value tables for each motif 
   ARRAY_T *bgfreqs, *motif_bg; // background letter probability distribution 
+  verbosity = QUIET_VERBOSE;
 
   (void) mytime(0); // initialize elapsed time
 
