@@ -102,7 +102,7 @@ static void usage(char *format, ...) {
      "  --max-total-width <value>     Maximum combined width of all motifs; (default: no limit).\n"
      "  --hardmask                    Nucleotides in lower case will be converted to 'N' \n"
      "                                   preventing them from being considered in motif matches.\n"
-     "  --parse-genomic-coord         Parse genomic coordinates found in sequence headers.\n"
+     "  --no-pgc                      Do not parse genomic coordinates found in sequence headers.\n"
      "  --bfile <file>                File containing n-order Markov background model.\n"
      "  --psp <value>                 File containing position specific priors; (default: none).\n"
      "  --prior-dist <value>          File containing distribution of position specific priors.\n"
@@ -171,7 +171,7 @@ static void process_command_line(
   options->motif_format = MEME_FORMAT;
   options->max_total_width = -1;
   options->hard_mask = false;
-  options->parse_genomic_coord = false;
+  options->parse_genomic_coord = true;
   options->bg_filename = NULL;
   options->psp_filename = NULL;
   options->alpha = DEFAULT_ALPHA;
@@ -195,6 +195,7 @@ static void process_command_line(
     {"max-total-width", REQUIRED_VALUE},
     {"hardmask", NO_VALUE},
     {"parse-genomic-coord", NO_VALUE},
+    {"no-pgc", NO_VALUE},
     {"bfile", REQUIRED_VALUE},
     {"bgfile", REQUIRED_VALUE},
     {"psp", REQUIRED_VALUE},
@@ -291,7 +292,9 @@ static void process_command_line(
         die("q-value threshold must be between 0.0 and 1.0!");
       }
     } else if (strcmp(option_name, "parse-genomic-coord") == 0) {
-      options->parse_genomic_coord = true;
+      options->parse_genomic_coord = true;			// backwards compatibility
+    } else if (strcmp(option_name, "no-pgc") == 0) {
+      options->parse_genomic_coord = false;
     } else if (strcmp(option_name, "psp") == 0) {
       options->psp_filename = option_value;
     } else if (strcmp(option_name, "prior-dist") == 0) {
@@ -583,9 +586,9 @@ static void build_hmm_from_motifs(
 static double purge_match_heap(HEAP *match_heap) {
 
   // How many matches do we need to delete?
-fprintf(stderr, "Size of heap: %d\n", get_num_nodes(match_heap));
   int num_matches_to_delete = get_num_nodes(match_heap) / 2;
   if (verbosity >= NORMAL_VERBOSE) {
+    fprintf(stderr, "Size of heap: %d\n", get_num_nodes(match_heap));
     fprintf(
       stderr,
       "%d matches stored. Need to delete at least %d matches.\n",
@@ -1452,7 +1455,7 @@ EVD_SET mcast_generate_synth_seq(
       fprintf(
         stderr, 
         "\nGiving up generating random sequences: match probability too low!\n"
-        "Try increasing the value of --motif-pthresh.\n\n"
+        "Try increasing the value of --motif-pthresh (the p-value threshold for scoring motif hits).\n\n"
       );
       break;
     }
@@ -1709,12 +1712,16 @@ static void mcast(
   double end_user_time = myclock();
   double duration = (end_user_time - start_user_time) / 1E6;
   total_user_time += duration;
-  fprintf(stderr, "User time for computation: %g seconds\n", duration);
+  if (verbosity >= NORMAL_VERBOSE) {
+    fprintf(stderr, "User time for computation: %g seconds\n", duration);
+  }
   start_user_time = end_user_time;
   double end_sys_time = mysysclock();
   duration = (end_sys_time - start_sys_time) / 1E6;
   total_sys_time += duration;
-  fprintf(stderr, "System time for computation: %g seconds\n", duration);
+  if (verbosity >= NORMAL_VERBOSE) {
+    fprintf(stderr, "System time for computation: %g seconds\n", duration);
+  }
   start_sys_time = end_sys_time;
 
   mcast_print_results(
@@ -1738,15 +1745,19 @@ static void mcast(
   end_user_time = myclock();
   duration = (end_user_time - start_user_time) / 1E6;
   total_user_time += duration;
-  fprintf(stderr, "User time for output: %g seconds\n", duration);
+  if (verbosity >= NORMAL_VERBOSE) {
+    fprintf(stderr, "User time for output: %g seconds\n", duration);
+  }
   start_user_time = end_user_time;
   end_sys_time = mysysclock();
   duration = (end_sys_time - start_sys_time) / 1E6;
   total_sys_time += duration;
-  fprintf(stderr, "System time for output: %g seconds\n", duration);
   start_sys_time = end_sys_time;
-  fprintf(stderr, "Total user time: %g seconds\n", total_user_time);
-  fprintf(stderr, "Total system time: %g seconds\n", total_sys_time);
+  if (verbosity >= NORMAL_VERBOSE) {
+    fprintf(stderr, "System time for output: %g seconds\n", duration);
+    fprintf(stderr, "Total user time: %g seconds\n", total_user_time);
+    fprintf(stderr, "Total system time: %g seconds\n", total_sys_time);
+  }
 
   // Tie up loose ends.
   
