@@ -126,25 +126,26 @@ int meme_main(
 )
 {
   int i, imotif;
-  DATASET *dataset; // the dataset 
-  DATASET *neg_dataset; // the dataset of negative examples 
-  MODEL *model; // the model 
-  MODEL *neg_model; // the model of negatives 
-  MODEL *best_model; // the best model found (so far) 
-  CANDIDATE *candidates = NULL; // list of candidate models 
-  MOTIF_SUMMARY *motif_summaries = NULL; // properties of final motifs 
-  int n_starts = 0; // number of starting points 
-  int nmotifs; // number of to find 
-  double stop_time=0, m1time=0; // time when stopped, for motif 1 (secs) 
-  int last_w; // keep track of change for PSP 
+  DATASET *dataset;				// the dataset 
+  DATASET *neg_dataset;				// the dataset of negative examples 
+  MODEL *model;					// the model 
+  MODEL *neg_model;				// the model of negatives 
+  MODEL *best_model;				// the best model found (so far) 
+  CANDIDATE *candidates = NULL;			// list of candidate models 
+  MOTIF_SUMMARY *motif_summaries = NULL; 	// properties of final motifs 
+  int min_w, max_w;				// motif width limits
+  int n_starts = 0;				// number of starting points 
+  int nmotifs;					// number of to find 
+  double stop_time=0, m1time=0;			// time when stopped, for motif 1 (secs) 
+  int last_w;					// keep track of change for PSP 
   bool output_error = false;
+  bool is_mpi = false;
 
   char * text_filename = "meme.txt";
   char * xml_filename = "meme.xml";
   char * html_filename = "meme.html";
-  FILE *text_output = NULL; // File for text output 
+  FILE *text_output = NULL;			// File for text output 
 
-  int min_w, max_w;
 
 #ifdef PARALLEL
   int start_start, incr;
@@ -160,6 +161,8 @@ int meme_main(
 #endif 
 #endif // PARALLEL 
 
+  if (strcmp(argv[argc-1], "-mpi") == 0) is_mpi = true;
+
 #ifdef debug_ieee
   ieee_handler_setup("common");
 #endif
@@ -189,7 +192,7 @@ int meme_main(
   // print the command line 
   if (VERBOSE) {
     argv[0] = "meme";
-    for (i=0; i<argc; i++) fprintf(text_output, "%s ", argv[i]);
+    for (i=0; i<(is_mpi ? argc-1 : argc); i++) fprintf(text_output, "%s ", argv[i]);
     fprintf(text_output, "\n\n");
     fflush(text_output);
   }
