@@ -1,3 +1,7 @@
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include <getopt.h>
 #include <stdarg.h>
 #include <stdbool.h>
@@ -12,8 +16,6 @@
 
 #define PAGEWIDTH 80
 
-VERBOSE_T verbosity = QUIET_VERBOSE;
-
 /**************************************************************************
  * Holds the program options.
  **************************************************************************/
