@@ -155,7 +155,7 @@ void copy_model(
 {
   int i;
 
-  m2->all_widths = m1->all_widths; // FIXME jj - this was left uncopied
+  m2->all_widths = m1->all_widths; 
   m2->mtype = m1->mtype;
   m2->min_w = m1->min_w;
   m2->max_w = m1->max_w;
