@@ -142,9 +142,10 @@ void balance_loop1(SAMPLE **samples, int n_samples)
 	     inode, mpNodes());
      }
   */
-  if (iseq != n_samples)
+  if (iseq != n_samples) {
     fprintf(stderr, "Warning! iseq(%d) != n_samples(%d)\n",
 	    iseq, n_samples);
+  }
 }
 
 /**********************************************************************
@@ -270,9 +271,13 @@ void theta_packer(
  * Ties are resolved in favor of:
  *   1) lowest start width
  *   2) lowest start nsites
+ *   3) node ID
  * in Classic mode.  Otherwise, we first break ties using
  *   1) model width
  *   2) model LLR
+ *   3) model start width
+ *   4) model start nsites
+ *   5) node ID
  * and then the previous two rules are applied.
  * This function is used in the reduction across models.
  *
@@ -292,6 +297,8 @@ void max_packets(void *f_data, void *f_result, int *f_length,
   double d_w = ((REDUCE_PACKET *)f_data)->width;
   double r_llr = ((REDUCE_PACKET *)f_result)->llr;
   double d_llr = ((REDUCE_PACKET *)f_data)->llr;
+  double r_ID = ((REDUCE_PACKET *)f_result)->ID;
+  double d_ID = ((REDUCE_PACKET *)f_data)->ID;
   bool classic = ((REDUCE_PACKET *)f_result)->classic == 1;
 
   /* Compare the data in the two packets. */
@@ -307,12 +314,14 @@ void max_packets(void *f_data, void *f_result, int *f_length,
 	|| (d_sig == r_sig && d_w == r_w && d_llr > r_llr)
 	|| (d_sig == r_sig && d_w == r_w && d_llr == r_llr && d_sw < r_sw)
 	|| (d_sig == r_sig && d_w == r_w && d_llr == r_llr && d_sw == r_sw && d_sn < r_sn)
+	|| (d_sig == r_sig && d_w == r_w && d_llr == r_llr && d_sw == r_sw && d_sn == r_sn && d_ID < r_ID)
       )
     )
     || (classic				// Classic
       && (				// and data better
 	(d_sig == r_sig && d_sw < r_sw) 
-	|| (d_sig == r_sig && d_sw == r_sw && d_sn < r_sn )
+	|| (d_sig == r_sig && d_sw == r_sw && d_sn < r_sn)
+	|| (d_sig == r_sig && d_sw == r_sw && d_sn == r_sn && d_ID < r_ID)
       )
     )
   ) {
@@ -383,6 +392,7 @@ void reduce_across_models(
   if (init == 0) {
     init = 1;
     MPI_Type_contiguous(8, MPI_DOUBLE, &reduction_packet_type);
+    REDUCTION_PACKET_TYPE_PTR = &reduction_packet_type;
     MPI_Type_commit(&reduction_packet_type);
     MPI_Op_create(max_packets, true, &max_packets_op);
   }
@@ -391,8 +401,10 @@ void reduce_across_models(
   MPI_Allreduce((void *)&a_packet, (void *)&best_packet, 1,
 		reduction_packet_type, max_packets_op, MPI_COMM_WORLD);
 
-  /*fprintf(stdout, "%d: Winner=%d score=%g\n", mpMyID(), (int)best_packet.ID,
-	  best_packet.sig);*/
+#ifdef DEBUG_PARALLEL
+  fprintf(stdout, "\nnode %d: Winner=%d score=%g\n", mpMyID(), (int)best_packet.ID,
+	  best_packet.sig);
+#endif
 
   /* The losers store their theta matrix and maxima pointers so they don't get
      overwritten in the upcoming broadcast. */
