@@ -18,6 +18,11 @@
 #ifndef MESSAGE_H
 #  define MESSAGE_H
 
+#ifdef PARALLEL
+#include <mpi.h>
+  DEXTERN(MPI_Datatype *, REDUCTION_PACKET_TYPE_PTR, NULL);
+#endif
+
 #include "meme.h" /* We need the defn of S_POINT. */
 /***************************************************************************/
 /* Type declarations */
