@@ -40,15 +40,6 @@
 #include "read-mhmm.h"   // HMM input/output. 
 #include "utils.h"       // Generic utilities. 
 
-// Number of matches required before we generate synthetic scores if
-// -synth given.
-// If fewer matches than this are found, we assume that EM (or fitevd)
-// will be unable to accurately estimate the distribution.
-// The current value of this was guessed at by assuming that:
-//   1) estimation works well if 10:1 ratio of negative:positive matches
-//   2) rarely will there be more than 1000 true positives
-#define MIN_MATCHES 10000
-
 // Global variables
 int       dp_rows = 0;           // Size of the DP matrix.
 int       dp_cols = 0; 
@@ -250,7 +241,7 @@ void print_mhmmscan_xml_file(
   }
   else {
     // Not enough scores to produce fit
-    fputs("<status>To few scores to estimate fit</status>\n", out);
+    fputs("<status>Too few scores to estimate fit</status>\n", out);
     fputs("<mu1>NaN</mu1>\n", out);
     fputs("<mu2>NaN</mu2>\n", out);
     fputs("<sigma2>NaN</sigma2>\n", out);
@@ -406,7 +397,6 @@ static SCORE_SET *read_and_score(
         get_int_sequence(sequence),
         get_seq_length(sequence),
         NULL, /* Array of priors (no priors) */
-        0, /* Count of priors (no priors) */
         1.0, /* Alpha parameter for calculating log-ratio priors (no priors) */
         log_hmm,
         &motif_score_matrix
@@ -1071,8 +1061,6 @@ void mhmmscan(
 
 #ifdef MAIN
 
-VERBOSE_T verbosity = NORMAL_VERBOSE;
-
 #include "simple-getopt.h"  // Cmd line processing
 
 /***********************************************************************
@@ -1172,7 +1160,7 @@ void process_command_line(
         break;
       } else if (c < 0) {
         simple_getopterror(&message);
-        die("Error process command line options (%s)\n", message);
+        die("Error process command line options: %s\n", message);
       }
 
       if (strcmp(option_name, "allow-weak-motifs") == 0) {
@@ -1241,7 +1229,7 @@ void process_command_line(
       } else if (strcmp(option_name, "text") == 0) {
         options->text_only = true;
       } else if (strcmp(option_name, "verbosity") == 0) {
-        verbosity = (VERBOSE_T)atoi(option_value);
+        verbosity = atoi(option_value);
       } else if (strcmp(option_name, "width") == 0) {
         options->output_width = atoi(option_value);
       } else if (strcmp(option_name, "zselo") == 0) {
