@@ -2,7 +2,9 @@
  * MoMo Portal
  ********************************************************************/
 
+#ifdef MAIN
 #define DEFINE_GLOBALS
+#endif
 
 #include <assert.h>
 #include <stdio.h>
@@ -33,9 +35,6 @@ char* program_name = "momo";
 /* local variables */
 #define DATA_HASH_SIZE 100003
 
-// default verbosity
-VERBOSE_T verbosity = NORMAL_VERBOSE;
-
 /***********************************************************************
  Initialize options processing
  ***********************************************************************/
@@ -75,7 +74,7 @@ static MOMO_OPTIONS_T init_options(ALGORITHM_T algorithm) {
   options.hash_fasta = false;
   options.hash_fasta_width = 0;
 
-  options.paper = "Alice Cheng, Charles Grant, Timothy L. Bailey and William Noble, \"MoMo: Discovery of statistically signficant post-translational modification motifs\", Bioinformatics, 2018.";
+  options.paper = "Alice Cheng, Charles Grant, Timothy L. Bailey and William Noble, \"MoMo: Discovery of statistically signficant post-translational modification motifs\", Bioinformatics, 35(16):2774-2782, 2018.";
   options.link = "https://doi.org/10.1093/bioinformatics/bty1058";
 
   // Motif-X options
@@ -376,7 +375,7 @@ static MOMO_OPTIONS_T process_momo_command_line(
     }
     else if (c < 0) {
       (void) simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      die("Error processing command line options: %s\n", message);
     }
     else if (strcmp(option_name, "eliminate-repeats") == 0) {
       options.eliminate_repeat_width = atoi(option_value);
