@@ -259,7 +259,7 @@ void psp_renormalize(
 )
 {
   // check for improper/unneccesary call
-  assert(mtype == Oops || mtype == Zoops);	// PM FIXME need to add Tcm
+  assert(mtype == Oops || mtype == Zoops);	// PM TODO need to add Tcm
 
   if (dataset->log_psp_w == new_w) return;	// nothing needed
 
@@ -302,7 +302,7 @@ void psp_renormalize(
           if (revcomp) log_psp[-j] = psp_original[-j];
         }
         // set remaining legal sites priors to zero
-        for (j=old_m; j<=new_m; j++) {
+        for (j=old_m+1; j<=new_m; j++) {
           log_psp[j] = 0;
           if (revcomp) log_psp[-j] = 0;
         }
@@ -485,10 +485,12 @@ static bool read_psp(
     number = numberstring(psp_file, false, name, true); // ignore anything after W
 
     // Check that W is a number and is legal (>0)
-    if (number==NULL || sscanf(number, "%d", w) != 1 || *w <= 0) {
-      fprintf(stderr, "\nIllegal value for W: `%s' in PSP record with ID: `%s'.\n", 
-        number, name);
-      if (number != NULL) myfree(number);
+    if (number==NULL) {
+      fprintf(stderr, "\nIllegal value for W: `NULL' in PSP record with ID: `%s'.\n", name);
+      return(true);			// bad W
+    } else if (sscanf(number, "%d", w) != 1 || *w <= 0) {
+      fprintf(stderr, "\nIllegal value for W: `%s' in PSP record with ID: `%s'.\n", number, name);
+      myfree(number);
       return(true);			// bad W
     }
   }
