@@ -815,27 +815,26 @@ void set_up_pssms_and_pvalues (
  *
  **************************************************************************/
 static void compute_motif_scores (
-  bool use_pvalues,   // Returns scores as p-values, not log-odds.
-  double    p_threshold,   // Divide p-values by this.
-  int       i_state,       // Index of the start state of the motif.
-  MHMM_T*   the_hmm,       // The HMM, in log form.
-  int*      int_sequence,  // The sequence, in integer format.
-  size_t    seq_length,    // The length of the sequence.
-  double *priors, // Array of priors
-  size_t num_priors, // Number of priors
-  double alpha, // Alpha parameter for calculating prior log odds
-  ARRAY_T*  score_array    // The scores (pre-allocated array).
+  bool use_pvalues,	// Returns scores as p-values, not log-odds.
+  double p_threshold,   // Divide p-values by this.
+  int i_state, 		// Index of the start state of the motif.
+  MHMM_T* the_hmm, 	// The HMM, in log form.
+  int* int_sequence,	// The sequence, in integer format.
+  size_t seq_length,	// The length of the sequence.
+  double *priors,	// Array of priors
+  double alpha,		// Alpha parameter for calculating prior log odds
+  ARRAY_T* score_array	// The scores (pre-allocated array).
 )
 {
   int j, k;
   size_t i;
-  size_t length = seq_length;                              // Length of sequence.
+  size_t length = seq_length;			// Length of sequence.
   PSSM_T *pssm = the_hmm->states[i_state].pssm;
-  MATRIX_T* pssm_matrix = pssm->matrix;        // PSSM for motif.
-  int w = the_hmm->states[i_state].w_motif;             // The motif width.
-  ARRAY_T* pv = pssm->pv;      // Lookup table for p-values.
-  double min_sig_score = the_hmm->states[i_state].min_sig_score; // Smallest significant score.
-  double off = use_pvalues? my_log2(p_threshold) : 0;   // Convert p_threshold to bits.
+  MATRIX_T* pssm_matrix = pssm->matrix;		// PSSM for motif.
+  int w = the_hmm->states[i_state].w_motif;	// The motif width.
+  ARRAY_T* pv = pssm->pv;			// Lookup table for p-values.
+  double min_sig_score = the_hmm->states[i_state].min_sig_score;	// Smallest significant score.
+  double off = use_pvalues? my_log2(p_threshold) : 0;	// Convert p_threshold to bits.
 
   //
   // Score motif at each position it fits.
@@ -844,7 +843,7 @@ static void compute_motif_scores (
   // Last position in sequence is not part of sequence.
   //
   set_array_item(0, 0, score_array);            // Position 0 not part of sequence.
-  for (i=1; length>w && i<length-w; i++) {  	// motif start (size_t is unsignd!)
+  for (i=1; length>w && i<length-w; i++) {  	// motif start (size_t is unsigned!)
     int* seq = int_sequence+i;                  // Letter at current position.
     double score = 0;                           // Score for match.
     // i : position in original sequence.
@@ -855,8 +854,8 @@ static void compute_motif_scores (
       score += get_matrix_cell(k, *seq, pssm_matrix);
     }
     if (priors != NULL) {
-      // The sequence has 1 char of padding at begining and end
-      // the priors don't
+      // The sequence has 1 char of padding at beginning and end;
+      // the priors don't.
       double prior = alpha * priors[i - 1];
       if (!isnan(prior)) {
         double log_prior_odds_score = my_log2(prior / (1.0L - prior));
@@ -884,14 +883,13 @@ static void compute_motif_scores (
  * grow if necessary.
  **************************************************************************/
 void compute_motif_score_matrix(
-  bool  use_pvalues,       // Returns scores as p-values, not log-odds.
-  double     p_threshold,       // Divide p-values by this.
-  int*       int_sequence,      // Sequence as integer indices into alphabet.
-  size_t     seq_length,        // Length of sequence.
-  double *priors, // Priors for sequence
-  size_t num_priors, // Number of priors
-  double alpha, // Alpha parameter for calculating prior log odds
-  MHMM_T*    the_hmm,           // The hmm.
+  bool use_pvalues,		// Returns scores as p-values, not log-odds.
+  double p_threshold,		// Divide p-values by this.
+  int* int_sequence,		// Sequence as integer indices into alphabet.
+  size_t seq_length,		// Length of sequence.
+  double *priors,		// Priors for sequence
+  double alpha,			// Alpha parameter for calculating prior log odds
+  MHMM_T* the_hmm,		// The hmm.
   MATRIX_T** motif_score_matrix
 )
 {
@@ -923,17 +921,17 @@ void compute_motif_score_matrix(
     if (this_state->type == START_MOTIF_STATE) {
 
       // Compute the scores for this motif at all sequence positions.
-      compute_motif_scores(use_pvalues,
-                           p_threshold,
-                           i_state,
-                           the_hmm,
-                           hashed_sequence,
-                           seq_length,
-         priors,
-         num_priors,
-         alpha,
-                           get_matrix_row(this_state->i_motif,
-                                          *motif_score_matrix));
+      compute_motif_scores(
+        use_pvalues,
+	p_threshold,
+	i_state,
+	the_hmm,
+	hashed_sequence,
+	seq_length,
+        priors,
+        alpha,
+        get_matrix_row(this_state->i_motif, *motif_score_matrix)
+      );
     }
   }
 
