@@ -32,8 +32,6 @@
 #include "spamo-scan.h"
 #include "red-black-tree.h"
 #include "utils.h"
-#include "xml-out.h"
-#include "xml-util.h"
 
 // default file names
 #define TEMPLATE_FILENAME "spamo_template.html"
@@ -42,74 +40,51 @@
 #define TEXT_FILENAME "spamo.tsv"
 
 typedef struct SPAMO_OPTIONS {
-  // pseudo random number generator seed
-  unsigned int prng_seed;
-  // program start time
-  time_t start;
-  // output directory
-  char *outdir;
-  // should existing output be overwritten?
-  bool clobber;
-  // should EPS files be created?
-  bool create_eps;
-  // should PNG files be created?
-  bool create_png;
-  // should images be made for redundant motifs?
-  bool create_for_redundant;
-  // should the matches be output for motifs declared significant?
-  bool dump_seqs;
-  // if the same file is specified for the primary motif and the secondary 
-  // motif should the primary be included?
-  bool keep_primary;
-  // pseudocount added to motifs loaded
-  double pseudocount;
-  // motif background for distributing pseudocounts and creating pssms
-  char *bg_filename;
-  // maximum distance from primary motif to secondary motif and minimum 
-  // distance to edge for primary motif.
-  int margin;
-  // bin size for calculations (1 is highly recommended)
-  int bin;
-  // range for significance testing
-  int test_range;
-  // bit threshold for trimming motifs
-  double trim_bit_threshold;
-  // fraction of bases needed to be equal before they are considered redundant
-  double sequence_similarity;
-  // minimum score to be accepted by the scanning code
-  double score_threshold;
-  // use only the best match to the secondary motif if true
-  bool use_best_secondary;
-  // pvalue threshold for spacings to be considered significant.
-  double pvalue_cutoff;
-  // Evalue threshold for reporting secondary motifs
-  double motif_evalue_cutoff;
-  // the minimum overlap in the best site
-  int overlap;
-  // the fraction of the intersection as relative to the smaller set
-  double joint;
-  // name of primary motif
-  RBTREE_T *primary_name;
-  // index of primary motif
-  RBTREE_T *primary_index;
-  // wildcard patterns for motif names to include
-  ARRAYLST_T *include_patterns;
-  // wildcard patterns for motif names to exclude
-  ARRAYLST_T *exclude_patterns;
-  // the sequences to be scanned
-  char *sequences_file;
-  // the primary motif file
-  char *primary_file;
-  // the files for the secondary motifs
-  ARRAYLST_T *secondary_files;
-  // should the alphabets of the secondary motifs be converted?
-  bool xalph;
-  // only output the spamo.tsv file not .html or .xml
-  bool text_only;
-  // Only dump sequences significant matches.
-  bool dump_sig_only;
-  // Control sampling for speedup of sequence similarity check.
-  double odds;
+  // Required inputs
+  char *sequences_file;		// the sequences to be scanned
+  char *primary_file;		// the primary motif file
+  ARRAYLST_T *secondary_files;	// the files for the secondary motifs
+
+  // Output
+  char *outdir; 		// output directory
+  bool clobber;			// should existing output be overwritten?
+  bool text_only; 		// only output the spamo.tsv file not .html
+  bool create_eps;		// should EPS files be created?
+  bool create_png;		// should PNG files be created?
+  bool dump_seqs;		// should the matches be output for motifs declared significant?
+  bool dump_sig_only;		// Only dump sequences significant matches.
+
+  // Scanning
+  bool norc;			// should reverse-complement strands be scanned?
+  double score_threshold;	// minimum score to be accepted by the scanning code
+  int margin;			// maximum distance from primary motif to secondary motif and minimum 
+				// distance to edge for primary motif.
+  int test_range;		// range for significance testing
+  int bin;			// bin size for calculations (1 is highly recommended)
+  bool use_best_secondary;	// use only the best match to the secondary motif if true
+  unsigned int prng_seed;	// pseudo random number generator seed
+  time_t start;			// program start time
+  double sequence_similarity;	// fraction of bases needed to be equal before they are considered redundant
+  double odds;			// Control sampling for speedup of sequence similarity check.
+
+  // Summarizing
+  double pvalue_cutoff;		// pvalue threshold for spacings to be considered significant.
+  double motif_evalue_cutoff;	// Evalue threshold for reporting secondary motifs
+  int overlap;			// the minimum overlap in the best site
+  double joint;			// the fraction of the intersection as relative to the smaller set
+
+  // Motif loading
+  double pseudocount;		// pseudocount added to motifs loaded
+  char *bg_filename;		// motif background for distributing pseudocounts and creating pssms
+  bool xalph;			// should the alphabets of the secondary motifs be converted?
+  double trim_bit_threshold;	// bit threshold for trimming motifs
+  RBTREE_T *primary_name;	// name of primary motif
+  RBTREE_T *primary_index;	// index of primary motif
+  bool keep_primary;		// if the same file is specified for the primary motif and the secondary 
+  				// motif should the primary be included?
+  ARRAYLST_T *include_patterns; // wildcard patterns for motif names to include
+  ARRAYLST_T *exclude_patterns; // wildcard patterns for motif names to exclude
+
 } SPAMO_OPTIONS_T;
 
 /**************************************************************************
@@ -137,9 +112,21 @@ static void usage(SPAMO_OPTIONS_T *options, char *format, ...) {
     "    spamo [options] <sequences> <primary motif> <secondary motifs>+\n"
     "Options:\n"
     "    -o <directory>   create the directory and write output files in it;\n"
-    "                       not compatible with -oc\n"
+    "                       not compatible with -oc; default: -oc spamo_out\n"
     "    -oc <directory>  create the directory but if it already exists allow\n"
-    "                       overwriting the contents; default: spamo_out\n"
+    "                       overwriting the contents; default: -oc spamo_out\n"
+    "    -text            output the TSV file only (no HTML)\n"
+    "    -eps             output histograms in eps format; usable with -png\n"
+    "    -png             output histograms in png format; usable with -eps\n"
+    "    -dumpseqs        dump matching trimmed sequences to TSV output files;\n"
+    "                       matches are initially in sequence name order;\n"
+    "                       see documentation for column descriptions\n"
+    "    -dumpsigs        same as above except only secondary matches in\n"
+    "                       in significant bins are dumped\n"
+    "                       matches are initially in sequence name order;\n"
+    "                       see documentation for column descriptions\n"
+    "    -norc            do not scan the reverse-complement strand for sites;\n"
+    "                       default: both strands are scanned for sites\n"
     "    -minscore <valu> the minimum score (bits) to accept as a motif match;\n"
     "                       default: 7\n"
     "                       Note: if <valu> is in the range [-1, 0), then the\n"
@@ -147,9 +134,9 @@ static void usage(SPAMO_OPTIONS_T *options, char *format, ...) {
     "    -margin <size>   edge margin excluded for primary motif matches and\n"
     "                       the maximum distance from the primary motif to the\n"
     "                       secondary motif; default: 150\n"
+    "    -range <size>    the distance range from the primary to the secondary\n"
+    "                       to include in significance tests; default: 150\n"
     "    -bin <size>      size of bins used for output; default: 1\n"
-    "    -range <size>    the range from the primary to include in significance\n"
-    "                       tests; default: 150\n"
     "    -usebestsec      use only the best match of the secondary motif;\n"
     "                       default: count all secondary matches above the\n"
     "                       score match threshold in the margins around the\n"
@@ -163,6 +150,11 @@ static void usage(SPAMO_OPTIONS_T *options, char *format, ...) {
     "                       redundant sequences to be missed; set <odds>\n"
     "                       to 0 to do full-length check;\n"
     "                       default: 20\n"
+    "    -numgen <seed>   specify the random seed for initializing the pseudo-\n"
+    "                       random number generator used in breaking ties;\n"
+    "                       the seed is included in the output so experiments\n"
+    "                       can be repeated; special value 'time' seeds to the\n"
+    "                       system clock; default: 1\n"
     "    -cutoff <pvalue> cutoff for spacings to be considered significant;\n"
     "                       default: 0.05\n"
     "    -evalue <evalue> minimum E-value for printing secondary motifs;\n"
@@ -188,11 +180,6 @@ static void usage(SPAMO_OPTIONS_T *options, char *format, ...) {
     "                       content less than bits will not be used in\n"
     "                       scanning\n"
     "                       default: 0.25\n"
-    "    -numgen <seed>   specify the random seed for initializing the pseudo-\n"
-    "                       random number generator used in breaking ties;\n"
-    "                       the seed is included in the output so experiments\n"
-    "                       can be repeated; special value 'time' seeds to the\n"
-    "                       system clock; default: 1\n"
     "    -primary <name>  name of motif to select as the primary motif;\n"
     "                       overrides -primaryi\n"
     "    -primaryi <num>  index of motif to select as the primary motif\n"
@@ -209,20 +196,10 @@ static void usage(SPAMO_OPTIONS_T *options, char *format, ...) {
     "                       repeated; default: all motifs are used\n"
     "    -exc <pattern>   name pattern to exclude as secondary motif; may be\n"
     "                       repeated; default: all motifs are used\n"
-    "    -text            output text file only (no HTML or XML)\n"
-    "    -eps             output histograms in eps format; usable with -png\n"
-    "    -png             output histograms in png format; usable with -eps\n"
-    "    -dumpseqs        dump matching trimmed sequences to output files;\n"
-    "                       matches are initially in sequence name order;\n"
-    "                       see documentation for column descriptions\n"
-    "    -dumpsigs        same as above except only secondary matches in\n"
-    "                       in significant bins are dumped\n"
-    "                       matches are initially in sequence name order;\n"
-    "                       see documentation for column descriptions\n"
     "    -help            print this usage message\n"
+    "    -version         print the version and exit\n"
     "    -verbosity <v>   set the verbosity of the output: 1 (quiet) - 5 (dump);\n"
     "                       default: 2 (normal)\n"
-    "    -version         print the version and exit\n"
     "Description:\n"
     "    SpaMo looks for significant spacings between a primary motif and\n"
     "    each motif in a library of secondary motifs.\n";
@@ -255,6 +232,7 @@ static void usage(SPAMO_OPTIONS_T *options, char *format, ...) {
 #define SHOW_VERSION 510
 #define ODDS_RATIO 511
 #define TEXT_ONLY 512
+#define NORC 513
 
 /**************************************************************************
  * Checks the consistency of arguments and loads them into the options 
@@ -269,74 +247,77 @@ static char *process_arguments(int argc, char **argv, SPAMO_OPTIONS_T *options)
   struct option spamo_options[] = {
     {"o", required_argument, NULL, OUTPUT},
     {"oc", required_argument, NULL, CLOBBER},
+    {"text", no_argument, NULL, TEXT_ONLY},
     {"eps", no_argument, NULL, CREATE_EPS},
     {"png", no_argument, NULL, CREATE_PNG},
     {"dumpseqs", no_argument, NULL, 'd'},
     {"dumpsigs", no_argument, NULL, 'z'},
-    {"numgen", required_argument, NULL, 'n'},
-    {"margin", required_argument, NULL, 'm'},
+    {"norc", no_argument, NULL, NORC},
     {"minscore", required_argument, NULL, MINSCORE},
-    {"usebestsec", no_argument, NULL, 'u'},
-    {"bin", required_argument, NULL, 'b'},
+    {"margin", required_argument, NULL, 'm'},
     {"range", required_argument, NULL, 'r'},
+    {"bin", required_argument, NULL, 'b'},
+    {"usebestsec", no_argument, NULL, 'u'},
+    {"numgen", required_argument, NULL, 'n'},
     {"shared", required_argument, NULL, 's'},     //sequence similarity threshold
+    {"odds", required_argument, NULL, ODDS_RATIO},
     {"cutoff", required_argument, NULL, 'c'},     //pvalue cutoff
     {"evalue", required_argument, NULL, 'e'},     //Evalue cutoff
     {"overlap", required_argument, NULL, 'o'},    //redundant site overlap
     {"joint", required_argument, NULL, 'j'},      //redundant joint fraction
     {"pseudocount", required_argument, NULL, PSEUDOCOUNT},
     {"bgfile", required_argument, NULL, ARG_BACKGROUND},
+    {"xalph", no_argument, NULL, 'a'},
     {"trimmotifs", required_argument, NULL, 't'},
     {"primary", required_argument, NULL, 'p'},
     {"primaryi", required_argument, NULL, PRIMARY_INDEX},
     {"keepprimary", no_argument, NULL, 'k'},
-    {"xalph", no_argument, NULL, 'a'},
     {"include", required_argument, NULL, 'i'},
     {"exclude", required_argument, NULL, 'x'},
     {"help", no_argument, NULL, 'h'},
-    {"verbosity", required_argument, NULL, 'v'},
     {"version", no_argument, NULL, SHOW_VERSION},
-    {"odds", required_argument, NULL, ODDS_RATIO},
-    {"text", no_argument, NULL, TEXT_ONLY},
+    {"verbosity", required_argument, NULL, 'v'},
     {NULL, 0, NULL, 0} //boundary indicator
   };
 
   // set option defaults
-  options->start = time(NULL);
-  options->prng_seed = 1;
+  options->sequences_file = NULL;			// Required
+  options->primary_file = NULL;				// Required
+  options->secondary_files = arraylst_create();		// Required
+
   options->clobber = true;
   options->outdir = "spamo_out";
-  options->use_best_secondary = false;
+  options->text_only = false;
   options->create_eps = false;
   options->create_png = false;
-  options->create_for_redundant = true;
   options->dump_seqs = false;
-  options->margin = 150;
-  options->bin = 1;
-  options->test_range = 150;
-  options->trim_bit_threshold = 0.25;
-  options->sequence_similarity = 0.5;
-  options->score_threshold = 7;
-  options->pvalue_cutoff = 0.05;
   options->dump_sig_only = false;
+
+  options->norc = false;
+  options->score_threshold = 7;
+  options->margin = 150;
+  options->test_range = 150;
+  options->bin = 1;
+  options->use_best_secondary = false;
+  options->prng_seed = 1;
+  options->start = time(NULL);
+  options->sequence_similarity = 0.5;
+  options->odds = 20;
+
+  options->pvalue_cutoff = 0.05;
   options->motif_evalue_cutoff = 10.0;
   options->overlap = 2;
   options->joint = 0.5;
+
+  options->pseudocount = 0.1;		// (same as FIMO)
+  options->bg_filename = NULL; 		// (same as FIMO)
+  options->xalph = false;
+  options->trim_bit_threshold = 0.25;
   options->primary_name = rbtree_create(rbtree_strcmp, NULL, NULL, NULL, NULL);
   options->primary_index = rbtree_create(rbtree_intcmp, rbtree_intcpy, free, NULL, NULL);
   options->keep_primary = false;
   options->include_patterns = arraylst_create();
   options->exclude_patterns = arraylst_create();
-  options->sequences_file = NULL;
-  options->primary_file = NULL;
-  options->secondary_files = arraylst_create();
-  options->odds = 20;
-  options->text_only = false;
-  options->xalph = false;
-
-  //meme file loading defaults (same as FIMO)
-  options->pseudocount = 0.1;
-  options->bg_filename = NULL;
 
   // parse optional arguments
   int index;
@@ -344,77 +325,92 @@ static char *process_arguments(int argc, char **argv, SPAMO_OPTIONS_T *options)
     int opt = getopt_long_only(argc, argv, "", spamo_options, NULL);
     if (opt == -1) break;
     switch (opt) {
-      case OUTPUT:        //-o <dir>
+      case OUTPUT:		//-o <dir>
         options->clobber = false;
-      case CLOBBER:       //-oc <dir>
+      case CLOBBER:		//-oc <dir>
         options->outdir = optarg;
         break;
-      case CREATE_EPS:    //-eps
+      case TEXT_ONLY:		//-text
+        options->text_only = true;
+        break;
+      case CREATE_EPS:		//-eps
         options->create_eps = true;
         break;
-      case CREATE_PNG:    //-png
+      case CREATE_PNG:		//-png
         options->create_png = true;
         break;
-      case MINSCORE:    //-minscore
-        options->score_threshold = strtod(optarg, NULL);
-        break;
-      case 'u':        //-usebestsec
-        options->use_best_secondary = true;
-        break;
-      case 'd':           //-dumpseqs
+      case 'd':			//-dumpseqs
         options->dump_seqs = true;
         break;
-      case 'z':           //-dumpsigs
+      case 'z':			//-dumpsigs
         options->dump_seqs = true;
         options->dump_sig_only = true;
         break;
-      case 'n':           //-numgen <seed>|time
+      case NORC:		//-norc
+        options->norc = true;
+        break;
+      case MINSCORE:		//-minscore
+        options->score_threshold = strtod(optarg, NULL);
+        break;
+      case 'm':			//-margin <num>
+        options->margin = strtol(optarg, NULL, 10);
+        break;
+      case 'r':			//-range <num>: pvalue testing range
+        options->test_range = strtol(optarg, NULL, 10);
+        break;
+      case 'b':			//-bin <num>
+        options->bin = strtol(optarg, NULL, 10);
+        break;
+      case 'u':			//-usebestsec
+        options->use_best_secondary = true;
+        break;
+      case 'n':			//-numgen <seed>|time
         if (strcmp(optarg, "time") == 0) {
           options->prng_seed = options->start;
         } else {
           options->prng_seed = strtoul(optarg, NULL, 10);
         }
         break;
-      case 'm':           //-margin <num>
-        options->margin = strtol(optarg, NULL, 10);
-        break;
-      case 'b':           //-bin <num>
-        options->bin = strtol(optarg, NULL, 10);
-        break;
-      case 'r':           //-range <num>: pvalue testing range
-        options->test_range = strtol(optarg, NULL, 10);
-        break;
-      case 's':           //-shared <fraction>: shared sequence
+      case 's':			//-shared <fraction>: shared sequence
         options->sequence_similarity = strtod(optarg, NULL);
         break;
-      case 'c':           //-cutoff <pvalue>: pvalue significance cutoff
+      case ODDS_RATIO:
+        options->odds = strtof(optarg, NULL);
+        if (options->pseudocount < 0) {
+          usage(options, "Odds ratio must be positive but got \"%s\".", optarg);
+        }
+        break;
+      case 'c':			//-cutoff <pvalue>: pvalue significance cutoff
         options->pvalue_cutoff = strtod(optarg, NULL);
         break;
-      case 'e':           //-evalue <Evalue>: motif Evalue significance cutoff
+      case 'e':			//-evalue <Evalue>: motif E-value significance cutoff
         options->motif_evalue_cutoff = strtod(optarg, NULL);
         break;
-      case 'o':           //-overlap <fraction>: minimum peak overlap
+      case 'o':			//-overlap <fraction>: minimum peak overlap
         options->overlap = (int)strtol(optarg, NULL, 10);
         break;
-      case 'j':           //-joint <fraction>: minimum shared sites
+      case 'j':			//-joint <fraction>: minimum shared sites
         options->joint = strtod(optarg, NULL);
         break;
-      case PSEUDOCOUNT:   //-pseudocount <fraction>: motif pseudocount
+      case PSEUDOCOUNT:		//-pseudocount <fraction>: motif pseudocount
         options->pseudocount = strtod(optarg, NULL);
         if (options->pseudocount < 0) {
           usage(options, "Pseudocount must be positive but got \"%s\".", optarg);
         }
         break;
-      case ARG_BACKGROUND:    //-bgfile <file>: background to distribute pseudocount
+      case ARG_BACKGROUND:	//-bgfile <file>: background to distribute pseudocount
         options->bg_filename = optarg;
         break;
-      case 't':           //-trimmotifs <bits>: bit threshold for trimming
+      case 'a': 		//-xalph
+        options->xalph = true;
+        break;
+      case 't':			//-trimmotifs <bits>: bit threshold for trimming
         options->trim_bit_threshold = strtod(optarg, NULL);
         break;
-      case 'p':           //-primary <name>: name of primary motif
+      case 'p':			//-primary <name>: name of primary motif
         rbtree_make(options->primary_name, optarg, optarg);
         break;
-      case PRIMARY_INDEX: //-primaryi <index>: index of primary motif
+      case PRIMARY_INDEX:	//-primaryi <index>: index of primary motif
         index = strtol(optarg, &endptr, 10);
         if ((errno != 0 && index == 0) || *endptr != '\0') {
           usage(options, "Option -primaryi '%s' was not in integer.", optarg);
@@ -424,38 +420,26 @@ static char *process_arguments(int argc, char **argv, SPAMO_OPTIONS_T *options)
         index--;
         rbtree_make(options->primary_index, &index, &index);
         break;
-      case 'k':           //-keepprimary: don't exclude the primary motif from the matched
+      case 'k':			//-keepprimary: don't exclude the primary motif from the matched
         options->keep_primary = true;
         break;
-      case 'a':           //-xalph
-        options->xalph = true;
-        break;
-      case 'i':           //-inc <pattern>
+      case 'i':			//-inc <pattern>
         arraylst_add(optarg, options->include_patterns);
         break;
-      case 'x':           //-exc <pattern>
+      case 'x':			//-exc <pattern>
         arraylst_add(optarg, options->exclude_patterns);
         break;
-      case TEXT_ONLY:           //-text
-        options->text_only = true;
-        break;
-      case 'h':           //-help
+      case 'h':			//-help
         usage(options, NULL);
         break;
-      case 'v':           //-verbosity <1-5>
-        verbosity = (int)strtol(optarg, NULL, 10);
-        if (verbosity < 1 || verbosity > 5) {
-          usage(options, "Verbosity must be between 1 and 5 inclusive. Got \"%s\".", optarg);
-        }
-        break;
       case SHOW_VERSION:
         fprintf(stdout, VERSION "\n");
         exit(EXIT_SUCCESS);
         break;
-      case ODDS_RATIO:
-        options->odds = strtof(optarg, NULL);
-        if (options->pseudocount < 0) {
-          usage(options, "Odds ratio must be positive but got \"%s\".", optarg);
+      case 'v':			//-verbosity <1-5>
+        verbosity = (int)strtol(optarg, NULL, 10);
+        if (verbosity < 1 || verbosity > 5) {
+          usage(options, "Verbosity must be between 1 and 5 inclusive. Got \"%s\".", optarg);
         }
         break;
       case '?':           //unrecognised or ambiguous argument
@@ -724,7 +708,7 @@ static void calculate_trimmed_filtered_sequences(
 
   // scan the primary motif
   DEBUG_MSG(NORMAL_VERBOSE, "Determining Best Primary Matches\n");
-  scan_spamo_primary(margin, options->score_threshold, background, primary_motif, seqs, false);
+  scan_spamo_primary(margin, options->score_threshold, background, primary_motif, seqs, false, options->norc);
 
   // remove sequences that don't have a match
   DEBUG_MSG(NORMAL_VERBOSE, "Eliminating Sequences Without Primary Matches\n");
@@ -890,7 +874,7 @@ static void calculate_trimmed_filtered_sequences(
   if (! options->keep_primary) {
     DEBUG_MSG(NORMAL_VERBOSE, "Erasing Extra Primary Matches\n");
     // scan the trimmed sequences with the primary motif 
-    scan_spamo_primary(0, options->score_threshold, background, primary_motif, seqs, true);
+    scan_spamo_primary(0, options->score_threshold, background, primary_motif, seqs, true, options->norc);
     node = rbtree_first(seqs);
     while (node != NULL) {
       next = rbtree_next(node);
@@ -1058,7 +1042,7 @@ static void load_secondary_matches(
     //if (verbosity >= NORMAL_VERBOSE) fprintf(stderr, "40.40%s\r", get_motif_id(smotif->motif));
     //scan
     scan_spamo_secondary(options->margin, options->score_threshold, options->use_best_secondary, background,
-        smotif->motif, sequences, matches, hits, hits_size);
+        smotif->motif, sequences, matches, hits, hits_size, options->norc);
     //process
     process_matches(options->margin, options->bin, options->pvalue_cutoff, options->motif_evalue_cutoff,
         test_max, primary_motif, sequences, smotif, n_secondary_motifs, matches);
