@@ -24,11 +24,14 @@ enum parser_state {
   PS_IN_TRAIN_NEGATIVES,
   PS_IN_TEST_POSITIVES,
   PS_IN_TEST_NEGATIVES,
-  PS_IN_SEQUENCE_DB,
   PS_IN_ALPHABET,
   PS_IN_ALPHABET_LETTER,
   PS_IN_STRANDS,
   PS_IN_BACKGROUND,
+  PS_IN_SEQUENCE_DB,
+  PS_IN_BACKGROUND_FREQUENCIES,
+  PS_IN_BF_ALPHABET_ARRAY,
+  PS_IN_BF_AA_VALUE,
   PS_IN_STOP,
   PS_IN_OBJFUN,
   PS_IN_TEST,
@@ -41,6 +44,7 @@ enum parser_state {
   PS_IN_NITER,
   PS_IN_PATIENCE,
   PS_IN_SEED,
+  PS_IN_NOTRIM,
   PS_IN_USEER,
   PS_IN_MINSCORE,
   PS_IN_IGNORE_DEPTH,
@@ -50,7 +54,9 @@ enum parser_state {
   PS_IN_CAND,
   PS_IN_EXPERIMENTAL,
   PS_IN_TOTALLENGTH,
+  PS_IN_ALIGN,
   PS_IN_HOST,
+  PS_IN_DESCRIPTION,
   PS_IN_MOTIFS,
   PS_IN_MOTIF,
   PS_IN_POS,
@@ -73,11 +79,12 @@ static char const * const state_names[] = {
   "IN_TRAIN_NEGATIVES",
   "IN_TEST_POSITIVES",
   "IN_TEST_NEGATIVES",
-  "IN_SEQUENCE_DB",
   "IN_ALPHABET",
   "IN_ALPHABET_LETTER",
   "IN_STRANDS",
+  "IN_SEQUENCE_DB",
   "IN_BACKGROUND",
+  "IN_BACKGROUND_FREQUENCIES",
   "IN_STOP",
   "IN_OBJFUN",
   "IN_TEST",
@@ -90,6 +97,7 @@ static char const * const state_names[] = {
   "IN_NITER",
   "IN_PATIENCE",
   "IN_SEED",
+  "IN_NOTRIM",
   "IN_USEER",
   "IN_MINSCORE",
   "IN_IGNORE_DEPTH",
@@ -138,6 +146,8 @@ struct ps {
   int state;                // the state code (see PS codes)
   int udepth;               // the depth of unknown tags (disabled)
   ATTRBUF_T attrbuf;
+  char *letter_id_buf;      // a buffer to store the current letter id
+  int letter_id_buf_len;    // the length of the letter id buffer
   CHARBUF_T characters;     // a buffer to store characters between elements
   LINKLST_T *expected_stack;// a queue of expected states
   STREME_IO_XML_CALLBACKS_T *callbacks; // callbacks to the user
@@ -295,7 +305,7 @@ static void parse_freq_attrs(PS_T *ps, const char* tag, const xmlChar **attrs) {
     double delta = sum - 1;
     delta = (delta < 0 ? -delta : delta);
     if (delta > (0.001 * ncore)) {
-      // streme writes background probabilities to 3 decimal places so assuming 
+      // STREME writes background probabilities to 3 decimal places so assuming 
       // the error on each is at maximum 0.001 then the total error for the 
       // sum must be less than or equal to 0.004
       error(ps, "Probabilities of %s do not sum to 1, got %g .\n", tag, sum);
@@ -304,7 +314,7 @@ static void parse_freq_attrs(PS_T *ps, const char* tag, const xmlChar **attrs) {
 }
 
 /*****************************************************************************
- * streme
+ * STREME 
  * contains: model, motifs, reason_for_stopping, run_time
  *
  *  release         the release date.
@@ -331,7 +341,7 @@ static void start_ele_streme(PS_T *ps, const xmlChar **attrs) {
 }
 
 /*****************************************************************************
- * /streme
+ * /STREME
  ****************************************************************************/
 static void st_end_ele_streme(PS_T *ps) {
   if (ps->callbacks->end_streme) {
@@ -340,19 +350,22 @@ static void st_end_ele_streme(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model
+ * STREME > model
  * contains: command_line, train_positives, train_negatives, test_positives,
- *          test_negatives, sequence_db, alphabet, strands, background, 
+ *          test_negatives, [sequence_db,] alphabet, strands, [background,] 
+ *          sequence_db, background_frequencies, 
  *          stop, objfun, test, minw, maxw, kmer, hofract, neval, nref,
- *          niter, patience, seed, useer, minscore, ignore_depth, 
+ *          niter, patience, seed, notrim, useer, minscore, ignore_depth, 
  *	    nsubsets, min_pal_ratio, max_pal_ed, cand, experimental, 
- *          totallength, host
+ *          totallength, [align], host, description?
  ****************************************************************************/
 static void start_ele_model(PS_T *ps, const xmlChar **attrs) {
   if (ps->callbacks->start_model && ps->state != PS_ERROR) {
     ps->callbacks->start_model(ps->user_data);
   }
+  streme_push_es(ps, PS_IN_DESCRIPTION, ES_ZERO_OR_ONE);
   streme_push_es(ps, PS_IN_HOST, ES_ONCE);
+  streme_push_es(ps, PS_IN_ALIGN, ES_ZERO_OR_ONE);
   streme_push_es(ps, PS_IN_TOTALLENGTH, ES_ONCE);
   streme_push_es(ps, PS_IN_EXPERIMENTAL, ES_ONCE);
   streme_push_es(ps, PS_IN_CAND, ES_ONCE);
@@ -362,6 +375,7 @@ static void start_ele_model(PS_T *ps, const xmlChar **attrs) {
   streme_push_es(ps, PS_IN_IGNORE_DEPTH, ES_ONCE);
   streme_push_es(ps, PS_IN_MINSCORE, ES_ONCE);
   streme_push_es(ps, PS_IN_USEER, ES_ONCE);
+  streme_push_es(ps, PS_IN_NOTRIM, ES_ZERO_OR_ONE);	// new in 5.5.3
   streme_push_es(ps, PS_IN_SEED, ES_ONCE);
   streme_push_es(ps, PS_IN_PATIENCE, ES_ONCE);
   streme_push_es(ps, PS_IN_NITER, ES_ONCE);
@@ -374,10 +388,12 @@ static void start_ele_model(PS_T *ps, const xmlChar **attrs) {
   streme_push_es(ps, PS_IN_TEST, ES_ONCE);
   streme_push_es(ps, PS_IN_OBJFUN, ES_ONCE);
   streme_push_es(ps, PS_IN_STOP, ES_ONCE);
-  streme_push_es(ps, PS_IN_BACKGROUND, ES_ONCE);
+  streme_push_es(ps, PS_IN_BACKGROUND_FREQUENCIES, ES_ZERO_OR_ONE);	// added after 5.3.0
+  streme_push_es(ps, PS_IN_SEQUENCE_DB, ES_ZERO_OR_ONE);		// added after 5.3.0
+  streme_push_es(ps, PS_IN_BACKGROUND, ES_ZERO_OR_ONE);			// removed after 5.3.0
   streme_push_es(ps, PS_IN_STRANDS, ES_ONCE);
   streme_push_es(ps, PS_IN_ALPHABET, ES_ONCE);
-  streme_push_es(ps, PS_IN_SEQUENCE_DB, ES_ONCE);
+  streme_push_es(ps, PS_IN_SEQUENCE_DB, ES_ZERO_OR_ONE);		// removed after 5.3.0
   streme_push_es(ps, PS_IN_TEST_NEGATIVES, ES_ZERO_OR_ONE);
   streme_push_es(ps, PS_IN_TEST_POSITIVES, ES_ZERO_OR_ONE);
   streme_push_es(ps, PS_IN_TRAIN_NEGATIVES, ES_ZERO_OR_ONE);
@@ -386,7 +402,7 @@ static void start_ele_model(PS_T *ps, const xmlChar **attrs) {
 }
 
 /*****************************************************************************
- * streme > /model
+ * STREME > /model
  ****************************************************************************/
 static void st_end_ele_model(PS_T *ps) {
   if (ps->callbacks->end_model && ps->state != PS_ERROR) {
@@ -395,7 +411,7 @@ static void st_end_ele_model(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /command_line
+ * STREME > model > /command_line
  * the command-line used to run the program.
  ****************************************************************************/
 static void st_end_ele_command_line(PS_T *ps) {
@@ -405,7 +421,7 @@ static void st_end_ele_command_line(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > train_positives
+ * STREME > model > train_positives
  *
  *  count           the number of sequences in the positive training set
  *  positions 	    the number of characters in the positive training set
@@ -430,7 +446,7 @@ static void start_ele_train_positives(PS_T *ps, const xmlChar **attrs) {
 }
 
 /*****************************************************************************
- * streme > model > train_negatives
+ * STREME > model > train_negatives
  *
  *  count           the number of sequences in the negative dataset
  *  positions 	    the number of characters in the negative training set
@@ -468,7 +484,7 @@ static void start_ele_train_negatives(PS_T *ps, const xmlChar **attrs) {
 }
 
 /*****************************************************************************
- * streme > model > test_positives
+ * STREME > model > test_positives
  *
  *  count           the number of sequences in the positive training set
  *  positions 	    the number of characters in the positive training set
@@ -490,7 +506,7 @@ static void start_ele_test_positives(PS_T *ps, const xmlChar **attrs) {
 }
 
 /*****************************************************************************
- * streme > model > test_negatives
+ * STREME > model > test_negatives
  *
  *  count           the number of sequences in the negative training set
  *  positions 	    the number of characters in the negative training set
@@ -607,7 +623,7 @@ void st_end_ele_strands(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > background
+ * STREME > model > background	(pre 5.3.0)
  *
  *  type            is the alphabet DNA or RNA (optional when custom alphabet specified)
  *  <symbol>        frequency of <symbol> from core alphabet
@@ -620,7 +636,7 @@ static void start_ele_background(PS_T *ps, const xmlChar **attrs) {
 
   char* from_options[1] = {"dataset"};
   int from_values[1] = {STREME_BG_FROM_DATASET};
-  MULTI_T from_multi = {.count = 1, .options = from_options, 
+  MULTI_T from_multi = {.count = 1, .options = from_options,
     .outputs = from_values, .target = &(from)};
 
   char* names[1] = {"from"};
@@ -638,7 +654,97 @@ static void start_ele_background(PS_T *ps, const xmlChar **attrs) {
 }
 
 /*****************************************************************************
- * streme > model > stop
+ * STREME > model > background_frequencies
+ *
+ *  type            is the alphabet DNA or RNA (optional when custom alphabet specified)
+ *  <symbol>        frequency of <symbol> from core alphabet
+ *  from            from the negative dataset or a background file
+ *  file            the background file (optional)
+ *  last_mod_date   the last modified date of the background file (optional)
+ ****************************************************************************/
+static void start_ele_background_frequencies(PS_T *ps, const xmlChar **attrs) {
+  char *bgsource;
+
+  char* names[1] = {"source"};
+  int (*parsers[1])(char*, void*) = {ld_str};
+  void *data[1] = {&bgsource};
+  bool required[1] = {true};
+  bool done[1];
+
+  parse_attributes(streme_attr_parse_error, ps, "background_frequencies", attrs, 1, names, parsers, data, required, done);
+
+  if (ps->callbacks->start_background_frequencies && ps->state != PS_ERROR) {
+    ps->callbacks->start_background_frequencies(ps->user_data, bgsource);
+  }
+  streme_push_es(ps, PS_IN_BF_ALPHABET_ARRAY, ES_ONCE);
+}
+
+/*****************************************************************************
+ * STREME > model > background_frequencies
+ ****************************************************************************/
+static void end_ele_background_frequencies(PS_T *ps) {
+  if (ps->callbacks->end_background_frequencies && ps->state != PS_ERROR) {
+    ps->callbacks->end_background_frequencies(ps->user_data);
+  }
+}
+
+/*****************************************************************************
+ * STREME > model > background_frequencies > alphabet_array
+ ****************************************************************************/
+static void start_ele_bf_alphabet_array(PS_T *ps, const xmlChar **attrs) {
+  if (ps->callbacks->start_bf_alphabet_array && ps->state != PS_ERROR) {
+    ps->callbacks->start_bf_alphabet_array(ps->user_data);
+  }
+  streme_push_es(ps, PS_IN_BF_AA_VALUE, ES_ONE_OR_MORE);
+}
+
+/*****************************************************************************
+ * STREME > model > background_frequencies > /alphabet_array
+ ****************************************************************************/
+static void end_ele_bf_alphabet_array(PS_T *ps) {
+  if (ps->callbacks->end_bf_alphabet_array && ps->state != PS_ERROR) {
+    ps->callbacks->end_bf_alphabet_array(ps->user_data);
+  }
+}
+
+/*****************************************************************************
+ * STREME > model > background_frequencies > alphabet_array > value
+ ****************************************************************************/
+static void start_ele_value(PS_T *ps, const xmlChar **attrs) {
+  char *letter_id;
+  int letter_id_len;
+
+  char* names[1] = {"letter_id"};
+  int (*parsers[1])(char*, void*) = {ld_str};
+  void *data[1] = {&letter_id};
+  bool required[1] = {true};
+  bool done[1];
+
+  parse_attributes(streme_attr_parse_error, ps, "value", attrs, 1, names, parsers, data, required, done);
+
+  letter_id_len = strlen(letter_id);
+  if (ps->letter_id_buf_len <= letter_id_len) {
+    ps->letter_id_buf = mm_realloc(ps->letter_id_buf, sizeof(char) * (letter_id_len + 1));
+    ps->letter_id_buf_len = letter_id_len + 1;
+  }
+  strncpy(ps->letter_id_buf, letter_id, ps->letter_id_buf_len);
+}
+
+/*****************************************************************************
+ * STREME > model > background_frequencies > alphabet_array > /value
+ ****************************************************************************/
+static void end_ele_bf_aa_value(PS_T *ps) {
+  double value;
+  if (ld_double(ps->characters.buffer, &value)) {
+    error(ps, "Couldn't parse value from \"%s\"\n", ps->characters.buffer);
+  }
+  if (ps->callbacks->handle_bf_aa_value && ps->state != PS_ERROR) {
+    ps->callbacks->handle_bf_aa_value(ps->user_data, ps->letter_id_buf, value);
+  }
+}
+
+/*****************************************************************************
+ * STREME > model > stop
  *
  *  pvt		the maximum p-value threshold for motifs
  *  nmotifs	the maximum number of motifs to find
@@ -698,7 +804,7 @@ void st_end_ele_test(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /minw
+ * STREME > model > /minw
  ****************************************************************************/
 static void st_end_ele_minw(PS_T *ps) {
   int minw;
@@ -713,7 +819,7 @@ static void st_end_ele_minw(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /maxw
+ * STREME > model > /maxw
  ****************************************************************************/
 static void st_end_ele_maxw(PS_T *ps) {
   int maxw;
@@ -728,7 +834,7 @@ static void st_end_ele_maxw(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /kmer
+ * STREME > model > /kmer
  ****************************************************************************/
 static void st_end_ele_kmer(PS_T *ps) {
   int kmer;
@@ -743,7 +849,7 @@ static void st_end_ele_kmer(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /hofract
+ * STREME > model > /hofract
  ****************************************************************************/
 static void st_end_ele_hofract(PS_T *ps) {
   double hofract;
@@ -758,7 +864,7 @@ static void st_end_ele_hofract(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /neval
+ * STREME > model > /neval
  ****************************************************************************/
 static void st_end_ele_neval(PS_T *ps) {
   int neval;
@@ -773,7 +879,7 @@ static void st_end_ele_neval(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /nref
+ * STREME > model > /nref
  ****************************************************************************/
 static void st_end_ele_nref(PS_T *ps) {
   int nref;
@@ -788,7 +894,7 @@ static void st_end_ele_nref(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /niter
+ * STREME > model > /niter
  ****************************************************************************/
 static void st_end_ele_niter(PS_T *ps) {
   int niter;
@@ -803,7 +909,7 @@ static void st_end_ele_niter(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > patience
+ * STREME > model > patience
  ****************************************************************************/
 static void st_end_ele_patience(PS_T *ps) {
   long patience;
@@ -818,7 +924,7 @@ static void st_end_ele_patience(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /seed
+ * STREME > model > /seed
  ****************************************************************************/
 static void st_end_ele_seed(PS_T *ps) {
   long seed;
@@ -833,7 +939,26 @@ static void st_end_ele_seed(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /useer
+ * STREME > model > /notrim 		New in 5.5.3
+ ****************************************************************************/
+static void st_end_ele_notrim(PS_T *ps) {
+  bool notrim = false;
+
+  if (strcmp("no", ps->characters.buffer) == 0) {
+    notrim = false;
+  } else if (strcmp("yes", ps->characters.buffer) == 0) {
+    notrim = true;
+  } else {
+    error(ps, "Bad value \"%s\" for notrim.\n", ps->characters.buffer);
+  }
+
+  if (ps->callbacks->handle_notrim && ps->state != PS_ERROR) {
+    ps->callbacks->handle_notrim(ps->user_data, notrim);
+  }
+}
+
+/*****************************************************************************
+ * STREME > model > /useer
  ****************************************************************************/
 static void st_end_ele_useer(PS_T *ps) {
   bool useer = false;
@@ -852,7 +977,7 @@ static void st_end_ele_useer(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /minscore
+ * STREME > model > /minscore
  ****************************************************************************/
 static void st_end_ele_minscore(PS_T *ps) {
   double minscore;
@@ -867,7 +992,7 @@ static void st_end_ele_minscore(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /ignore_depth
+ * STREME > model > /ignore_depth
  ****************************************************************************/
 static void st_end_ele_ignore_depth(PS_T *ps) {
   long ignore_depth;
@@ -882,7 +1007,7 @@ static void st_end_ele_ignore_depth(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /nsubsets
+ * STREME > model > /nsubsets
  ****************************************************************************/
 static void st_end_ele_nsubsets(PS_T *ps) {
   long nsubsets;
@@ -897,7 +1022,7 @@ static void st_end_ele_nsubsets(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /min_pal_ratio
+ * STREME > model > /min_pal_ratio
  ****************************************************************************/
 static void st_end_ele_min_pal_ratio(PS_T *ps) {
   double min_pal_ratio;
@@ -912,7 +1037,7 @@ static void st_end_ele_min_pal_ratio(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /max_pal_ed
+ * STREME > model > /max_pal_ed
  ****************************************************************************/
 static void st_end_ele_max_pal_ed(PS_T *ps) {
   double max_pal_ed;
@@ -927,7 +1052,7 @@ static void st_end_ele_max_pal_ed(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /cand
+ * STREME > model > /cand
  ****************************************************************************/
 static void st_end_ele_cand(PS_T *ps) {
   bool cand = false;
@@ -946,7 +1071,7 @@ static void st_end_ele_cand(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /experimental
+ * STREME > model > /experimental
  ****************************************************************************/
 static void st_end_ele_experimental(PS_T *ps) {
   bool experimental = false;
@@ -965,7 +1090,7 @@ static void st_end_ele_experimental(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /totallength
+ * STREME > model > /totallength
  ****************************************************************************/
 static void st_end_ele_totallength(PS_T *ps) {
   long totallength;
@@ -980,7 +1105,16 @@ static void st_end_ele_totallength(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > model > /host
+ * STREME > model > /align
+ ****************************************************************************/
+static void st_end_ele_align(PS_T *ps) {
+  if (ps->callbacks->handle_host && ps->state != PS_ERROR) {
+    ps->callbacks->handle_host(ps->user_data, ps->characters.buffer);
+  }
+}
+
+/*****************************************************************************
+ * STREME > model > /host
  * the name of the computer which ran STREME.
  ****************************************************************************/
 static void st_end_ele_host(PS_T *ps) {
@@ -990,7 +1124,17 @@ static void st_end_ele_host(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > motifs
+ * STREME > model > /description
+ * an optional description of the experiment.
+ ****************************************************************************/
+static void end_ele_description(PS_T *ps) {
+  if (ps->callbacks->handle_description && ps->state != PS_ERROR) {
+    ps->callbacks->handle_description(ps->user_data, ps->characters.buffer);
+  }
+}
+
+/*****************************************************************************
+ * STREME > motifs
  * contains: motif*
  ****************************************************************************/
 static void start_ele_motifs(PS_T *ps, const xmlChar **attrs) {
@@ -1001,7 +1145,7 @@ static void start_ele_motifs(PS_T *ps, const xmlChar **attrs) {
 }
 
 /*****************************************************************************
- * streme > /motifs
+ * STREME > /motifs
  ****************************************************************************/
 static void st_end_ele_motifs(PS_T *ps) {
   if (ps->callbacks->end_motifs && ps->state != PS_ERROR) {
@@ -1010,7 +1154,7 @@ static void st_end_ele_motifs(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > motifs > motif
+ * STREME > motifs > motif
  *
  *  id                the identifier used by STREME
  *  alt		      alternate identifier used by STREME
@@ -1095,7 +1239,7 @@ static void start_ele_motif(PS_T *ps, const xmlChar **attrs) {
 }
 
 /*****************************************************************************
- * streme > motifs > /motif
+ * STREME > motifs > /motif
  * contains: pos+
  ****************************************************************************/
 static void st_end_ele_motif(PS_T *ps) {
@@ -1113,7 +1257,7 @@ static void st_end_ele_motif(PS_T *ps) {
 }
 
 /*****************************************************************************
- * streme > motifs > motif > pos
+ * STREME > motifs > motif > pos
  *
  *  i                 index of the motif position (optional)
  *  <symbol>          frequency of <symbol>
@@ -1239,10 +1383,11 @@ void handle_streme_start_ele(void *ctx, const xmlChar *name, const xmlChar **att
         DO_START_ELE(train_negatives, start_ele_train_negatives, PS_IN_TRAIN_NEGATIVES, IGNORE);
         DO_START_ELE(test_positives, start_ele_test_positives, PS_IN_TEST_POSITIVES, IGNORE);
         DO_START_ELE(test_negatives, start_ele_test_negatives, PS_IN_TEST_NEGATIVES, IGNORE);
-        CHECK_START_ELE(sequence_db, PS_IN_SEQUENCE_DB, IGNORE);
         DO_START_ELE(alphabet, start_ele_alphabet, PS_IN_ALPHABET, IGNORE);
         CHECK_START_ELE(strands, PS_IN_STRANDS, ALL_BUT_SPACE);
         DO_START_ELE(background, start_ele_background, PS_IN_BACKGROUND, IGNORE);
+        CHECK_START_ELE(sequence_db, PS_IN_SEQUENCE_DB, IGNORE);
+        DO_START_ELE(background_frequencies, start_ele_background_frequencies, PS_IN_BACKGROUND_FREQUENCIES, IGNORE);
         DO_START_ELE(stop, start_ele_stop, PS_IN_STOP, IGNORE);
         CHECK_START_ELE(objfun, PS_IN_OBJFUN, ALL_CHARS);
         CHECK_START_ELE(test, PS_IN_TEST, ALL_CHARS);
@@ -1255,6 +1400,7 @@ void handle_streme_start_ele(void *ctx, const xmlChar *name, const xmlChar **att
         CHECK_START_ELE(niter, PS_IN_NITER, ALL_BUT_SPACE);
         CHECK_START_ELE(patience, PS_IN_PATIENCE, ALL_BUT_SPACE);
         CHECK_START_ELE(seed, PS_IN_SEED, ALL_BUT_SPACE);
+        CHECK_START_ELE(notrim, PS_IN_NOTRIM, ALL_BUT_SPACE); // new in 5.5.3
         CHECK_START_ELE(useer, PS_IN_USEER, ALL_BUT_SPACE);
         CHECK_START_ELE(minscore, PS_IN_MINSCORE, ALL_BUT_SPACE);
         CHECK_START_ELE(ignore_depth, PS_IN_IGNORE_DEPTH, ALL_BUT_SPACE);
@@ -1264,7 +1410,9 @@ void handle_streme_start_ele(void *ctx, const xmlChar *name, const xmlChar **att
         CHECK_START_ELE(cand, PS_IN_CAND, ALL_BUT_SPACE);
         CHECK_START_ELE(experimental, PS_IN_EXPERIMENTAL, ALL_BUT_SPACE);
         CHECK_START_ELE(totallength, PS_IN_TOTALLENGTH, ALL_BUT_SPACE);
+        CHECK_START_ELE(align, PS_IN_ALIGN, ALL_BUT_SPACE);
         CHECK_START_ELE(host, PS_IN_HOST, ALL_BUT_SPACE);
+        CHECK_START_ELE(description, PS_IN_DESCRIPTION, ALL_CHARS);
         break;
       case PS_IN_ALPHABET:
         DO_START_ELE(letter, start_ele_alphabet_letter, PS_IN_ALPHABET_LETTER, IGNORE);
@@ -1277,6 +1425,14 @@ void handle_streme_start_ele(void *ctx, const xmlChar *name, const xmlChar **att
         DO_START_ELE(pos, start_ele_pos, PS_IN_POS, IGNORE);
         known = 0;
         break;
+      case PS_IN_BACKGROUND_FREQUENCIES:
+        DO_START_ELE(alphabet_array, start_ele_bf_alphabet_array, PS_IN_BF_ALPHABET_ARRAY, IGNORE);
+        known = 0;
+        break;
+      case PS_IN_BF_ALPHABET_ARRAY:
+        DO_START_ELE(value, start_ele_value, PS_IN_BF_AA_VALUE, ALL_BUT_SPACE);
+        known = 0;
+        break;
       default:
         known = 0;
         break;
@@ -1334,11 +1490,14 @@ void handle_streme_end_ele(void *ctx, const xmlChar *name) {
       CHECK_END_ELE(train_negatives, PS_IN_TRAIN_NEGATIVES, PS_IN_MODEL);
       CHECK_END_ELE(test_positives, PS_IN_TEST_POSITIVES, PS_IN_MODEL);
       CHECK_END_ELE(test_negatives, PS_IN_TEST_NEGATIVES, PS_IN_MODEL);
-      CHECK_END_ELE(sequence_db, PS_IN_SEQUENCE_DB, PS_IN_MODEL);
       DO_END_ELE(alphabet, st_end_ele_alphabet, PS_IN_ALPHABET, PS_IN_MODEL);
       CHECK_END_ELE(letter, PS_IN_ALPHABET_LETTER, PS_IN_ALPHABET);
       CHECK_END_ELE(strands, PS_IN_STRANDS, PS_IN_MODEL);
       CHECK_END_ELE(background, PS_IN_BACKGROUND, PS_IN_MODEL);
+      CHECK_END_ELE(sequence_db, PS_IN_SEQUENCE_DB, PS_IN_MODEL);
+      DO_END_ELE(background_frequencies, end_ele_background_frequencies, PS_IN_BACKGROUND_FREQUENCIES, PS_IN_MODEL);
+      DO_END_ELE(alphabet_array, end_ele_bf_alphabet_array, PS_IN_BF_ALPHABET_ARRAY, PS_IN_BACKGROUND_FREQUENCIES);
+      DO_END_ELE(value, end_ele_bf_aa_value, PS_IN_BF_AA_VALUE, PS_IN_BF_ALPHABET_ARRAY);
       CHECK_END_ELE(stop, PS_IN_STOP, PS_IN_MODEL);
       DO_END_ELE(objfun, st_end_ele_objfun, PS_IN_OBJFUN, PS_IN_MODEL);
       DO_END_ELE(test, st_end_ele_test, PS_IN_TEST, PS_IN_MODEL);
@@ -1351,6 +1510,7 @@ void handle_streme_end_ele(void *ctx, const xmlChar *name) {
       DO_END_ELE(niter, st_end_ele_niter, PS_IN_NITER, PS_IN_MODEL);
       DO_END_ELE(patience, st_end_ele_patience, PS_IN_PATIENCE, PS_IN_MODEL);
       DO_END_ELE(seed, st_end_ele_seed, PS_IN_SEED, PS_IN_MODEL);
+      DO_END_ELE(notrim, st_end_ele_notrim, PS_IN_NOTRIM, PS_IN_MODEL);		// new in 5.5.3
       DO_END_ELE(useer, st_end_ele_useer, PS_IN_USEER, PS_IN_MODEL);
       DO_END_ELE(minscore, st_end_ele_minscore, PS_IN_MINSCORE, PS_IN_MODEL);
       DO_END_ELE(ignore_depth, st_end_ele_ignore_depth, PS_IN_IGNORE_DEPTH, PS_IN_MODEL);
@@ -1360,7 +1520,9 @@ void handle_streme_end_ele(void *ctx, const xmlChar *name) {
       DO_END_ELE(cand, st_end_ele_cand, PS_IN_CAND, PS_IN_MODEL);
       DO_END_ELE(experimental, st_end_ele_experimental, PS_IN_EXPERIMENTAL, PS_IN_MODEL);
       DO_END_ELE(totallength, st_end_ele_totallength, PS_IN_TOTALLENGTH, PS_IN_MODEL);
+      DO_END_ELE(align, st_end_ele_align, PS_IN_ALIGN, PS_IN_MODEL);
       DO_END_ELE(host, st_end_ele_host, PS_IN_HOST, PS_IN_MODEL);
+      DO_END_ELE(description, end_ele_description, PS_IN_DESCRIPTION, PS_IN_MODEL);
       DO_END_ELE(motifs, st_end_ele_motifs, PS_IN_MOTIFS, PS_IN_STREME);
       DO_END_ELE(motif, st_end_ele_motif, PS_IN_MOTIF, PS_IN_MOTIFS);
       CHECK_END_ELE(pos, PS_IN_POS, PS_IN_MOTIF);
@@ -1403,13 +1565,18 @@ void* create_streme_io_xml_sax_context(void *user_data, STREME_IO_XML_CALLBACKS_
   ps->freqs = NULL;
   ps->motif_id = NULL;
   ps->last_pos = 0;
+  // setup attribute buffer
+  attrbuf_init(&(ps->attrbuf));
   //set up character buffer
   buf = &(ps->characters);
   buf->buffer = mm_malloc(sizeof(char)*10);
   buf->buffer[0] = '\0';
   buf->size = 10;
   buf->pos = 0;
-  attrbuf_init(&(ps->attrbuf));
+  //set up attribute buffer (needed for an alphabet array value)
+  ps->letter_id_buf = mm_malloc(sizeof(char)*10);
+  ps->letter_id_buf[0] = '\0';
+  ps->letter_id_buf_len = 10;
   //set up expected queue
   ps->expected_stack = linklst_create();
   return ps;
