@@ -206,6 +206,7 @@ Multiseq *read_pos_neg_seqs(
   BOOL allow_ambigs,			// don't convert ambiguous characters to SEPARATOR
   BOOL no_trim,				// don't trim sequences to average length
   BOOL set_back,			// set the background in the multiseq objects
+  BOOL reset_rand,			// reset the random number generator
   ARRAY_T *background,                  // IN MEME-style background model
   Multiseq **test_multiseq_ptr		// OUT hold-out set
 ) {
@@ -215,17 +216,21 @@ Multiseq *read_pos_neg_seqs(
   ALPHABET_T alphabet_type = options->alphabet_type;
   int order = options->order;		// shuffle using m-order shuffle
   double hofract = options->hofract;	// size of test set; none if <=0; -1 means don't set nmotifs
+  hofract = MAX(0, hofract);		// make hofract >= 0
   int minwidth = options->minwidth;	// mininum motif width
   int maxtotallength = options->totallength;	// truncate each each sequence set (+/-) to this length
   Multiseq *multiseq=NULL, *test_multiseq=NULL, *negmultiseq=NULL, *test_negmultiseq=NULL;
+  BOOL restore_strand = reset_rand;
+  int i;
 
   // Convert DNA to RNA?
   BOOL is_rna = (alphabet_type == Rna || (alphabet_type == Custom && alph_check(alph, RNA)));
   if (is_rna) DEBUG_MSG(NORMAL_VERBOSE, "# NOTE: Will convert any DNA sequences to RNA.\n");
 
-  // Read in the positive sequences.
-  if (read_fasta_to_multiseqs(&multiseq, &test_multiseq, hofract, MIN_HO_SIZE, do_rc, use_smaller_strand, 
-       is_rna, allow_ambigs, posfile, alph, COMPALPH, minwidth, maxtotallength) != 0) { 
+  // Read in the positive (PRIMARY) sequences.
+  if (reset_rand) srand_mt(options->seed);// Reset random seed so read_fasta_to_multiseqs will permute the same way.
+  if (read_fasta_to_multiseqs(&multiseq, &test_multiseq, hofract, MIN_HO_SIZE, do_rc, use_smaller_strand, restore_strand,
+       is_rna, allow_ambigs, posfile, PRIMARY, alph, COMPALPH, minwidth, maxtotallength) != 0) { 
     DEBUG_FMT(QUIET_VERBOSE, "ERROR: There was a problem reading the primary sequence file '%s'.\n", posfile); 
     exit(EXIT_FAILURE);
   }
@@ -244,10 +249,11 @@ Multiseq *read_pos_neg_seqs(
       "#          would have had fewer than %d sequences.\n", MIN_HO_SIZE);
   }
 
-  // Read in the negative sequences if needed.
+  // Read in the negative (CONTROL) sequences if needed.
   if (options->objfun == DE || options->objfun == NO_OBJFUN) {
-    if (read_fasta_to_multiseqs(&negmultiseq, &test_negmultiseq, (test_multiseq==NULL ? 0 : hofract), MIN_HO_SIZE, do_rc, use_smaller_strand,
-      is_rna, allow_ambigs, negfile, alph, COMPALPH, minwidth, maxtotallength) != 0) { 
+    DBTYPE_T control_type = (negfile == posfile ? SHUFFLED_PRIMARY : CONTROL);
+    if (read_fasta_to_multiseqs(&negmultiseq, &test_negmultiseq, (test_multiseq==NULL ? 0 : hofract), MIN_HO_SIZE, do_rc, use_smaller_strand, restore_strand,
+      is_rna, allow_ambigs, negfile, control_type, alph, COMPALPH, minwidth, maxtotallength) != 0) { 
       DEBUG_FMT(QUIET_VERBOSE, "ERROR: There was a problem reading the control sequence file '%s'.\n", negfile); 
       exit(EXIT_FAILURE);
     }
@@ -261,10 +267,10 @@ Multiseq *read_pos_neg_seqs(
       freemultiseq(multiseq);
       freemultiseq(test_multiseq);
       freemultiseq(negmultiseq);
-      (void) read_fasta_to_multiseqs(&multiseq, &test_multiseq, 0, MIN_HO_SIZE, do_rc, use_smaller_strand,
-        is_rna, allow_ambigs, posfile, alph, COMPALPH, minwidth, maxtotallength);
-      (void) read_fasta_to_multiseqs(&negmultiseq, &test_negmultiseq, (test_multiseq==NULL ? 0 : 0), MIN_HO_SIZE, do_rc, use_smaller_strand,
-        is_rna, allow_ambigs, negfile, alph, COMPALPH, minwidth, maxtotallength);
+      (void) read_fasta_to_multiseqs(&multiseq, &test_multiseq, 0, MIN_HO_SIZE, do_rc, use_smaller_strand, restore_strand,
+        is_rna, allow_ambigs, posfile, PRIMARY, alph, COMPALPH, minwidth, maxtotallength);
+      (void) read_fasta_to_multiseqs(&negmultiseq, &test_negmultiseq, (test_multiseq==NULL ? 0 : 0), MIN_HO_SIZE, do_rc, use_smaller_strand, restore_strand,
+        is_rna, allow_ambigs, negfile, control_type, alph, COMPALPH, minwidth, maxtotallength);
     }
   }
 
@@ -352,7 +358,6 @@ Multiseq *read_pos_neg_seqs(
   // Initialize the lookup table of starts, lengths and 
   // minimum and maximum lengths.
   Uint seqno;
-  int i;
   multiseq->use_binomial = false;
   multiseq->bernoulli = -1;
   for (i=0; i<2; i++) {
@@ -467,6 +472,7 @@ void score_model_pssm(
   BOOL set_pvalue,			// compute the enrichment p-value of the model
   SAVE_MATCHES_T save_matches, 		// ZOOPS: save best match in every sequence (positive or negative) for nesting
 					// PASSING: save all matches with score >= model->score_threshold for erasing
+					// APPEND_PASSING: add all matches with score >= model->score_threshold for erasing
 					// NONE: don't save matches
   BOOL is_ho, 				// data is the hold-out set
   BOOL use_cache,  			// use the p-value cache
@@ -496,6 +502,14 @@ void score_model_pssm(
   // Matches to be returned in model.
   Uint nmatches = 0;
   Site *matches = NULL;
+  if (save_matches == APPEND_PASSING) {
+    nmatches = model->nmatches;
+    matches = model->matches;
+  } else if (save_matches != NONE) {
+    if (model->nmatches != 0 && model->matches) {
+      free(model->matches); matches = model->matches = NULL; nmatches = model->nmatches = 0;
+    }
+  }
   double pos_sites = npos * MAX(1, (avg_poslen - w + 1));
   double neg_sites = nneg * MAX(1, (avg_neglen - w + 1));
   double bernoulli = use_binomial ? pos_sites / (pos_sites + neg_sites) : -1;
@@ -570,11 +584,12 @@ void score_model_pssm(
           best_strand = strand;
         }
         // Save the site if it is a MATCH and we are returning all PASSING matches.
-	if (save_matches==PASSING && score >= score_threshold) {
+	if ((save_matches==PASSING || save_matches==APPEND_PASSING) && score >= score_threshold) {
           if (nmatches % RCHUNK == 0) Resize(matches, nmatches+RCHUNK, Site);
 	  matches[nmatches].seqno = seqno;
 	  matches[nmatches].pos = pos;
           matches[nmatches].is_positive = (seqno < npos);
+          matches[nmatches].is_holdout = (save_matches==APPEND_PASSING);
           matches[nmatches].score = score;
           matches[nmatches].strand = strand;
 	  nmatches++;
@@ -605,7 +620,7 @@ void score_model_pssm(
   } // seqno
 
   // Save the matches in the model if requested.
-  if (save_matches==ZOOPS || save_matches==PASSING) {
+  if (save_matches != NONE) {
     model->matches = matches;
     model->nmatches = nmatches;
   }
@@ -1108,12 +1123,16 @@ void get_passing_sequences(
   double *best_score = malloc(nseqs * sizeof(double));
   double score_threshold = model->score_threshold;
   int npassing = 0;
+  int npos_passing = 0;
   for (seqno=0; seqno<nseqs; seqno++) best_score[seqno] = score_threshold-1;
   for (i=0; i<model->nmatches; i++) {
     seqno = model->matches[i].seqno;
     double score = model->matches[i].score;
     if (score >= score_threshold && score > best_score[seqno]) {
-      if (best_score[seqno] < score_threshold) npassing++;	// first passing score
+      if (best_score[seqno] < score_threshold) {		// first passing score
+        npassing++;
+        if (seqno < npos) npos_passing++;
+      }
       best_score[seqno] = score;
     }
   }
@@ -1123,6 +1142,7 @@ void get_passing_sequences(
     (Passing_seq *) realloc(model->passing_seqs, (npassing+model->npassing) * sizeof(Passing_seq)) :
     (Passing_seq *) malloc(npassing * sizeof(Passing_seq));
   npassing = append ? model->npassing : 0;
+  npos_passing = append ? model->npos_passing : 0;
   for (seqno=0; seqno<nseqs; seqno++) {
     if (best_score[seqno] >= score_threshold) {
       sequences[npassing].dbno = append ? 1 : 0;	// present to allow unique sort order
@@ -1131,6 +1151,7 @@ void get_passing_sequences(
       sequences[npassing].score = best_score[seqno];
       sequences[npassing].is_tp = (seqno < npos);
       npassing++;
+      if (seqno < npos) npos_passing++;
     }
   }
 
@@ -1143,6 +1164,7 @@ void get_passing_sequences(
   // Set the passing sequences in the model.
   model->passing_seqs = sequences;
   model->npassing = npassing;
+  model->npos_passing = npos_passing;
 } // get_passing_sequences
 
 //
