@@ -7,6 +7,10 @@
 *                                                                      *
 ***********************************************************************/
 
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include <assert.h>
 
 #include "matrix.h"
@@ -509,7 +513,6 @@ ARRAY_T *get_pseudocount_freqs(
         Specify the integer PAM distance.
 */
 /***********************************************************************/
-VERBOSE_T verbosity = NORMAL_VERBOSE;
 main(int argc, char **argv) {
   int i, j, alength;
   int dist = 0;
