@@ -286,8 +286,8 @@ static void usage(bool msg, char *format, ...) {
     "                                          Note: there must be one distance for each histone name in <histones>\n"
     "    --max-pvalue <mp>              maximum p-value for including non-CT, non-CL links in output;\n"
     "                                          default: %.2f\n"
-    "    --tissues <tissues>            comma-separated list (no spaces) of tissue names that are the\n"
-    "                                   sources of the histone and expression data; default: None\n"
+    "    --tissues <tissues>            comma-separated list (no spaces) of three (or more) tissue names that are\n"
+    "                                   the sources of the histone and expression data; default: None\n"
     "    --histone-root <hrd>           histone root directory; default: None\n"
     "                                          Note: histone files must be in subfolders '<hrd>/<t>'\n"
     "                                          where <t> is one of the tissue names in <tissues>\n"
@@ -549,8 +549,11 @@ static char *process_command_line(int argc, char* argv[], TGENE_OPTIONS_T *optio
   options->n_tissues = 0;
   if (strcmp(options->tissues, "") != 0) {
     STRING_LIST_T *tissue_names = new_string_list_char_split(',', options->tissues);
-    // Sort the tissue names so that input order won't matter.
     options->n_tissues = get_num_strings(tissue_names);
+    if (options->n_tissues < 3) {
+      usage(false, "Illegal value for --tissues <tissues>: %s. Must be at least 3 tissue names.\n", options->tissues);
+    }
+    // Sort the tissue names so that input order won't matter.
     sort_string_list(tissue_names);
     options->tissue_names = tissue_names;
   }
@@ -798,7 +801,7 @@ static void output_html_file(
 
   // Output general information.
   jsonwr_bool_prop(json, "have_tss_info", link_table->have_tss_info);
-  jsonwr_lng_prop(json, "n_perms", N_PERMS);
+  jsonwr_lng_prop(json, "n_perms", link_table->n_perms);
   jsonwr_dbl_prop(json, "noise_fraction", NOISE_FRACTION);
 
   // Output Links.
@@ -950,7 +953,7 @@ static int compare_abs_correlation(
   const LINK_T *item2 = *(LINK_T **) p2;
   int cmp;
 
-  // Compare the |corelation| of two links.
+  // Compare the |correlation| of two links.
   if (fabs(item1->correlation) > fabs(item2->correlation)) {
     return(-1);
   } else if (fabs(item1->correlation) < fabs(item2->correlation)) {
@@ -1450,7 +1453,7 @@ static void output_links_tsv_file(
 	"%c\t"		// closest_locus
 	"%c\t"		// closest_tss
 	"%s\t"		// histone
-	"%0.8f\t"	// correlation
+	"%0.5f\t"	// correlation
 	"%0.3e\t" 	// corr_pvalue
 	"%0.3e\t"	// distance_pvalue
 	"%0.3e\t"	// cnd_pvalue
@@ -2313,7 +2316,7 @@ static void output_histone_tsv_file(
 
 /*************************************************************************
  * Add links for the current histone modification to the link table.
- * Compute null scores using permuted expression columns.
+ * Compute null scores using expression from a different link.
  *************************************************************************/
 static void get_correlations(
   TGENE_OPTIONS_T *options,
@@ -2321,48 +2324,28 @@ static void get_correlations(
   int first_link_index,		// current histone's links start here
   LINK_TABLE_T *link_table
 ) {
-  int i, j, k, link_i, array_i;
-  int n_links = link_table->n_links;
-  LINK_T **links = link_table->links;
+  int i, j, k, link_i;
+  LINK_T **links = link_table->links + first_link_index;	// points to links for this histone
+  int n_links = link_table->n_links - first_link_index;		// number of links for this histone
   int n_tissues = get_num_strings(options->tissue_names);
   int n_perms = link_table->n_perms;
-  double lecat = options->lecat;	// low expression correlation adjustment threshold
+  double lecat = options->lecat;				// low expression correlation adjustment threshold
 
   DEBUG_FMT(NORMAL_VERBOSE,
     "Getting the correlations for %d links for histone %s.\n", n_links, get_nth_string(i_hist, options->histone_names));
 
-  // Get the indices of the valid tissues for this histone.
-  int *valid_indices = (int *)mm_malloc(sizeof(int) * n_tissues);
-  bool *is_valid_index = (bool *)mm_malloc(sizeof(bool) * n_tissues);
-  int n_valid_tissues = 0;
-  for (j=0; j<n_tissues; j++) {
-    if (options->valid_tissues[i_hist][j]) {
-      is_valid_index[j] = true;
-      valid_indices[n_valid_tissues++] = j;
-    } else {
-      is_valid_index[j] = false;
-    }
-  }
-
-  // Create a random ordering of the tissue indices to use for computing null distribution.
-  double *perm_expr = (double *)mm_malloc(sizeof(double) * n_tissues);
-  int **perm = (int **) mm_malloc(sizeof(int *) * n_perms);
-  int *perm_indices = (int *)mm_malloc(sizeof(int) * n_valid_tissues);
-  srand_mt(options->seed);	// Make sure the permutation is not affected by other things.
+  // Set up for permuting expression values for null distribution.
+  DEBUG_FMT(NORMAL_VERBOSE, "  Creating %d permutations of %d link indices.\n", n_perms, n_links);
+  int **perms = (int **) mm_malloc(sizeof(int *) * n_perms);
+  srand_mt(options->seed);					// Make sure the permutations are not affected by other things.
   for (i=0; i<n_perms; i++) {
-    perm[i] = (int *)mm_malloc(sizeof(int) * n_tissues);
-    //for (j=0; j<n_tissues; j++) (perm[i])[j] = j;
-    //SHUFFLE(perm[i], n_tissues);
-    for (j=0; j<n_valid_tissues; j++) perm_indices[j] = valid_indices[j];
-    SHUFFLE(perm_indices, n_valid_tissues);
-    for (j=k=0; j<n_tissues; j++) {
-      (perm[i])[j] = is_valid_index[j] ? perm_indices[k++] : j;
-    }
+    perms[i] = (int *)mm_malloc(sizeof(int) * n_links);
+    for (j=0; j<n_links; j++) perms[i][j] = i;			// Set permutation to identity.
+    SHUFFLE(perms[i], n_links);					// Make a permutation of the indices.
   }
 
   // Compute correlation of each link.
-  array_i = 0;
-  for (link_i=first_link_index; link_i<n_links; link_i++) {
+  for (link_i=0; link_i<n_links; link_i++) {
     LINK_T *link = links[link_i];
     TRANSCRIPT_T *transcript = link->transcript;
     LOCUS_T *locus = link->locus;
@@ -2372,15 +2355,20 @@ static void get_correlations(
     if (lecat > 0 && link_max_expr(link) < lecat) {
       scale_factor = link_max_expr(link) / lecat;
     }
+    // Compute correlation of link.
     double rho = pearson_correlation(n_tissues, transcript->expr, locus->histone_level,
       NULL, NULL, NULL, NULL, true, options->valid_tissues[i_hist]);
       
     // Round results so order of tissues doesn't matter.
     RND(rho*scale_factor, 8, link->correlation);
 
-    // Compute correlation with permuted order of expression tissues.
+    // Compute correlation with permuted order of expression tissues.  Repeat n_perms times.
     for (i=0; i<n_perms; i++) {
-      for (j=0; j<n_tissues; j++) perm_expr[j] = transcript->expr[(perm[i])[j]];
+      int perm_i = perms[i][link_i];
+      // Check that permutation changed the link.
+      if (perm_i == link_i) perm_i = (link_i < n_links) ? perms[i][link_i+1] : perms[i][0]; 
+      LINK_T *perm_link = links[perm_i];
+      double *perm_expr = perm_link->transcript->expr;
       rho = pearson_correlation(n_tissues, perm_expr, locus->histone_level,
         NULL, NULL, NULL, NULL, true, options->valid_tissues[i_hist]);
       RND(rho*scale_factor, 8, link->perm_correlation[i]);
@@ -2388,12 +2376,8 @@ static void get_correlations(
   } // link 
 
   // Free space.
-  for (i=0; i<n_perms; i++) myfree(perm[i]);
-  myfree(perm);
-  myfree(perm_expr);
-  myfree(perm_indices);
-  myfree(valid_indices);
-  myfree(is_valid_index);
+  for (i=0; i<n_perms; i++) myfree(perms[i]);
+  myfree(perms);
 
 } // get_correlations
 
