@@ -5,6 +5,11 @@
  * PROJECT: TOMTOM
  * DESCRIPTION: Motif-Motif comparison using the score statistic.
  **************************************************************************/
+
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include <assert.h>
 #include <ctype.h>
 #include <errno.h>
@@ -722,6 +727,8 @@ void pearson_scores(
         SCORE_NUMERATOR
           += (get_matrix_cell(index_query, index, get_motif_freqs(query_motif)) - x_bar)
           * (get_matrix_cell(index_target, index, get_motif_freqs(target_motif)) - y_bar);
+        RND(SCORE_NUMERATOR, RNDDIG, SCORE_NUMERATOR);
+        //printf("SCORE_NUMERATOR = %.20f\n", SCORE_NUMERATOR);
 
         /*  The denominoator of the Pearson */
         SCORE_SQ_DENOMINATOR_1
@@ -736,6 +743,16 @@ void pearson_scores(
                - y_bar),
               2
               );
+        RND(SCORE_SQ_DENOMINATOR_1, RNDDIG, SCORE_SQ_DENOMINATOR_1);
+        RND(SCORE_SQ_DENOMINATOR_2, RNDDIG, SCORE_SQ_DENOMINATOR_2);
+        //printf(
+        //  "SCORE_SQ_DENOMINATOR_1 = %.20f\n", 
+        //  SCORE_SQ_DENOMINATOR_1
+        //);
+        //printf(
+        //  "SCORE_SQ_DENOMINATOR_2 = %.20f\n", 
+        //  SCORE_SQ_DENOMINATOR_2
+        //);
       } /* Nr and Dr components summed over the entire alphabet. */
 
       /*       Compute the Denominator */
@@ -1758,7 +1775,6 @@ static ARRAYLST_T *load_motifs(
 /*****************************************************************************
  * Tomtom program
  *****************************************************************************/
-VERBOSE_T verbosity = NORMAL_VERBOSE;
 #ifdef MAIN
 
 /*****************************************************************************
