@@ -5,6 +5,11 @@
  * PROJECT: EVOMCAST
  * COPYRIGHT: 1998-2004, W. S. N., UW
  *************************************************************************/
+
+#ifdef MAIN
+#define DEFINE_GLOBALS
+#endif
+
 #include "tree.h"
 #include "utils.h"
 #include "string-list.h"
@@ -315,8 +320,7 @@ int compute_depth
  * Add a given child to a tree.
  *************************************************************************/
 void add_child
-  (const VERBOSE_T verbosity,
-   TREE_T * const  a_child,
+  (TREE_T * const  a_child,
    TREE_T *        a_tree)
 {
   check_null_tree(a_tree);
@@ -370,8 +374,7 @@ TREE_T * get_nth_child
  * Does not free dynamic memory. 
  *************************************************************************/
 void remove_nth_child
-  (const VERBOSE_T verbosity,
-   const bool free_child,		// free child node?
+  (const bool free_child,		// free child node?
    const bool free_children, 	/* Boolean: Free children as well? */
    const int       n,
    TREE_T *        a_tree)
@@ -879,7 +882,7 @@ static void convert_to_uniform_star_tree_helper(
   if (is_leaf(the_tree)) {
     // add current leaf to new tree
     set_length(length, the_tree);
-    add_child(verbosity, the_tree, new_tree);
+    add_child(the_tree, new_tree);
   } else {
     int num_children = get_num_children(the_tree);
     int i_child;
@@ -923,7 +926,7 @@ TREE_T* reroot_tree(
       // Make it the root.
       // Start by making its old parent its child.
       // Then return the non-null current node.
-      add_child(verbosity, the_parent, the_tree);
+      add_child(the_parent, the_tree);
       return(the_tree);
     } else {
       // This leaf is not the one we want.
@@ -950,7 +953,6 @@ TREE_T* reroot_tree(
 	fprintf(stderr, "Rerooting- backing up from (%d).\n", i_child);
       }
       remove_nth_child(
-        verbosity,
         false,				// Don't free child node
         false,				// Don't go recursive
         i_child,
@@ -965,7 +967,7 @@ TREE_T* reroot_tree(
       set_length(new_length, the_tree);		// update current node's length
       if (the_parent != NULL) {
         // backing up towards old root
-	add_child(verbosity, the_parent, the_tree);
+	add_child(the_parent, the_tree);
         set_length(old_length, new_root);		// pass old length up to parent
       } else {
         // backed up to the old root
@@ -1223,7 +1225,6 @@ void free_tree
 #ifdef MAIN
 
 #include "simple-getopt.h"
-VERBOSE_T verbosity = NORMAL_VERBOSE;
 
 int main
   (int    argc,
@@ -1236,9 +1237,8 @@ int main
   int option_index = 0;
   char* option_name = NULL;
   char* option_value = NULL;
-	const char *  message = NULL;
+  const char* message = NULL;
   TREE_T *  the_tree = NULL;
-  VERBOSE_T verbosity = NORMAL_VERBOSE;
   cmdoption const options[] = {
     { "verbosity", REQUIRED_VALUE }
   };
@@ -1252,15 +1252,15 @@ int main
   strcat(usage, "\n");
 
   /* Parse the command line. */
-	simple_setopt(argc, argv, option_count, options);
+  simple_setopt(argc, argv, option_count, options);
   while(1) {
     // Read the next option, and break if we're done.
     c = simple_getopt(&option_name, &option_value, &option_index);
     if (c == 0) {
       break;
     } else if (c < 0) {
-    	simple_getopterror(&message);
-      die("Error processing command line options (%s)\n", message);
+      simple_getopterror(&message);
+      die("Error processing command line options: %s\n", message);
     }
 
     if (strcmp(option_name, "verbosity") == 0) {
