@@ -23,6 +23,7 @@ typedef int VERBOSE_T;
 #define HIGH_VERBOSE 3
 #define HIGHER_VERBOSE 4
 #define DUMP_VERBOSE 5
+DEXTERN(VERBOSE_T, verbosity, NORMAL_VERBOSE);
 
 #define BIG HUGE_VAL
 #define LITTLE -BIG
@@ -30,8 +31,6 @@ typedef int VERBOSE_T;
 
 #define SHUFFLE(base, n) shuffle(base, n, sizeof *(base))
 
-extern VERBOSE_T verbosity;
-
 /*
  * Support LLVM as a compiler.
  */
