@@ -1,4 +1,3 @@
-
 var alphabet = null;
 var sequences = null;
 var control_sequences = null;
@@ -33,7 +32,7 @@ function register_component(id, element, controler) {
 function check() {
   "use strict";
   var alphs = null;
-  var min_seqs = 2;		// Change MIN_SEQS in src/ame.c too if this changes.
+  var min_seqs = 3;		// Change MIN_SEQS in src/ame.c too if this changes.
   var num_sequences = 0;
   var num_control_sequences = 0;
   if (alphabet != null) {
@@ -44,6 +43,8 @@ function check() {
     if (alphs == null) alphs = sequences.get_alphabets();
     if (sequences.source.value == "file") {
       num_sequences = sequences.file_dbh.sequence_count;
+    } else if (sequences.source.value == "bedfile") {
+      num_sequences = sequences.bed_file_dbh.sequence_count;
     } else if (sequences.source.value == "text") {
       num_sequences = sequences.text_dbh.sequence_count;
     }
@@ -53,9 +54,11 @@ function check() {
       if(!control_sequences.check(alphs)) return false;
       if (alphs == null) alphs = control_sequences.get_alphabets();
       if (control_sequences.source.value == "file") {
-	num_control_sequences = control_sequences.file_dbh.sequence_count;
+	      num_control_sequences = control_sequences.file_dbh.sequence_count;
+      } else if (control_sequences.source.value == "bedfile") {
+        num_control_sequences = control_sequences.bed_file_dbh.sequence_count;
       } else if (control_sequences.source.value == "text") {
-	num_control_sequences = control_sequences.text_dbh.sequence_count;
+	      num_control_sequences = control_sequences.text_dbh.sequence_count;
       }
     }
   } else if ($("generate_on").checked) {
