@@ -789,8 +789,8 @@ SequenceInput.prototype.reset = function() {
   this.file_dbh.reset();
   this.text_area.value = "";
   this.text_dbh.reset();
-  this.bed_file_input.value = "";
-  this.bed_file_dbh.reset();
+  if (typeof this.bed_file_input != "undefined") this.bed_file_input.value = "";
+  if (typeof this.bed_file_dbh != "undefined") this.bed_file_dbh.reset();
   if (this.db_listing != null) this._clear_select(this.db_listing);
   if (this.db_version != null) this._clear_select(this.db_version);
   if (this.bed_file_db_listing != null) this._clear_select(this.bed_file_db_listing);
