@@ -465,6 +465,9 @@ function options_reset(evt) {
 function fix_reset() {
   on_alg_change(1);
   updateFilterMenu(); 		// update the filter menu from the first PTM file
+  // Make sure "Hidden Modifications" gets turned off on form reset.
+  var i, more_opts = document.getElementsByClassName("more_opts");
+  for (i=0; i<more_opts.length; i++) { toggle_class(more_opts[i], 'modified', false); }
 }
 
 function reloadpage() {
