@@ -277,8 +277,12 @@ function create_job_detail_background(item, inputs, even) {
   }
   input = inputs[item["key"]];
   source = input["source"];
-  if (source == "UNIFORM") {
+  if (source == "DEFAULT") {
+    value = document.createTextNode("The default background (depends on source of input sequences).");
+  } else if (source == "UNIFORM") {
     value = document.createTextNode("A uniform background.");
+  } else if (source == "NRDB") {
+    value = document.createTextNode("A background based on the NRDB frequencies.");
   } else if (source == "MEME") {
     value = document.createTextNode("The background specified in the motif input.");
   } else if (source == "FILE") {
@@ -295,6 +299,7 @@ function create_job_detail_background(item, inputs, even) {
     value = replace_tokens(text, "!!ORIG-NAME!!", fileOrig, "!!SAFE-NAME!!", fileSafe);
   } else { // source == "ORDER_X" where X is 0, 1, 2, 3 or 4
     order = input["order"];
+    if (typeof(order) == "undefined") { order = "default"; }
     value = document.createTextNode("A " + order + "-order background model generated from the supplied sequences.");
   }
   return create_row(even, item["name"], value);
