@@ -1,6 +1,7 @@
 var alphabet = null;
 var sequences = null;
 var control_sequences = null;
+var background = null;
 
 function register_component(id, element, controler) {
   "use strict";
@@ -20,6 +21,8 @@ function register_component(id, element, controler) {
     if (alphabet != null) {
       control_sequences.set_custom_alphabet(alphabet.has_custom_alphabet(), alphabet.get_custom_alphabet());
     }
+  } else if (id == "background") {
+    background = controler;
   }
 }
 
@@ -39,16 +42,20 @@ function check() {
   if (!check_int_value("motif count", "nmotifs", 1, null, 10)) return false;
   if (!check_int_range("minimum motif width", "minw", 8,
     "maximum motif width", "maxw", 15, 2, 30)) return false;
+  if (background != null && !background.check(alphs)) return false;
   return true;
 }
 
 function options_changed() {
+    if (background != null && background.changed()) return true;
   if (!/^\s*8\s*$/.test($("minw").value)) return true;
   if (!/^\s*15\s*$/.test($("maxw").value)) return true;
   if (!$("enable_pvt").checked) return true;
   if (!/^\s*0\.05\s*$/.test($("pvt").value)) return true;
+  if ($("notrim").checked) return true;
   if ($("order_enable").checked) return true;
   if (!$("align_center").checked) return true;
+  if (! $("pgc").checked) return true;
   return false;
 }
 
@@ -61,10 +68,12 @@ function options_reset(evt) {
   $("pvt").disabled = false;
   $("nmotifs").value = 10;
   $("nmotifs").disabled = true;
+  $("notrim").checked = false;
   $("order_enable").checked = false;
   $("order").value = 0;
   $("order").disabled = true;
   $("align_center").checked = true;
+  $("pgc").checked = true;
 }
 
 function fix_reset() {
