@@ -77,6 +77,7 @@ public final class SQL {
     "  avgLen REAL NOT NULL,\n" +
     "  stdDLen REAL NOT NULL,\n" +
     "  obsolete INTEGER DEFAULT 0,\n" +
+    "  fileSeqIndex TEXT,\n" +
     "  UNIQUE (listingId, alphabet, edition, fileSeq)\n" +
     ")";
   /** Create a table to store information about a prior file */
@@ -371,6 +372,7 @@ public final class SQL {
     "SELECT sequenceId, filePrior, fileDist, biosample, assay, source, url, description\n" +
      "FROM tblPriorFile WHERE id = ?";
 
+  /** The Category must contain the word "Genomes" and the sequences must be DNA. **/
   public static final String SELECT_DNA_FASTA_FILES =
    "SELECT tblSequenceFile.id, tblSequenceFile.fileSeq, tblSequenceFile.fileSeqIndex\n" +
    "FROM tblCategory, tblListing, tblSequenceFile\n" +
