@@ -177,7 +177,8 @@ public class FastaParser {
       // should be a continuation byte
       if ((currByte & 0xC0) == 0x80) { // 10xx xxxx
         // found a continuation byte
-        cVal |= (currByte & 0x3F) << (6 * (cLen - cPos - 1));
+        //cVal |= (currByte & 0x3F) << (6 * (cLen - cPos - 1));
+        cVal |= (currByte & 0x3F) << (6 * (cLen - cPos));
         if (cPos == cLen && cVal <= minimumCodepointValue[cLen]) {
           // codepoint uses more bytes than needed
           out.error(new FastaParseException(pos - cLen + 1, line, column, BAD_UTF8_OVERLONG_ENCODING));
