@@ -121,7 +121,7 @@ public class Streme extends SubmitJob<Streme.Data> {
         addArgs(args, "-genome-neg", ((LociDataSource)negSeq).getGenomeFileName());
       }
       addArgs(args, posSeq.getName());
-      if (pgc) addArgs(args, "-parse-genomic-coord");
+      if (! pgc) addArgs(args, "-no-pgc");
       return args.toString();
     }
   
@@ -270,7 +270,7 @@ public class Streme extends SubmitJob<Streme.Data> {
       data.dna2rna = paramBool(request, "dna2rna");
       // Align
       data.align = paramChoice(request, "align", "left", "center", "right");
-      // parse-genomic-coordinates
+      // parse genomic coordinates
       data.pgc = WebUtils.paramBool(request, "pgc");
       // background file
       data.background = background.getBfile(backgroundName, request, feedback);
