@@ -13,12 +13,19 @@ public abstract class AbstractFtpSource implements Source, FtpSource {
   public abstract String getRemoteDir();
   public abstract String getRemoteName();
   public abstract long getRemoteSize();
+
   public String getRemotePath() {
     return getRemoteDir() + getRemoteName();
   }
+
   public String getRemoteUrl() {
     return "ftp://" + getRemoteHost() + getRemotePath();
   }
+
+  public String getRemoteHttpUrl() {
+    return "http://" + getRemoteHost() + getRemotePath();
+  }
+
   public String getRemoteExt() {
     String name = getRemoteName();
     int firstDot = name.indexOf('.');
@@ -27,6 +34,7 @@ public abstract class AbstractFtpSource implements Source, FtpSource {
     }
     return "";
   }
+
   public String getLocalName() {
     return getNamePrefix() + getRemoteExt();
   }
