@@ -40,90 +40,135 @@ public class FtpFileListUpdater extends SequenceUpdater {
   private int retain;
   private String categoryName;
   private String listingSubdir;
+  private String DbRegexp;
 
   public FtpFileListUpdater(String division, SQLiteDataSource dataSource,
-      ReentrantReadWriteLock dbLock, File binDir, File dbDir,
+      ReentrantReadWriteLock dbLock, File binDir, File dbDir, String dbRegexp, String dbRel,
       ExecutorService worker, MultiSourceStatus status) {
-    super("Miscellaneous Source Downloader", dataSource, dbLock, binDir, dbDir, worker, status);
+    //super("Miscellaneous Source Downloader", dataSource, dbLock, binDir, dbDir, worker, status);
+    super("", dataSource, dbLock, binDir, dbDir, worker, status);
+    DbRegexp = dbRegexp;
     Properties conf = loadConf(FtpFileListUpdater.class, dbDir, "FtpFileListUpdater.properties");
     retain = getConfInt(conf, "retain", 1, null, 1);
     categoryName = conf.getProperty("category.name", "Other Databases");
     listingSubdir = conf.getProperty("listing.subdir", "MISC");
   }
 
-  private void downloadSource(CsvEntry entry, AlphStd alphabet, File dbTarget)
+  private int downloadSource(CsvEntry entry, AlphStd alphabet, File dbTarget)
       throws ExecutionException, InterruptedException, SQLException {
+    int nhave_databases = 0;
+    String listing_name = entry.name + (entry.version.equals("") ? "" : (" " + entry.version)) + " (" + alphabet + ")";
     String source;
     switch (alphabet) {
       case DNA: source = entry.dnaUrl; break;
       case PROTEIN: source = entry.proteinUrl; break;
-      default: throw new IllegalArgumentException("Only DNA or protein sources accepted");
+      default: throw new IllegalArgumentException("Only DNA or protein sources accepted.");
+    }
+    if (source.isEmpty()) {
+      logger.log(Level.WARNING, "No URL found in CSV entry '" + listing_name + "'.");
+      return 0;
     }
-    if (!source.isEmpty()) {
-      Matcher m = SOURCE_RE.matcher(source);
-      if (m.matches()) {
-        String host = m.group(2);
-        String path = m.group(3);
-        String name = m.group(4);
-        // Now attempt downloading it using FTP or HTTPS.
-        if (host.equals("https:")) {
-          // Use HTTPS.
-          Reader reader = null; 
-          String output = null;
-          try {
-            URL url = new URL(host + path + name);
-	    URLConnection connection = url.openConnection();
-            long lastModified = connection.getLastModified();
-            long sourceSize = connection.getContentLength();
-	    Calendar timestamp = Calendar.getInstance();
-	    timestamp.setTimeInMillis(lastModified);
-	    CsvSource httpSrc = new CsvSource(entry, alphabet, host, path, name, sourceSize, timestamp);
-	    if (!sourceExists(httpSrc, true)) {
-	      if (!downloadHttpSource(url, httpSrc)) return;
-	      enqueueSequences(new CsvSequenceProcessor(httpSrc, dbTarget));
-	    }
-	  } catch (IOException e) {
-	   logger.log(Level.SEVERE, "URL exception.");
-	  }
 
-        } else {
-          // Use FTP.
-	  FTPClient ftp = null;
-	  try {
-	    ftp = new FTPClient();
-	    if (!loginFtp(ftp, host)) throw new IOException("Unable to login to remote host: " + host);
-	    FTPFile[] sourceFiles = ftp.listFiles(path + name);
-	    if (sourceFiles.length == 0) throw new IOException("Unable to find remote file: " + path + name);
-	    if (sourceFiles.length != 1) throw new IOException("Too many files returned for query on remote file: " +
-		path + name);
-	    FTPFile sourceFile = sourceFiles[0];
-	    Calendar timestamp = sourceFile.getTimestamp();
-	    timestamp.getTimeInMillis();
-	    CsvSource ftpSrc = new CsvSource(entry, alphabet,
-		host, path, name, sourceFile.getSize(), sourceFile.getTimestamp());
-	    if (!sourceExists(ftpSrc, true)) {
-	      if (!downloadFtpSource(ftp, ftpSrc, true, RETRY_COUNT)) return;
-	      enqueueSequences(new CsvSequenceProcessor(ftpSrc, dbTarget));
-	    }
-	    ftp.logout();
-	    ftp.disconnect();
-	  } catch (IOException e) {
-	    logger.log(Level.SEVERE, "Skipping source: " + source, e);
-	  } finally {
-	    if (ftp != null && ftp.isConnected()) {
-	      try {
-		ftp.logout();
-	      } catch (IOException e) { /* ignore */ }
-	      try {
-		ftp.disconnect();
-	      } catch (IOException e) { /* ignore */ }
-	    } else {
-	      logger.log(Level.WARNING, "Source does not match FTP URL pattern:\n" + source);
-	    }
-	  }
-        } // FTP
-      }
+    // Parse URL for HTTPS and FTP.
+    Matcher m = SOURCE_RE.matcher(source);
+    if (! m.matches()) {
+      logger.log(Level.WARNING, "Failed to parse URL for CSV entry '" + listing_name + "'.");
+      return 0;
     }
+    String host = m.group(2);
+    String path = m.group(3);
+    String name = m.group(4);
+
+    // See if listing name matches db regular expression if we are updating, not just listing.
+    boolean matchFound = false;
+    if (! DbRegexp.equals("^$")) {
+      Pattern db_regexp = Pattern.compile(DbRegexp, Pattern.CASE_INSENSITIVE);
+      Matcher matcher = db_regexp.matcher(listing_name);
+      matchFound = matcher.find();
+    }
+
+    // Now attempt downloading it using FTP or HTTPS.
+    if (host.equals("https:")) {
+      // Use HTTPS.
+      Reader reader = null; 
+      String output = null;
+      try {
+	URL url = new URL(host + path + name);
+	URLConnection connection = url.openConnection();
+	long lastModified = connection.getLastModified();
+	long sourceSize = connection.getContentLength();
+	Calendar timestamp = Calendar.getInstance();
+	timestamp.setTimeInMillis(lastModified);
+	CsvSource httpSrc = new CsvSource(entry, alphabet, host, path, name, sourceSize, timestamp);
+	if (sourceExists(httpSrc, true)) {
+	  nhave_databases = 1;			// Don't download if already have it.
+	} else {
+	  // Listing only?
+	  if (DbRegexp.equals("^$")) {
+	    System.out.println("missing: " + listing_name);	// Missing database file.
+	  } else {
+	    // Download if matches --db_regexp.
+	    if (matchFound) {
+	      if (downloadHttpSource(url, httpSrc)) {
+		enqueueSequences(new CsvSequenceProcessor(httpSrc, dbTarget));
+		nhave_databases = 1;		// Now we have it. 
+	      }
+	    }
+          }
+	}
+      } catch (IOException e) {
+       logger.log(Level.SEVERE, "URL exception.");
+      }
+
+    } else {
+      // Use FTP.
+      FTPClient ftp = null;
+      try {
+	ftp = new FTPClient();
+	if (!loginFtp(ftp, host)) throw new IOException("Unable to login to remote host: " + host);
+	FTPFile[] sourceFiles = ftp.listFiles(path + name);
+	if (sourceFiles.length == 0) throw new IOException("Unable to find remote file: " + path + name);
+	if (sourceFiles.length != 1) throw new IOException("Too many files returned for query on remote file: " +
+	    path + name);
+	FTPFile sourceFile = sourceFiles[0];
+	Calendar timestamp = sourceFile.getTimestamp();
+	timestamp.getTimeInMillis();
+	CsvSource ftpSrc = new CsvSource(entry, alphabet,
+	    host, path, name, sourceFile.getSize(), sourceFile.getTimestamp());
+	if (sourceExists(ftpSrc, true)) {
+	  nhave_databases = 1;				// Don't download if already have it.
+        } else {
+	  // Listing only?
+	  if (DbRegexp.equals("^$")) {
+	    System.out.println("missing: " + listing_name);	// Missing database file.
+	  } else {
+	    // Download if matches --db_regexp.
+	    if (matchFound) {
+	      if (downloadFtpSource(ftp, ftpSrc, true, RETRY_COUNT)) {
+		enqueueSequences(new CsvSequenceProcessor(ftpSrc, dbTarget));
+		nhave_databases = 1;		// Now we have it. 
+	      }
+	    }
+          }
+	}
+	ftp.logout();
+	ftp.disconnect();
+      } catch (IOException e) {
+	logger.log(Level.SEVERE, "Skipping source: " + source, e);
+      } finally {
+	if (ftp != null && ftp.isConnected()) {
+	  try {
+	    ftp.logout();
+	  } catch (IOException e) { /* ignore */ }
+	  try {
+	    ftp.disconnect();
+	  } catch (IOException e) { /* ignore */ }
+	} else {
+	  logger.log(Level.WARNING, "Source does not match FTP URL pattern:\n" + source);
+	}
+      }
+    } // FTP
+    return nhave_databases;
   }
 
   public void markRemovedSourcesObsolete(File[] csvFiles) throws IOException, SQLException {
@@ -150,7 +195,6 @@ public class FtpFileListUpdater extends SequenceUpdater {
       Long categoryId = null;
       Long listingId;
       for (File csv : csvFiles) {
-        progress.setName(csv.getName() + " Downloader");
         reader = new SeqSourceReader(csv);
         while ((entry = reader.next()) != null) {
           // get the category in the db
@@ -221,15 +265,33 @@ public class FtpFileListUpdater extends SequenceUpdater {
     try {
       // download sources listed in CSV files
       for (File csv : csvFiles) {
-        progress.setName(csv.getName() + " Downloader");
+        int navailable_genomes = 0;
+        int nhave_genomes = 0;
+	if (DbRegexp.equals("^$")) {
+	  System.out.println("\nOther Updater - Listing Missing FASTA Files from Division '" + csv.getName() + "':\n");
+	} else {
+	  System.out.println("\nOther Updater - Downloading FASTA Files from '" + csv.getName() + "':\n");
+        }
         reader = new SeqSourceReader(csv);
         while ((entry = reader.next()) != null) {
           logger.log(Level.INFO, "Downloading entry " + entry.name);
-          downloadSource(entry, AlphStd.DNA, dbTarget);
-          downloadSource(entry, AlphStd.PROTEIN, dbTarget);
+          if (entry.has_dna) {
+            navailable_genomes++;
+            nhave_genomes += downloadSource(entry, AlphStd.DNA, dbTarget);
+          }
+          if (entry.has_prot) {
+            navailable_genomes++;
+            nhave_genomes += downloadSource(entry, AlphStd.PROTEIN, dbTarget);
+          }
           checkWorkerTasks();
         }
         reader.close(); reader = null;
+        // Report numbers of Available and Missing sequence files.
+        int nmissing_genomes = navailable_genomes - nhave_genomes;
+        String a_verb = (navailable_genomes == 1) ? " is " : " are ";
+        String m_verb = (nmissing_genomes == 1) ? " is " : " are ";
+	System.out.println("\nThere" + a_verb + navailable_genomes + " available sequence file(s) and " + 
+          (navailable_genomes - nhave_genomes) + m_verb + "missing.\n*******");
       }
     } finally {
       if (reader != null) {
@@ -267,8 +329,8 @@ public class FtpFileListUpdater extends SequenceUpdater {
       downloadSources(csvFiles, dbTarget);
       // check that we actually tried to do something
       if (csvFiles.length == 0) {
-        logger.log(Level.WARNING, "No csv files for miscellaneous sources in: " + confDir + "\n" +
-            "(you probably want to copy in the default CSV files provided in the distribution's etc folder)");
+        logger.log(Level.WARNING, "No CSV files for miscellaneous sources in: " + confDir + "\n" +
+            "(you probably want to copy in the default CSV files provided in the distribution's etc/ folder)");
         progress.setTask("No CSV's provided");
       }
     } catch (Exception e) {
@@ -287,6 +349,7 @@ public class FtpFileListUpdater extends SequenceUpdater {
     public SeqSourceReader(File csv) throws FileNotFoundException, UnsupportedEncodingException {
       reader =  new BufferedReader(new InputStreamReader(new FileInputStream(csv), "UTF-8"));
     }
+
     public CsvEntry next() throws IOException {
       String line;
       Pattern categoryPattern = Pattern.compile("^-*(.*?)-*$");
@@ -298,6 +361,8 @@ public class FtpFileListUpdater extends SequenceUpdater {
           continue;
         }
         String root = parts[0].trim();
+        boolean has_prot = parts[1].trim().equals("yes");
+        boolean has_dna = parts[2].trim().equals("yes");
         String name = parts[4].trim();
         if (root.length() == 0) {
           // category
@@ -316,7 +381,8 @@ public class FtpFileListUpdater extends SequenceUpdater {
           String description = parts[5].trim();
           String proteinUrl = parts[6].trim();
           String dnaUrl = parts.length >= 8 ? parts[7].trim() : "";
-          return new CsvEntry(category, root, name, description, dnaUrl, proteinUrl);
+          String version = parts.length >= 9 ? parts[8].trim() : "";
+          return new CsvEntry(category, root, has_prot, has_dna, name, description, dnaUrl, proteinUrl, version);
         }
       }
       return null;
@@ -340,7 +406,8 @@ public class FtpFileListUpdater extends SequenceUpdater {
     public void process() throws IOException, SQLException, InterruptedException {
       if (!unpackSequences(source, dbTarget)) return;
       processSequences(source, dbTarget);
-      obsoleteOldEditions(recordSequences(source, dbTarget, listingSubdir).listingId, source.guessAlphabet(), retain);
+      //obsoleteOldEditions(recordSequences(source, dbTarget, listingSubdir).listingId, source.guessAlphabet(), retain);
+      recordSequences(source, dbTarget, listingSubdir);
     }
   }
 
@@ -439,24 +506,45 @@ public class FtpFileListUpdater extends SequenceUpdater {
 
     @Override
     public String getSequenceVersion() {
-      return DateFormat.getDateInstance(DateFormat.MEDIUM).format(timestamp.getTime());
+      String version;
+      if (entry.version.equals("")) {
+	version = DateFormat.getDateInstance(DateFormat.MEDIUM).format(timestamp.getTime());
+      } else {
+        version = entry.version;
+      }
+      return version;
     }
 
     @Override
     public String getSequenceDescription() {
       StringBuilder builder = new StringBuilder();
+      String remoteHost = getRemoteHost();
+      String remoteUrl;
+      if (remoteHost.equals("https:")) { 
+        remoteUrl = remoteHost + getRemotePath();;
+      } else {
+        remoteUrl = getRemoteUrl();
+      }
       builder.append("Downloaded from ");
-      builder.append("<a href=\"").append(this.getRemoteUrl()).append("\">");
-      builder.append(this.getRemoteUrl());
+      builder.append("<a href=\"").append(remoteUrl).append("\">");
+      builder.append(remoteUrl);
       builder.append("</a>.");
       return builder.toString();
     }
 
     @Override
     public String getNamePrefix() {
-      DateFormat simple = new SimpleDateFormat("dd-MM-yyyy");
-      Date lastModifiedDate = new Date(timestamp.getTimeInMillis());
-      return entry.root + "_" + alphabet.name() + "_" + simple.format(lastModifiedDate);
+      String Version;
+      if (entry.version.equals("")) {
+        // Use date as version.
+	DateFormat simple = new SimpleDateFormat("dd-MM-yyyy");
+	Date lastModifiedDate = new Date(timestamp.getTimeInMillis());
+        Version = simple.format(lastModifiedDate); 
+      } else {
+        Version = entry.version;
+      }
+      //return entry.root + "_" + alphabet.name() + "_" + Version;
+      return entry.root + "_" + Version;
     }
 
     @Override
@@ -538,18 +626,24 @@ public class FtpFileListUpdater extends SequenceUpdater {
   private static class CsvEntry {
     public final String category;
     public final String root;
+    public final boolean has_prot;
+    public final boolean has_dna;
     public final String name;
     public final String description;
     public final String dnaUrl;
     public final String proteinUrl;
-    public CsvEntry(String category, String root, String name,
-        String description, String dnaUrl, String proteinUrl) {
+    public final String version;
+    public CsvEntry(String category, String root, boolean has_prot, boolean has_dna, String name,
+        String description, String dnaUrl, String proteinUrl, String version) {
       this.category = category;
       this.root = root;
+      this.has_prot = has_prot;
+      this.has_dna = has_dna;
       this.name = name;
       this.description = description;
       this.dnaUrl = dnaUrl;
       this.proteinUrl = proteinUrl;
+      this.version = version;
     }
   }
 }
