@@ -34,14 +34,18 @@ public class GenbankUpdater extends SequenceUpdater {
   private String ftpLog;
   private int retain;
   private String categoryName;
+  private String DbRegexp;
   private String dbSubdir;
+  private String Division;
   private String ftpSubdir;
   private Logger logger;
 
   public GenbankUpdater(String division, SQLiteDataSource dataSource,
-      ReentrantReadWriteLock dbLock, File binDir, File dbDir,
+      ReentrantReadWriteLock dbLock, File binDir, File dbDir, String dbRegexp, String dbRel,
       ExecutorService worker, MultiSourceStatus multiStatus) {
-    super("GenBank Genome Downloader", dataSource, dbLock, binDir, dbDir, worker, multiStatus);
+    super("GenBank Updater", dataSource, dbLock, binDir, dbDir, worker, multiStatus);
+    DbRegexp = dbRegexp;
+    Division = division;
 
     // Set the common properties.
     Properties conf = loadConf(GenbankUpdater.class, dbDir, "GenbankUpdater.properties");
@@ -60,6 +64,7 @@ public class GenbankUpdater extends SequenceUpdater {
   protected int queryReleaseNumber(FTPClient ftp) throws IOException {
     final String RELEASE_NUMBER_FILE = path + "GB_Release_Number";
     FTPFile[] files = ftp.listFiles(RELEASE_NUMBER_FILE);
+
     if (files.length == 0) throw new IOException("Could not find the release number file \"" +
         RELEASE_NUMBER_FILE + "\".");
     if (files.length != 1) throw new IOException("Got more than one file returned for the release number file \"" +
@@ -92,8 +97,9 @@ public class GenbankUpdater extends SequenceUpdater {
   protected List<GenbankGenome> queryAvailableGenomes(FTPClient ftp) throws IOException {
     Pattern dna = Pattern.compile("^.*\\.fna$");
     Pattern protein = Pattern.compile("^.*\\.faa$");
-    progress.setTask("Querying Avaliable Genomes", 0, -1);
-    int releaseNumber = queryReleaseNumber(ftp);
+    //progress.setTask("Querying Avaliable Databases for division '" + Division + "'", 0, -1);
+    //int releaseNumber = queryReleaseNumber(ftp);
+    String releaseNumber = "ARCHIVE";
     logger.log(Level.INFO, "Got release number " + releaseNumber);
     List<GenbankGenome> genomes = new ArrayList<GenbankGenome>();
 
@@ -171,7 +177,7 @@ public class GenbankUpdater extends SequenceUpdater {
       }
       if (!loginFtp(ftp, host)) return null;
 
-      // Get the list of available genomes.
+      // Get the list of available genomes for this division.
       List<GenbankGenome> genomes = queryAvailableGenomes(ftp);
       if (genomes.isEmpty()) {
         logger.log(Level.SEVERE, "Failed parsing the genome releases from the FAQ... No genomes found!");
@@ -180,22 +186,51 @@ public class GenbankUpdater extends SequenceUpdater {
 
       // Query the database to see which genomes we already have
       // and remove them so we don't download them again.
-      progress.setTask("Excluding Pre-exisiting Genomes", 0, -1);
+      // Only download genomes whose genome name matches the species regex.
+      if (DbRegexp.equals("^$")) {
+        System.out.println("\nGenBank Updater - Listing Missing FASTA files from Division '" + Division + "':\n");
+      } else {
+        System.out.println("\nGenBank Updater - Downloading FASTA files from Division '" + Division + "':\n");
+        progress.setTask("Excluding Pre-exisiting Genomes", 0, -1);
+      }
       int navailable_genomes = 0;
-      int nremoved_genomes = 0;
+      int nhave_genomes = 0;
+      int nskipped_genomes = 0;
+      Pattern db_regexp = Pattern.compile(DbRegexp, Pattern.CASE_INSENSITIVE);
       Iterator<GenbankGenome> iterator = genomes.iterator();
+      String[] missingGenomes = new String[genomes.size()];
+      int nmissing = 0;
       while (iterator.hasNext()) {
-        GenbankGenome genome = iterator.next();
         navailable_genomes++;
+        GenbankGenome genome = iterator.next();
         if (sourceExists(genome, true)) {
           iterator.remove();
           logger.log(Level.INFO, "Already have " + genome);
-          nremoved_genomes++;
+          nhave_genomes++;
+          continue;
+        }
+        String listing_name = String.valueOf(genome);
+        Matcher matcher = db_regexp.matcher(listing_name);
+        boolean matchFound = matcher.find();
+        if (! matchFound) {
+          // List available genomes?
+          if (DbRegexp.equals("^$")) missingGenomes[nmissing++] = "missing: " + listing_name;
+          iterator.remove();
+          nskipped_genomes++;
+          continue;
         }
       }
-      logger.log(Level.INFO, "Number of AVAILABLE genomes: " + navailable_genomes);
-      logger.log(Level.INFO, "Number of genomes to UPDATE: " + (navailable_genomes - nremoved_genomes));
-      if (genomes.isEmpty()) return null;
+      // Print missing genomes, sorted.
+      if (DbRegexp.equals("^$") && nmissing > 0) {
+        String[] resizedArray = Arrays.copyOf(missingGenomes, nmissing);
+        Arrays.sort(resizedArray);
+        for (String missing : resizedArray) {
+          System.out.println(missing);
+        }
+      }
+      logger.log(Level.INFO, "Number of genomes AVAILABLE: " + navailable_genomes);
+      logger.log(Level.INFO, "Number of genomes HAVE: " + nhave_genomes);
+      logger.log(Level.INFO, "Number of genomes SKIPPED: " + nskipped_genomes);
 
       genome_loop:
       for (GenbankGenome genome : genomes) {
@@ -207,6 +242,7 @@ public class GenbankUpdater extends SequenceUpdater {
             if (!downloadFtpSource(ftp, source, true, RETRY_COUNT)) continue genome_loop;
           }
           enqueueSequences(new GenbankSequenceProcessor(genome, dbTarget));
+          nhave_genomes++;
         } catch (IOException e) {
           logger.log(Level.WARNING, "Skipped " + genome + " due to ftp errors", e);
           errorCount++;
@@ -217,6 +253,12 @@ public class GenbankUpdater extends SequenceUpdater {
       ftp.disconnect();
       progress.complete();
       waitForWorkerTasks();
+      // Report numbers of Available and Missing sequence files.
+      int nmissing_genomes = navailable_genomes - nhave_genomes;
+      String a_verb = (navailable_genomes == 1) ? " is " : " are ";
+      String m_verb = (nmissing_genomes == 1) ? " is " : " are ";
+      System.out.println("\nThere" + a_verb + navailable_genomes + " sequence file(s) and " +
+        (navailable_genomes - nhave_genomes) + m_verb + "missing.\n*******");
       logger.log(Level.INFO, "Finished update of " + categoryName);
     } catch (ExecutionException e) { // only thrown by sequence processor
       cancelWorkerTasks();
@@ -261,12 +303,16 @@ public class GenbankUpdater extends SequenceUpdater {
     public void process() throws IOException, SQLException, InterruptedException {
       if (!unpackSequences(source, dbTarget)) return;
       processSequences(source, dbTarget);
-      obsoleteOldEditions(recordSequences(source, dbTarget, dbSubdir).listingId, source.guessAlphabet(), retain);
+      // GenBank is no longer being updated so no need to update regularly.
+      //obsoleteOldEditions(recordSequences(source, dbTarget, dbSubdir).listingId, source.guessAlphabet(), retain);
+      // Record new sequences and don't obsolete old ones.
+      // Delete old files manually and then run with --purge_only.
+      recordSequences(source, dbTarget, dbSubdir);
     }
   }
 
   private class GenbankGenome implements Source {
-    private int version;
+    private String version;
     private String group;
     private String id;
     private AlphStd alphabet;
@@ -283,7 +329,7 @@ public class GenbankUpdater extends SequenceUpdater {
     private double seqStdDLen;
     private long seqTotalLen;
 
-    public GenbankGenome(int version, String group, String id,
+    public GenbankGenome(String version, String group, String id,
         AlphStd alphabet, String path, Pattern ftpPattern) {
       this.version = version;
       this.group = group;
@@ -313,7 +359,7 @@ public class GenbankUpdater extends SequenceUpdater {
     }
 
     public String toString() {
-      return "GenBank v" + version + " " + id.replace('_', ' ').trim() + " (" + alphabet + ")";
+      return "GenBank " + id.replace('_', ' ').trim() + " (" + alphabet + ")";
     }
 
     @Override
@@ -348,12 +394,13 @@ public class GenbankUpdater extends SequenceUpdater {
 
     @Override
     public long getSequenceEdition() {
-      return version;
+      //return version;
+      return 0;
     }
 
     @Override
     public String getSequenceVersion() {
-      return Integer.toString(version);
+      return version;
     }
 
     @Override
