@@ -25,10 +25,11 @@ import java.util.regex.Matcher;
  * Download promoters from RSA Tools for specified groupings.
  */
 public class RsatUpdater extends SequenceUpdater {
-  private int ageMin;
   private int start;
   private int end;
   private int retain;
+  private String Division;
+  private String DbRegexp;
   private String categoryName;
   private String dbSubdir;
   private String ftpSubdir;
@@ -36,13 +37,14 @@ public class RsatUpdater extends SequenceUpdater {
   private String group;
   private Pattern taxare;
   private Logger logger;
-
-  //private static Logger logger = Logger.getLogger("au.edu.uq.imb.memesuite.updatedb.rsat");
   private static final int RSAT_RETRIEVER_ID = 4;
 
-  public RsatUpdater(String division, SQLiteDataSource dataSource, ReentrantReadWriteLock dbLock,
-      File binDir, File dbDir, ExecutorService worker, MultiSourceStatus multiStatus) {
-    super("RSAT Upstream Downloader", dataSource, dbLock, binDir, dbDir, worker, multiStatus);
+  public RsatUpdater(String division, SQLiteDataSource dataSource, 
+      ReentrantReadWriteLock dbLock, File binDir, File dbDir, String dbRegexp, String dbRel,
+      ExecutorService worker, MultiSourceStatus multiStatus) {
+    super("Upstream Sequence Updater", dataSource, dbLock, binDir, dbDir, worker, multiStatus);
+    Division = division;
+    DbRegexp = dbRegexp;
 
     // Set global group.
     group = division.substring(4);
@@ -51,7 +53,6 @@ public class RsatUpdater extends SequenceUpdater {
     String wsdlDir = binDir.getPath().replace("libexec", "share");
 
     Properties conf = SequenceUpdater.loadConf(RsatUpdater.class, dbDir, "RsatUpdater.properties");
-    this.ageMin = getConfInt(conf, "age.min", 0, null, 30);
     this.start = getConfInt(conf, "start", null, null, -1000);
     this.end = getConfInt(conf, "end", null, null, 200);
     this.retain = getConfInt(conf, "retain", 1, null, 1);
@@ -287,42 +288,90 @@ public class RsatUpdater extends SequenceUpdater {
 
       // Create subdirectory.
       dbTarget = new File(dbDir + "/" + dbSubdir);
-      logger.log(Level.INFO, "Creating subdirectory for genomes: " + dbTarget);
+      logger.log(Level.INFO, "Creating subdirectory for upstream sequences: " + dbTarget);
       if (!dbTarget.exists() && !dbTarget.mkdir()) {
         logger.log(Level.SEVERE, "Unable to create subdirectory " + dbTarget + "!");
         return null;
       }
 
+      // Get the list of available genomes.
       logger.log(Level.INFO, "Querying RSAT " + group + " server at URL " + server);
       List<RsatSource> serverGenomes = queryAvailableOrganisms(group, server);
       if (serverGenomes.isEmpty()) {
 	logger.log(Level.WARNING, "Empty supported organism list from RSAT " + group +
 	  " at URL " + server);
+        return null;
       } else {
 	logger.log(Level.INFO, "RSAT " + group + " at URL " + server + " lists " +
 	    serverGenomes.size() + " supported organisms; the last one is " +
 	    serverGenomes.get(serverGenomes.size() - 1).getOrganism());
       }
-      progress.setTask("Excluding Pre-exisiting " + group + " upstream sequences", 0, -1);
       // Query the database to see which organisms we already have
-      // and remove them so we don't download them again.
-      long updateDelayMillis = TimeUnit.DAYS.toMillis(ageMin);
+      // and remove them from the list so we don't download them again.
+      // Only download genomes whose genome name matches the species regexp.
+      if (DbRegexp.equals("^$")) {
+        System.out.println("\nUpstream Sequences Updater - Listing Missing FASTA files from Division '" + Division + "':\n");
+      } else {
+        System.out.println("\nUpstream Sequences Updater - Downloading FASTA files from Division '" + Division + "':\n");
+        progress.setTask("Excluding Pre-exisiting Genomes", 0, -1);
+      }
+      int navailable_genomes = 0;
+      int nhave_genomes = 0;
+      int nskipped_genomes = 0;
+      Pattern db_regexp = Pattern.compile(DbRegexp, Pattern.CASE_INSENSITIVE);
       Iterator<RsatSource> iterator = serverGenomes.iterator();
+      long updateDelayMillis = TimeUnit.DAYS.toMillis(1000000000);	// ignore difference in file date
+      String[] missingGenomes = new String[serverGenomes.size()];
+      int nmissing = 0;
       while (iterator.hasNext()) {
 	RsatSource genome = iterator.next();
-	if (sourceExists(genome, true, false, updateDelayMillis)) {
+        String listing_name = String.valueOf(genome);
+        navailable_genomes++;
+        if (sourceExists(genome, true, false, updateDelayMillis)) {
 	  iterator.remove();
-	  logger.log(Level.INFO, "Already updated " + genome + " within " + ageMin + " day(s) ago.");
+	  logger.log(Level.INFO, "Already have" + genome);
+          nhave_genomes++;
+          continue;
 	}
+        Matcher matcher = db_regexp.matcher(listing_name);
+        boolean matchFound = matcher.find();
+        if (! matchFound) {
+          // List available genomes?
+          if (DbRegexp.equals("^$")) missingGenomes[nmissing++] = "missing: " + listing_name;
+          iterator.remove();
+          nskipped_genomes++;
+          continue;
+        }
       }
+      // Print missing genomes, sorted.
+      if (DbRegexp.equals("^$") && nmissing > 0) {
+        String[] resizedArray = Arrays.copyOf(missingGenomes, nmissing);
+        Arrays.sort(resizedArray);
+        for (String missing : resizedArray) {
+          System.out.println(missing);
+        }
+      }
+      logger.log(Level.INFO, "Number of genomes AVAILABLE: " + navailable_genomes);
+      logger.log(Level.INFO, "Number of genomes HAVE: " + nhave_genomes);
+      logger.log(Level.INFO, "Number of genomes SKIPPED: " + nskipped_genomes);
+      logger.log(Level.INFO, "Number of genomes to UPDATE: " + (navailable_genomes - nskipped_genomes - nhave_genomes));
 
       for (RsatSource source : serverGenomes) {
 	if (Thread.currentThread().isInterrupted()) throw new InterruptedException();
 	checkWorkerTasks();
-	if (downloadSequence(source)) enqueueSequences(new RsatSequenceProcessor(source, dbTarget));
+	if (downloadSequence(source)) {
+          enqueueSequences(new RsatSequenceProcessor(source, dbTarget));
+          nhave_genomes++;
+        }
       }
       progress.complete();
       waitForWorkerTasks();
+      // Report numbers of Available and Missing sequence files.
+      int nmissing_genomes = navailable_genomes - nhave_genomes;
+      String a_verb = (navailable_genomes == 1) ? " is " : " are ";
+      String m_verb = (nmissing_genomes == 1) ? " is " : " are ";
+      System.out.println("\nThere" + a_verb + navailable_genomes + " available sequence file(s) and " +
+        (navailable_genomes - nhave_genomes) + m_verb + "missing.\n*******");
       logger.log(Level.INFO, "Finished RSAT update");
     } catch (ExecutionException e) { // only thrown by sequence processor
       cancelWorkerTasks();
