@@ -59,6 +59,8 @@ public abstract class SequenceUpdater implements Callable<Void> {
 
   protected static Pattern dnaFilePattern1 = Pattern.compile("^.*\\.dna\\.primary_assembly\\.fa\\.gz$");
   protected static Pattern dnaFilePattern2 = Pattern.compile("^.*\\.dna\\.toplevel\\.fa\\.gz$");
+  protected static Pattern dnaFilePattern3 = Pattern.compile("^.*\\.dna_sm\\.primary_assembly\\.fa\\.gz$");
+  protected static Pattern dnaFilePattern4 = Pattern.compile("^.*\\.dna_sm\\.toplevel\\.fa\\.gz$");
   protected static Pattern aaFilePattern = Pattern.compile("^.*\\.pep\\.all\\.fa\\.gz$");
   protected static Pattern aiFilePattern = Pattern.compile("^.*\\.pep\\.abinitio\\.fa\\.gz$");
   protected static Pattern releasePattern = Pattern.compile("/release-(\\d+)/");
@@ -83,129 +85,6 @@ public abstract class SequenceUpdater implements Callable<Void> {
     progress = new Progress(status, name);
   }
 
-  // Read a JSON object from the Ensembl REST interface.
-  protected String ensemblRestRead(URL url) {
-    String output = "";
-    Reader reader = null;
-
-    try {
-      URLConnection connection = url.openConnection();
-      HttpURLConnection httpConnection = (HttpURLConnection)connection;
-
-      httpConnection.setRequestProperty("Content-Type", "application/json");
-
-      InputStream response = connection.getInputStream();
-      int responseCode = httpConnection.getResponseCode();
-
-      if (responseCode != 200) {
-        throw new RuntimeException("Response code was not 200. Detected response was " + responseCode);
-      }
-
-      // Read from the REST interface.
-      reader = new BufferedReader(new InputStreamReader(response, "UTF-8"));
-      StringBuilder builder = new StringBuilder();
-      char[] buffer = new char[8192];
-      int read;
-      while ((read = reader.read(buffer, 0, buffer.length)) > 0) {
-        builder.append(buffer, 0, read);
-      }
-      output = builder.toString();
-    } catch (IOException e) {
-     logger.log(Level.SEVERE, "URL exception.");
-    } finally {
-      if (reader != null) try {
-        reader.close();
-      } catch (IOException logOrIgnore) {
-        logOrIgnore.printStackTrace();
-      }
-    }
-
-    return output;
-  } // ensemblRestRead()
-
-protected List<EnsemblGenome> ensemblAvailableGenomes(
-  String genomeRelease, boolean abinitio, int retrieverId, String categoryName, 
-  String host, String rootDir, String restSubdir, Map<String, String> name2Subdir) {
-    progress.setTask("Querying available genomes using REST", 0, -1);
-    List<EnsemblGenome> genomes = new ArrayList<EnsemblGenome>();
-
-    // get a listing of species
-    try {
-      logger.log(Level.INFO, "Starting Update of " + categoryName);
-
-      // Create the REST query.
-      String server = "https://rest.ensembl.org";
-      String ext = "/info/genomes/division/" + restSubdir + "?";
-      URL url = new URL(server + ext);
-
-      // Query the REST interface.
-      String output = ensemblRestRead(url);
-
-      // Parse the JSON string.
-      JSONParser parser = new JSONParser();
-      try {
-        Object obj = parser.parse(output);
-        JSONArray array = (JSONArray) obj;
-        Iterator itr = array.iterator();
-        boolean first_genome = true;
-        while (itr.hasNext()) {
-          JSONObject jenome = (JSONObject) itr.next();
-          String displayName = jenome.get("display_name").toString();
-          logger.log(Level.INFO, "Display Name: " + displayName);
-          String scientificName = jenome.get("scientific_name").toString();
-          String ftpDirName = jenome.get("name").toString();
-          String path = rootDir;
-          // Add the collection name to the path.
-          String collection = name2Subdir.get(ftpDirName);
-          if (collection != null) { path += collection; }
-          path += ftpDirName;
-          String dnaPath = path + "/dna/";
-          String proteinPath = path + "/pep/";
-          logger.log(Level.FINE, "Adding Ensembl DNA and protein genomes for " + displayName);
-          if (! abinitio) {
-            genomes.add(new EnsemblGenome(genomeRelease, retrieverId, categoryName, displayName, ftpDirName, AlphStd.DNA, false, dnaPath, host, dnaFilePattern1, dnaFilePattern2));
-          }
-          genomes.add(new EnsemblGenome(genomeRelease, retrieverId, categoryName, displayName, ftpDirName, AlphStd.PROTEIN, abinitio, proteinPath, host, abinitio ? aiFilePattern : aaFilePattern));
-        }
-      } catch(ParseException pe) {
-        logger.log(Level.SEVERE, "position: " + pe.getPosition());
-      }
-    } catch (IOException e) {
-     logger.log(Level.SEVERE, "URL exception in ensemblAvailableGenomes.");
-    }
-    return genomes;
-  } // ensemblAvailableGenomes
-
-  //
-  // Make a Map of from the name of the species to its directory.
-  // The species directory MUST be either:
-  //   1) in the baseDir, or
-  //   2) in a subdirectory of it named "*_collection".
-  //
-  protected Map<String, String> makeMapName2Subdir(
-    FTPClient ftpClient, String rootDir
-  ) throws IOException {
-    Map<String, String> map = new HashMap<>();
-
-    FTPFile[] topFiles = ftpClient.listFiles(rootDir);
-    for (FTPFile aFile : topFiles) {
-      Matcher m = collectionPattern.matcher(aFile.getName());
-      if (m.find()) {
-        String collectionName = aFile.getName();
-        String subDir = rootDir + collectionName + "/";
-        FTPFile[] subFiles = ftpClient.listFiles(subDir);
-        for (FTPFile bFile : subFiles) {
-          // System.out.println(subDir + "\t" + bFile.getName());
-          map.put(bFile.getName(), collectionName + "/");
-        }
-      } else {
-        // System.out.println(rootDir + "\t" + aFile.getName());
-        map.put(aFile.getName(), "");
-      }
-    }
-    return map;
-  } // makeMapName2Subdir
-
   protected boolean determineFtpSource(String host, FTPClient ftp, EnsemblGenome genome, int retryCount) throws IOException, InterruptedException {
     for (int attempt = 1; attempt <= retryCount; attempt++) {
       try {
@@ -230,8 +109,9 @@ protected List<EnsemblGenome> ensemblAvailableGenomes(
   }
 
   protected boolean determineFtpSource(FTPClient ftp, EnsemblGenome genome) throws IOException {
-    progress.setTask("Determining full URL for " + genome, 0, -1);
+    //progress.setTask("Determining full URL for " + genome, 0, -1);
     PatternFileFilter filter = new PatternFileFilter(genome.getFilePattern());
+    logger.log(Level.INFO, "Looking for Host: " + genome.getRemoteHost() + " Dir: " + genome.getRemoteDir());
     logger.log(Level.INFO, "Looking for " + genome + " sequences at ftp://" + genome.getRemoteHost() + genome.getRemoteDir());
     FTPFile sequenceFile = filter.best(ftp.listFiles(genome.getRemoteDir(), filter));
     if (sequenceFile == null) {
@@ -280,12 +160,13 @@ protected List<EnsemblGenome> ensemblAvailableGenomes(
       resultSet.close();
       ps.close();
       if (deobsolete && exists && obsolete) {
+	//TLB: added next line to prevent deadlock
+        dbLock.readLock().unlock();
         dbLock.writeLock().lock();
         try {
           ps = conn.prepareStatement(MARK_SEQUENCE_FILE);
           ps.setInt(1, 0); // set obsolete = 0
           ps.setLong(2, fileId);
-          ps.executeUpdate();
           ps.close();
         } finally {
            dbLock.writeLock().unlock();
@@ -316,7 +197,7 @@ protected List<EnsemblGenome> ensemblAvailableGenomes(
     ftp.setDefaultTimeout(REPLY_TIMEOUT);
     ftp.setAutodetectUTF8(true);
     logger.log(Level.INFO, "Attempting connection (" + host + ").");
-    progress.setTask("Attempting connection to " + host, 0, -1);
+    //progress.setTask("Attempting connection to " + host, 0, -1);
     ftp.connect(host);
     reply = ftp.getReplyCode();
     if (!FTPReply.isPositiveCompletion(reply)) {
@@ -325,14 +206,14 @@ protected List<EnsemblGenome> ensemblAvailableGenomes(
       return false;
     }
     logger.log(Level.INFO, "Logging in (" + host + ").");
-    progress.setTask("Logging in", 0, -1);
+    //progress.setTask("Logging in", 0, -1);
     if (!ftp.login("anonymous", "meme-suite@uw.edu")) {
       logger.log(Level.SEVERE, "Log in attempt failed (" + host + ").");
       ftp.disconnect();
       return false;
     }
     logger.log(Level.INFO, "Setting file type to binary (" + host + ").");
-    progress.setTask("Setting file type to binary", 0, -1);
+    //progress.setTask("Setting file type to binary", 0, -1);
     if (!ftp.setFileType(FTP.BINARY_FILE_TYPE)) {
       logger.log(Level.SEVERE, "Unable to set file type to binary (" + host + ").");
       ftp.disconnect();
@@ -389,7 +270,7 @@ protected List<EnsemblGenome> ensemblAvailableGenomes(
     boolean reconnectAfterTransfer = false;
     try {
       long downloaded = (target.exists() && supportResume ? target.length() : 0);
-      progress.setTaskPartDone(downloaded);
+      //progress.setTaskPartDone(downloaded);
       out = new FileOutputStream(target, supportResume);
       if (supportResume) ftp.setRestartOffset(downloaded);
       in = ftp.retrieveFileStream(source.getRemotePath());
@@ -473,7 +354,7 @@ protected List<EnsemblGenome> ensemblAvailableGenomes(
   }
 
   protected boolean downloadHttpSource(URL url, FtpSource source) throws IOException, ExecutionException, InterruptedException {
-    progress.setTask("Downloading " + source, 0, source.getRemoteSize());
+    //progress.setTask("Downloading " + source, 0, source.getRemoteSize());
     // create the downloads directory if it does not exist
     File downloadDir = new File(dbDir, "downloads");
     if (downloadDir.exists()) {
