@@ -35,17 +35,19 @@ public class UCSCGenomeUpdater extends SequenceUpdater {
   private String path;
   private String ftpLog;
   private String categoryName;
+  private String DbRegexp;
   private String dbSubdir;
   private String ftpSubdir;
   private Logger logger;
 
   public UCSCGenomeUpdater(String division, SQLiteDataSource dataSource,
-      ReentrantReadWriteLock dbLock, File binDir, File dbDir,
+      ReentrantReadWriteLock dbLock, File binDir, File dbDir, String dbRegexp, String dbRel,
       ExecutorService worker, MultiSourceStatus statusManager) {
-    super("UCSC Genome Downloader", dataSource, dbLock, binDir, dbDir, worker, statusManager);
+    super("UCSC Genome Updater", dataSource, dbLock, binDir, dbDir, worker, statusManager);
+    DbRegexp = dbRegexp;
     Properties conf = loadConf(UCSCGenomeUpdater.class, dbDir, "UCSCGenomeUpdater.properties");
     scrape = conf.getProperty("scrape", "http://genome.ucsc.edu/FAQ/FAQreleases.html").trim();
-    host = conf.getProperty("host", "hgdownload.cse.ucsc.edu").trim();
+    host = conf.getProperty("host", "hgdownload.soe.ucsc.edu").trim();
     path = conf.getProperty("path", "/goldenPath/").trim();
     ftpLog = conf.getProperty("ftp.log", "").trim();
     categoryName = conf.getProperty(division + "_categoryName", "unknown_categoryName");
@@ -77,9 +79,9 @@ public class UCSCGenomeUpdater extends SequenceUpdater {
   }
 
   protected List<UCSCGenome> scrapeAvailableGenomes(
-   String division		// desired division (without "ucsc" at the front)
+    String division             // desired division (without "ucsc" at the front)
   ) {
-    progress.setTask("Querying Avaliable Genomes for division " + division, 0, -1);
+    progress.setTask("Querying Avaliable Databases from Division '" + division + "'", 0, -1);
     List<UCSCGenome> genomes = new ArrayList<UCSCGenome>();
     // Get a listing of available species.
     try {
@@ -182,7 +184,8 @@ public class UCSCGenomeUpdater extends SequenceUpdater {
       if (!loginFtp(ftp, host)) return null;
 
       // Get the list of available genomes for this division.
-      List<UCSCGenome> genomes = scrapeAvailableGenomes(dbSubdir.substring(4));
+      String division = dbSubdir.substring(4);
+      List<UCSCGenome> genomes = scrapeAvailableGenomes(division);
       if (genomes.isEmpty()) {
         logger.log(Level.SEVERE, "Failed parsing the genome releases from the FAQ... No genomes found!");
         return null;
@@ -190,22 +193,51 @@ public class UCSCGenomeUpdater extends SequenceUpdater {
 
       // Query the database to see which genomes we already have
       // and remove them so we don't download them again.
-      progress.setTask("Excluding Pre-exisiting Genomes", 0, -1);
+      // Only download genomes whose genome name matches the species regexp.
+      if (DbRegexp.equals("^$")) {
+        System.out.println("\nUCSC Genome Updater - Listing Missing FASTA files from Division '" + division + "':\n");
+      } else {
+        System.out.println("\nUCSC Genome Updater - Downloading FASTA files from Division '" + division + "':\n");
+        progress.setTask("Excluding Pre-exisiting Genomes", 0, -1);
+      }
       int navailable_genomes = 0;
-      int nremoved_genomes = 0;
+      int nhave_genomes = 0;
+      int nskipped_genomes = 0;
+      Pattern db_regexp = Pattern.compile(DbRegexp, Pattern.CASE_INSENSITIVE);
       Iterator<UCSCGenome> iterator = genomes.iterator();
+      String[] missingGenomes = new String[genomes.size()];
+      int nmissing = 0;
       while (iterator.hasNext()) {
         navailable_genomes++;
         UCSCGenome genome = iterator.next();
         if (sourceExists(genome, true)) {
           iterator.remove();
           logger.log(Level.INFO, "Already have " + genome.getNamePrefix());
-          nremoved_genomes++;
+          nhave_genomes++;
+          continue;
+        }
+        String listing_name = String.valueOf(genome);
+        Matcher matcher = db_regexp.matcher(listing_name);
+        boolean matchFound = matcher.find();
+        if (! matchFound) {
+          // List available genomes?
+          if (DbRegexp.equals("^$")) missingGenomes[nmissing++] = "missing: " + listing_name;
+          iterator.remove();
+          nskipped_genomes++;
+          continue;
         }
       }
-      logger.log(Level.INFO, "Number of AVAILABLE genomes: " + navailable_genomes);
-      logger.log(Level.INFO, "Number of genomes to UPDATE: " + (navailable_genomes - nremoved_genomes));
-      if (genomes.isEmpty()) return null;
+      // Print missing genomes, sorted.
+      if (DbRegexp.equals("^$") && nmissing > 0) {
+        String[] resizedArray = Arrays.copyOf(missingGenomes, nmissing);
+        Arrays.sort(resizedArray);
+        for (String missing : resizedArray) {
+          System.out.println(missing);
+        }
+      }
+      logger.log(Level.INFO, "Number of genomes AVAILABLE: " + navailable_genomes);
+      logger.log(Level.INFO, "Number of genomes HAVE: " + nhave_genomes);
+      logger.log(Level.INFO, "Number of genomes SKIPPED: " + nskipped_genomes);
 
       for (UCSCGenome genome : genomes) {
         try {
@@ -214,6 +246,7 @@ public class UCSCGenomeUpdater extends SequenceUpdater {
           checkWorkerTasks();
           if (!downloadFtpSource(ftp, genome, true, RETRY_COUNT)) continue;
           enqueueSequences(new UCSCSequenceProcessor(genome, dbTarget));
+	  nhave_genomes++;
         } catch (IOException e) {
           logger.log(Level.WARNING, "Skipped " + genome + " due to ftp errors", e);
           errorCount++;
@@ -224,6 +257,12 @@ public class UCSCGenomeUpdater extends SequenceUpdater {
       ftp.disconnect();
       progress.complete();
       waitForWorkerTasks();
+      // Report numbers of Available and Missing sequence files.
+      int nmissing_genomes = navailable_genomes - nhave_genomes;
+      String a_verb = (navailable_genomes == 1) ? " is " : " are ";
+      String m_verb = (nmissing_genomes == 1) ? " is " : " are ";
+      System.out.println("\nThere" + a_verb + navailable_genomes + " available sequence file(s) and " +
+        (navailable_genomes - nhave_genomes) + m_verb + "missing.\n*******");
       logger.log(Level.INFO, "Finished update of " + categoryName);
     } catch (ExecutionException e) { // only thrown by sequence processor
       cancelWorkerTasks();
@@ -272,7 +311,7 @@ public class UCSCGenomeUpdater extends SequenceUpdater {
     }
   }
 
-  private static Pattern editionPattern = Pattern.compile("^[a-zA-Z]+(\\d+)$");
+  private static Pattern editionPattern = Pattern.compile("^[a-zA-Z]+(\\d*)$");
 
   private class UCSCGenome extends AbstractFtpSource {
     private String group;
@@ -295,17 +334,18 @@ public class UCSCGenomeUpdater extends SequenceUpdater {
     private double seqStdDLen;
     private long seqTotalLen;
 
-
     public UCSCGenome(String group, String species, boolean speciesItalic, String version, String releaseDate, String releaseName) {
       Matcher m = editionPattern.matcher(version);
       if (!m.matches()) throw new IllegalArgumentException("UCSC version does not match expected pattern");
+      String match = m.group(1);
       this.group = group;
       this.species = species;
       this.speciesItalic = speciesItalic;
       this.version = version;
       this.releaseDate = releaseDate;
       this.releaseName = releaseName;
-      this.edition = Integer.parseInt(m.group(1), 10);
+      //this.edition = Integer.parseInt(m.group(1), 10);
+      this.edition = match.isEmpty() ? 0 : Integer.parseInt(match, 10);
     }
 
     public String toString() {
