@@ -600,12 +600,15 @@ public class UpdateSequenceDB {
    * @param ds the database source, the database should be initialised already.
    * @param binDir the directory containing the fasta_get_markov program.
    * @param dbDir the directory containing the fasta databases.
+   * @param dbRegexp a JAVA regular expression to limit which databases are downloaded.
+   * @param dbRel a string specifying the desired release of the databases to download.
    * @param updaters a list of classes to run to update the database.
    * @param status access to the command line to display status messages.
    */
   public static void update(SQLiteDataSource ds,
-      File binDir, File dbDir, List<String> updaters, MultiSourceStatus status) {
-    logger.log(Level.INFO, "Started update of sequence databases in " + dbDir);
+      File binDir, File dbDir, String dbRegexp, String dbRel, List<String> updaters, MultiSourceStatus status) {
+    logger.log(Level.INFO, "Started update of sequence databases in " + dbDir + " matching JAVA regexp '" + dbRegexp + "'");
+    logger.log(Level.INFO, "Desired database release: '" + dbRel + "'");
     // check that we actually have some updaters selected
     if (updaters.size() > 0) {
       // this thread is responsible for unpacking files and generating the background
@@ -624,9 +627,9 @@ public class UpdateSequenceDB {
       for (String className : updaters) {
 
         try {
-          // Special handling for Ensembl (and Genbank and UCSC) divisions; 
-          // use the EnsemblUpdater (or GenbankUpdater and UCSC) 
-	  // with the division specified in its call.
+          // Special handling for Ensembl (and Genbank and UCSC and RSAT) divisions; 
+          // use the EnsemblUpdater (or GenbankUpdater or UCSC or RSAT) 
+	  // with the division specified in its Constructor call.
           String division = "unknown_division";
           Pattern ensemblMethod = Pattern.compile("^ensembl.*[abinitio]{0,1}.*$");
           Matcher m = ensemblMethod.matcher(className);
@@ -655,13 +658,24 @@ public class UpdateSequenceDB {
 	      }
 	    }
           }
+	  // Only allow listing or specifying of releases for Ensembl.
+          if (className != "au.edu.uq.imb.memesuite.updatedb.EnsemblUpdater") {
+	    if (dbRel != "0") {
+	      if (dbRel == "-1") {
+		System.err.println("\nERROR: --list_rel is only supported for Ensembl databases.");
+	      } else {
+		System.err.println("\nERROR: --db_rel is only supported for Ensembl databases.");
+	      }
+	      System.exit(1);
+	    }
+          }
           // Create the constructor for the updater.
           Class<?> updaterClass = Class.forName(className);
           Constructor<?> updaterConstructor = updaterClass.getConstructor(
               String.class, SQLiteDataSource.class, ReentrantReadWriteLock.class, File.class,
-              File.class, ExecutorService.class, MultiSourceStatus.class);
+              File.class, String.class, String.class, ExecutorService.class, MultiSourceStatus.class);
           Object updater = updaterConstructor.newInstance(division, ds, lock, binDir,
-              dbDir, sequenceWorker, status);
+              dbDir, dbRegexp, dbRel, sequenceWorker, status);
           // launch the task
           downloaderTasks.add(downloadWorkers.submit((Callable<?>)updater));
         } catch (Exception e) {
@@ -1146,6 +1160,31 @@ public class UpdateSequenceDB {
     List<String> updaters = new ArrayList<String>();
     List<Parameter> parameters = new ArrayList<Parameter>();
 
+    // General Options
+    parameters.add(
+      new Switch("db_all")
+          .setLongFlag("db_all")
+          .setHelp("Download all available FASTA files from the chosen category (see below). " +
+                   "Default: list available FASTA files from the chosen category.")
+    );
+    parameters.add(
+      new FlaggedOption("db_regexp").setStringParser(JSAP.STRING_PARSER).
+          setLongFlag("db_regexp").
+          setHelp("Download only FASTA files from the chosen category (see below) matching the given JAVA regular expression. " +
+                  "Default: list available databases of the chosen category.")
+    );
+    parameters.add(
+      new FlaggedOption("db_rel").setStringParser(JSAP.STRING_PARSER).
+          setLongFlag("db_rel").
+          setHelp("Download FASTA files or list missing FASTA files from this specific release of the chosen category (see below).")
+    );
+    parameters.add(
+      new Switch("list_rel")
+          .setLongFlag("list_rel")
+          .setHelp("List available database release numbers of the chosen category (see below) and exit.")
+    );
+
+    // Selecta a Category of Databases to Update or List
     for (String id : ids) {
       // add the class to the list of downloaders
       String qualifiedClass = setup.getProperty("dl." + id + ".class");
@@ -1154,32 +1193,23 @@ public class UpdateSequenceDB {
       // add an option to enable the downloader
       Switch aSwitch = new Switch(qualifiedClass).setLongFlag(id);
       String description = setup.getProperty("dl." + id + ".description", id);
-      if (description != null) aSwitch.setHelp("Enable downloading " + description + ".");
+      if (description != null) aSwitch.setHelp("Download category: " + description + ".");
       parameters.add(aSwitch);
     }
-
-    // define some special parsers for files
-    StringParser FILE_PARSER = FileStringParser.getParser().setMustBeFile(true);
-    StringParser DIR_PARSER = FileStringParser.getParser().setMustBeDirectory(true);
-
-    // add the always existing switches
     parameters.add(
       new FlaggedOption("updater").setStringParser(new ClassnameStringParser())
           .setLongFlag("updater").setShortFlag('u')
           .setAllowMultipleDeclarations(true)
           .setHelp("Specify the classname of a custom updater [experimental].")
     );
+
+    // File Cleanup Options
     parameters.add(
         new FlaggedOption("obsolete")
             .setLongFlag("obsolete")
             .setAllowMultipleDeclarations(true)
             .setHelp("Mark all sequence databases matching the GLOB pattern file name(s) as obsolete and exit.")
     );
-    parameters.add(
-        new FlaggedOption("load_priors").setStringParser(FILE_PARSER)
-            .setLongFlag("priors")
-            .setHelp("Add priors to the database for the entries mentioned in the tab separated file and exit.")
-    );
     parameters.add(
       new Switch("remove_obsolete")
           .setLongFlag("delete_old").setShortFlag('d')
@@ -1188,14 +1218,30 @@ public class UpdateSequenceDB {
     parameters.add(
         new Switch("retain_missing")
         .setLongFlag("retain_missing")
-        .setHelp("Sequence databases that the file has been lost for will be kept in the database.")
+        .setHelp("Sequence databases that the file has been lost for will be kept in the sqlite database.")
     );
+    parameters.add(
+      new Switch("purge_only")
+          .setLongFlag("purge_only")
+          .setHelp("Delete sequence databases for which the files have been lost and exit.")
+    );
+    
+    // Backwards Compatibility Options
+    StringParser FILE_PARSER = FileStringParser.getParser().setMustBeFile(true);
+    StringParser DIR_PARSER = FileStringParser.getParser().setMustBeDirectory(true);
     parameters.add(
       new QualifiedSwitch("csv_dir").setStringParser(FILE_PARSER).
           setLongFlag("csv").setShortFlag('c').
           setHelp("Create a csv file and index file that lists all the databases to " +
               "enable backwards compatibility with older releases.")
     );
+
+    // Miscellaneous Options
+    parameters.add(
+        new FlaggedOption("load_priors").setStringParser(FILE_PARSER)
+            .setLongFlag("priors")
+            .setHelp("Add priors to the database for the entries mentioned in the tab separated file and exit.")
+    );
     parameters.add(
       new FlaggedOption("bin_dir").setStringParser(DIR_PARSER).
           setLongFlag("bin").setShortFlag('b').
@@ -1214,21 +1260,22 @@ public class UpdateSequenceDB {
           .setHelp("Specify the logging level [1-8].")
     );
     parameters.add(
-      new Switch("purge_only")
-          .setLongFlag("purge_only")
-          .setHelp("Delete sequence databases for which the files have been lost and exit.")
-    );
-    parameters.add(
-      new UnflaggedOption("db_dir").setStringParser(DIR_PARSER).setRequired(true)
-          .setHelp("Specify the directory containing the databases.")
+      new UnflaggedOption("db_dir").setStringParser(DIR_PARSER)
+          .setHelp("Specify the local directory to contain (or already containing) the MEME Suite FASTA database.")
     );
 
     SimpleJSAP jsap = new SimpleJSAP(
       "update-sequence-db",
-      "  Updates sequence databases; optionally removes old databases.",
+      "Download sequence FASTA files from the given category(s) to a MEME Suite FASTA database. " + 
+      "If --db_all or --db_regexp is not given, list the missing FASTA files from the given category(s).\n",
       parameters.toArray(new Parameter[parameters.size()])
     );
 
+    // Make --help the default argument.
+    if (args.length == 0) {
+      args = new String[] {"--help"};
+    }
+
     // Parse the arguments.
     JSAPResult config = jsap.parse(args);
     if (jsap.messagePrinted()) {
@@ -1256,7 +1303,7 @@ public class UpdateSequenceDB {
 
     // Error if no updaters given.
     if (! specified_only && ! config.getBoolean("purge_only", false)) {
-      System.err.println("Error: You must specify at least one database to update.");
+      System.err.println("Error: You must specify at least one category to update or list.");
       System.exit(1);
     }
 
@@ -1270,12 +1317,53 @@ public class UpdateSequenceDB {
       return; // make compiler happy
     }
 
-    File dbDir = config.getFile("db_dir");
+    // determine which databases to download (or list)
+    String dbRegexp;
+    if (config.getBoolean("db_all")) {
+      // download all databases in category
+      dbRegexp = ".*";
+    } else if (config.contains("db_regexp")) {
+      // download only databases matching the regexp
+      dbRegexp = config.getString("db_regexp");
+    } else {
+      // just list the (new) databases available for downloading
+      dbRegexp = "^$";		// default
+    }
+
+    // determine which release to download (or list all releases)
+    String dbRel;
+    if (config.getBoolean("list_rel")) {
+      // just list available releases and exit
+      dbRel = "-1";
+    } else if (config.contains("db_rel")) {
+      // download specific release
+      dbRel = config.getString("db_rel");
+    } else {
+      // download most recent available release
+      dbRel = "0";		// default
+    }
+ 
+    // Prepare MEME Suite FASTA database directory unless we are just listing available releases.
+    File dbDir = null;
+    if (! config.contains("db_dir")) {
+      if (dbRel != "-1") {
+	System.err.println("ERROR: <db_dir> is required unless you specify --db_rel.");
+	System.exit(1);
+      } else {
+        // When listing releases, if no <db_dir> is given, logs go to /tmp/UpdateSequenceDB.
+        dbDir = new File("/tmp/UpdateSequenceDB");
+      }
+    } else {
+      dbDir = config.getFile("db_dir");
+    }
+
     // create the database directory if it doesn't exist
     if (!dbDir.exists() && !dbDir.mkdirs()) {
       System.err.println("Unable to create database directory!");
       System.exit(1);
     }
+
+    // create the logs directory if it doesn't exist.
     File log_dir = new File(dbDir, "logs");
     if (!log_dir.exists() && !log_dir.mkdir()) {
       System.err.println("Unable to create log directory!");
@@ -1331,7 +1419,7 @@ public class UpdateSequenceDB {
         // remove obsolete databases
         if (config.getBoolean("remove_obsolete")) removeObsolete(ds, dbDir);
         // ** run the selected updaters **
-        update(ds, binDir, dbDir, updaters, status);
+        update(ds, binDir, dbDir, dbRegexp, dbRel, updaters, status);
         // create the optional backwards compatibility views
         if (config.getBoolean("csv_dir")) {
           File csv_dir = config.getFile("csv_dir", dbDir);
